(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    587479,      13940]
NotebookOptionsPosition[    584616,      13842]
NotebookOutlinePosition[    584956,      13857]
CellTagsIndexPosition[    584913,      13854]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Bottlenecks", "Title",
 CellChangeTimes->{{3.649003803137397*^9, 3.649003816647418*^9}}],

Cell[CellGroupData[{

Cell["User-defined Versus Built-in Function Calls", "Section",
 CellChangeTimes->{{3.649008231278201*^9, 3.649008252277236*^9}}],

Cell["\<\
To optimize in Wolfram Language, the user should focus on the 10 steps \
described by Jon McLoone in the Wolfram Blog post.\
\>", "Text",
 CellChangeTimes->{{3.649008263392253*^9, 3.6490083022593117`*^9}, {
  3.6490083774642344`*^9, 3.6490084048377857`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hyperlink", "[", 
  RowBox[{
  "\"\<10 Steps for Writing Fast Code\>\"", ",", 
   "\"\<http://blog.wolfram.com/2011/12/07/10-tips-for-writing-fast-\
mathematica-code/\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.649008405717787*^9, 3.649008419073806*^9}}],

Cell[BoxData[
 TagBox[
  ButtonBox[
   PaneSelectorBox[{False->"\<\"10 Steps for Writing Fast Code\"\>", True->
    StyleBox["\<\"10 Steps for Writing Fast Code\"\>", "HyperlinkActive"]}, 
    Dynamic[
     CurrentValue["MouseOver"]],
    BaseStyle->{"Hyperlink"},
    FrameMargins->0,
    ImageSize->Automatic],
   BaseStyle->"Hyperlink",
   ButtonData->{
     URL["http://blog.wolfram.com/2011/12/07/10-tips-for-writing-fast-\
mathematica-code/"], None},
   ButtonNote->
    "http://blog.wolfram.com/2011/12/07/10-tips-for-writing-fast-mathematica-\
code/"],
  Annotation[#, 
   "http://blog.wolfram.com/2011/12/07/10-tips-for-writing-fast-mathematica-\
code/", "Hyperlink"]& ]], "Output",
 CellChangeTimes->{
  3.649008420194808*^9, {3.649008844668479*^9, 3.6490088648015127`*^9}, 
   3.6490104025437827`*^9, 3.649065960135574*^9, 3.6490906787684355`*^9, 
   3.649106617409242*^9, {3.6491067752553368`*^9, 3.6491068267242284`*^9}}]
}, Open  ]],

Cell["\<\
Utilization of built-in functions to accomplish a desired task is preferred. \
The functions themselves have been optimized to achieve completion of their \
task at maximum speeds. Often, the user will write a single function that \
accomplishes the task and move on. However, without attempting to form \
various solutions the user will habitually fallback on their standard \
knowledge and never access the full depth and capability that the language \
provides.\
\>", "Text",
 CellChangeTimes->{{3.649008432086826*^9, 3.6490085423400073`*^9}}],

Cell["\<\
Basic analysis is done on a user package. The code achieves the required \
task, however it is not well formed (interpretation below) .\
\>", "Text",
 CellChangeTimes->{{3.649008549464019*^9, 3.649008611701116*^9}, {
  3.649008789453393*^9, 3.6490087947064004`*^9}}],

Cell["\<\
The author is defined a well formed solution as one which meets the following \
criteria:\
\>", "Text",
 CellChangeTimes->{{3.6490086171271267`*^9, 3.649008663639196*^9}}],

Cell["\<\
\t- Minimization of memory usage via proper package development and \
encapsulation of variables\
\>", "Text",
 CellChangeTimes->{{3.649008667044202*^9, 3.649008696612249*^9}, {
  3.649008750683335*^9, 3.649008756179343*^9}}],

Cell["\<\
\t- Minimization of processor time by implementation of timing tests and \
multiple solutions\
\>", "Text",
 CellChangeTimes->{{3.6490087011482587`*^9, 3.6490087802353797`*^9}}],

Cell["\t- Achieves the solution", "Text",
 CellChangeTimes->{{3.649008735262311*^9, 3.649008741296321*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Load", " ", "the", " ", "package"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SetDirectory", "[", 
     RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"<<", "\"\<MotivaMultiPeriodOptimization.wl\>\""}]}]}]], "Input",
 CellChangeTimes->{{3.6489958993111963`*^9, 3.648995919217228*^9}, {
  3.6489959871513352`*^9, 3.6489959882313366`*^9}, {3.649003629767128*^9, 
  3.649003645277152*^9}, {3.649003681797207*^9, 3.649003685635213*^9}, {
  3.649008830718457*^9, 3.649008855963497*^9}, {3.6490692689407687`*^9, 
  3.649069270640772*^9}, {3.6491066324158697`*^9, 3.6491067703881283`*^9}}],

Cell[TextData[{
 "It is important in this step to realize that the user-defined variables and \
functions are present in the \[OpenCurlyDoubleQuote]Global`\
\[CloseCurlyDoubleQuote] context. The user should strive to create code that \
follows basic package formatting present in the availabe packages. More than \
500 packages are present in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v10.2. "
}], "Text",
 CellChangeTimes->{{3.649008822152444*^9, 3.649008827621452*^9}, {
  3.6490088804755363`*^9, 3.6490089596126614`*^9}, {3.649009049275137*^9, 
  3.6490090705911703`*^9}, {3.649069296607811*^9, 3.649069297577812*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"avaiable", " ", "packages"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Length", "@", "#"}], ",", 
      RowBox[{"Short", "@", "#"}]}], "}"}], "&"}], "@", 
   RowBox[{"Contexts", "[", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6490089655386705`*^9, 3.649009018917754*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"463", ",", 
   TagBox[
    RowBox[{"{", 
     RowBox[{"\<\"Algebra`\"\>", ",", "\<\"Algebraics`Private`\"\>", 
      ",", "\<\"Algebra`Polynomial`\"\>", ",", 
      RowBox[{"\[LeftSkeleton]", "457", "\[RightSkeleton]"}], 
      ",", "\<\"XML`RSS`\"\>", ",", "\<\"XML`SVG`\"\>", 
      ",", "\<\"$CellContext`\"\>"}], "}"}],
    Short]}], "}"}]], "Output",
 CellChangeTimes->{{3.649009005121733*^9, 3.649009033495776*^9}, 
   3.649010402663783*^9, 3.6490659603071737`*^9, 3.649090678948436*^9, 
   3.6491066175672426`*^9, {3.6491067753801374`*^9, 3.649106826880229*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Number", " ", "of", " ", "user", " ", "defined", " ", "functions", " ", 
    "and", " ", 
    RowBox[{"variables", ":", " ", 
     RowBox[{"All", " ", "accessed", " ", 
      RowBox[{"globally", "!"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"$UserFunc", ",", "$UserVars"}], "}"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Extract", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"#2", "/@", 
              RowBox[{"First", "/@", 
               RowBox[{"Characters", "/@", "#"}]}]}], ",", "True"}], "]"}]}], 
          "]"}], ")"}], "&"}], "[", 
       RowBox[{
        RowBox[{"Names", "[", "\"\<Global`*\>\"", "]"}], ",", "#"}], "]"}], 
      "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{"UpperCaseQ", ",", "LowerCaseQ"}], "}"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.6489973966241407`*^9, 3.6489975038333116`*^9}, {
   3.648997877448897*^9, 3.6489979319019814`*^9}, {3.648997989298067*^9, 
   3.6489981301122956`*^9}, {3.6490035891220665`*^9, 3.649003606079091*^9}, 
   3.6490037024962435`*^9, {3.649006287852104*^9, 3.649006312826155*^9}, {
   3.6490110428973885`*^9, 3.6490110502004004`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "/@", 
  RowBox[{"{", 
   RowBox[{"$UserFunc", ",", "$UserVars"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6490063153961606`*^9, 3.6490063292571898`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"84", ",", "98"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6490063301121917`*^9, {3.6490088448284793`*^9, 3.649008864911513*^9}, 
   3.649010402723783*^9, 3.649065960338374*^9, 3.6490906790184355`*^9, 
   3.649106617582843*^9, {3.649106775411337*^9, 3.6491068268958287`*^9}}]
}, Open  ]],

Cell[TextData[{
 "Note the use of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Set", " ", 
    RowBox[{"(", "=", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " versus ",
 Cell[BoxData[
  FormBox[
   RowBox[{"SetDelayed", " ", 
    RowBox[{"(", ":=", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The ",
 Cell[BoxData[
  FormBox["Set", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " commands forces the import to happen immediately and only once. The ",
 Cell[BoxData[
  FormBox["SetDelayed", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " action would cause the import to reoccur each time the LHS is called. \
Although this import is a trivial example, importation of large data sets or \
from URL sources can be quite expensive. "
}], "Text",
 CellChangeTimes->{{3.6490090982032127`*^9, 3.6490092567994566`*^9}, {
  3.649009287629504*^9, 3.6490092919895115`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Import", " ", "package", " ", "as", " ", "text"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"LoadText", "[", "]"}], "=", 
    RowBox[{"Import", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
       "\"\<MotivaMultiPeriodOptimization.wl\>\""}], ",", "\"\<Text\>\""}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.6490038330754433`*^9, 3.6490038558474784`*^9}, 
   3.649003955583632*^9, {3.6490042329130697`*^9, 3.6490042591631107`*^9}, {
   3.649009264230468*^9, 3.649009269380475*^9}, {3.649106808383196*^9, 
   3.649106813286605*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"All", " ", "System", " ", "functions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SysFunc", "[", "]"}], "=", 
    RowBox[{"Cases", "[", 
     RowBox[{
      RowBox[{"Names", "[", "\"\<System`*\>\"", "]"}], ",", 
      RowBox[{"x_", "/;", 
       RowBox[{
        RowBox[{"StringLength", "[", "x", "]"}], ">", "1"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.6490038820805182`*^9, 3.6490039300205917`*^9}, {
  3.6490039616936407`*^9, 3.6490039698146544`*^9}}],

Cell["\<\
Importing the *.wl package as text allows for quick patten matching. The \
imported text is compared against both the built-in functions and the \
user-defined functions. Upon totaling the values, the user-defined functions \
are called at a rate over 25%.\
\>", "Text",
 CellChangeTimes->{{3.649009332252575*^9, 3.649009395507672*^9}, {
  3.649009456898775*^9, 3.6490094571587753`*^9}, {3.649010117151092*^9, 
  3.6490101693341837`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Built", "-", 
    RowBox[{"in", " ", "function", " ", "calls"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"userDS", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"StringCases", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"LoadText", "[", "]"}], ",", 
         RowBox[{"Alternatives", "@@", 
          RowBox[{"SysFunc", "[", "]"}]}], ",", 
         RowBox[{"Overlaps", "\[Rule]", "False"}]}], "\[IndentingNewLine]", 
        "]"}], "//", "Tally"}], "//", 
      RowBox[{"SortBy", "[", "Last", "]"}]}], "//", "Reverse"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQnabuFP9S/7Xjhsp3SSDahzE0HUQv2zkfTFttEy8C
0bsyFEtB9APpzXUgOocxogFEm9WqdILoIJsJ/SDaILBqMoh2WZQ9H0SXN71e
AaK9/GQ3g+gj9y6avwbSdsciLUB0wZr1ISC6rvkymNa4np4Kog2u6qSBaJ2+
9TkgmqlDvwFE73lV3AKi11rW9YPoBb0dp0C08avt50A01652jTdA+tZ3RR0Q
zWXMHgSiza7rh4Jom7LiJBCd+dI/HURLK7pmg2iV0gNg2mPR8wYQrScr0wii
U2YyJb4F0mK3v4FpACrpm8w=
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"userDF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"StringCases", "[", 
       RowBox[{
        RowBox[{"LoadText", "[", "]"}], ",", 
        RowBox[{"Alternatives", "@@", "$UserFunc"}], ",", 
        RowBox[{"Overlaps", "\[Rule]", "False"}]}], "]"}], "//", "Tally"}], "//", 
     RowBox[{"SortBy", "[", "Last", "]"}]}], "//", "Reverse"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6490062330459538`*^9, 3.64900627438207*^9}, 
   3.6490063759542933`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Total", " ", "built"}], "-", 
    RowBox[{"in", " ", "function", " ", "calls"}]}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Total", "@", 
   RowBox[{"userDS", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6490061911108637`*^9, 3.6490062082798967`*^9}, {
  3.6490073801064386`*^9, 3.6490073815344415`*^9}}],

Cell[BoxData["2181"], "Output",
 CellChangeTimes->{{3.649008847938483*^9, 3.6490088680445175`*^9}, 
   3.649010405774788*^9, 3.64906596347998*^9, 3.6490906821894426`*^9, 
   3.6491066181288433`*^9, {3.6491067758793383`*^9, 3.6491067999123807`*^9}, 
   3.649106830031434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Total", " ", "user"}], "-", 
    RowBox[{"defined", " ", "function", " ", "calls"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Total", "@", 
   RowBox[{"userDF", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.649007373135425*^9, 3.6490073976354747`*^9}}],

Cell[BoxData["602"], "Output",
 CellChangeTimes->{
  3.649007398130476*^9, {3.6490074501725793`*^9, 3.649007481581648*^9}, {
   3.649008848008484*^9, 3.6490088681145177`*^9}, 3.649010405784788*^9, 
   3.64906596347998*^9, 3.6490906821994424`*^9, 3.649106618238044*^9, {
   3.6491067759885387`*^9, 3.6491068000215807`*^9}, 3.6491068300470343`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Ratio", " ", 
     RowBox[{"user", "/", "built"}]}], "-", "in"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"N", "[", 
   RowBox[{"%", "/", "%%"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.649007407491493*^9, 3.649007474627636*^9}}],

Cell[BoxData["0.27602017423200365`"], "Output",
 CellChangeTimes->{{3.6490074367635536`*^9, 3.6490074830946503`*^9}, {
   3.6490088480284834`*^9, 3.6490088681245174`*^9}, {3.6490103976057754`*^9, 
   3.649010405794788*^9}, 3.6490659634955797`*^9, 3.649090682209442*^9, 
   3.649106618316044*^9, {3.6491067760665383`*^9, 3.6491068300626345`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Comparision", " ", "of", " ", "function", " ", "calls"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"#2", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotTheme", "\[Rule]", "\"\<Scientific\>\""}], ",", 
      RowBox[{"Filling", "->", "Axis"}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Builtin\>\"", ",", "\"\<Defined\>\""}], "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Func Calls\>\"", ",", "None"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"None", ",", "None"}], "}"}]}], "}"}]}], ",", 
      RowBox[{
      "PlotLabel", "\[Rule]", 
       "\"\<Comparing Built-in to User-definied Function Calls\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "&"}], "[", 
   RowBox[{"userDS", ",", "userDF"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.649007009425666*^9, 3.649007067475787*^9}, {
  3.6490071548079653`*^9, 3.6490073553243847`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, 
     GraphicsComplexBox[CompressedData["
1:eJzt2ctOVEEQxvGOK5YsWLBggRNCCCGE+x3mKCqKFxS83zAmroz6CvUoPko9
ko/g5dRXJ/0n7tyY9Cyo/KaoYZhz5uuk+/rHb+efrpVSzn79+F37x4/xn9J9
7eKJvn7/Ep6I+iHqZNTzqFNRH0ed7qudhmeiyrPRvxsewXNR5fmoJ1EX4vfv
hBfDx+Gl8M3wMrwCr0aV16LeiLoOb0Ttom5GHUfdgrejHkXdiXoYdTfqHqqe
34cP/vI6/Dt8H3qfet/xfxmc/2d8Dibzcwrzcy3HtQ0ut6LqusDldlRdRzmu
c+F1l+O+uHKfyLqPcF9due/u1TZ5FPW0tsHlPvpy3PflQW2T9T15WNvg8gh9
Ob535SxqfC8Nzu9puIMNdrg8wbwcuWCww5kb4Q422OFygXnYYIfLU8zDBrus
HHxWu4MNdrg8xzxssMPlBeZhkyPHHS4va3ewwQ6XV5iHTY51xeHyunYHG+xw
eYN52GCHy1vMwwY7XN5hHjbY4fIe87DBDpdLWK/zOZ7XdVAu6r7ROjEJ63ut
/FWOKG9nYOWY8nIE83nlrl5nAebfWYL1vvQ+V+BVeA1ehzfgTXgL3oZ34F14
D96HtX7zOshH8Bjuahuc67f6cK7fygs412/14Vy/1Ydz/VYfLrgvr9ynJ+jD
uX6rD+f6rb6s/DqtbXCu3+rDuX6rD+f6rT6c67f6cK7f6sO5fit/YYMdzvVb
87LyB3Y412/lDpw1H13NCXgSnoKn4Rl4Fh7Bc/A8vAAvwkvwMrwCr8Jr8Dq8
AW/CW/A2vAPvwnvwPnwAH8JH8BjuahuceaQ+nHmkPpx5pD6ceaQ+nHmkPpx5
pD6ceaQ+nHmkPpx5pD485FH04SGPog8PeRR9eMij6MNDHkUfHvIo+vCQR/2j
gw12eMijmIcNdjjzSPNwyyO45VHdb3lU91se1fP/OI8MdubVRe0ONtjh3N/Q
PGyww7m/oXnYYIdzf0PzsMEO5/6G5mGDHR72N2IeNtjhYX8j5mGDHc79Dc3D
Bjuc+xuahw12OPc3NA8b7HDub2geNtjh3N/QPGyww7m/oUc7n+ir3M4n+trO
J/p+O5+o59v5ROV2PoH5dj5Rz7fzifp12vlEX9v5RN9v5xN1//89n/gJIKl9
Bg==
      "], {{{}, {}, {}, {}, {}, {
         Directive[
          RGBColor[0.9, 0.36, 0.054], 
          Opacity[0.3]], 
         LineBox[{271, 1}], 
         LineBox[{272, 2}], 
         LineBox[{273, 3}], 
         LineBox[{274, 4}], 
         LineBox[{275, 5}], 
         LineBox[{276, 6}], 
         LineBox[{277, 7}], 
         LineBox[{278, 8}], 
         LineBox[{279, 9}], 
         LineBox[{280, 10}], 
         LineBox[{281, 11}], 
         LineBox[{282, 12}], 
         LineBox[{283, 13}], 
         LineBox[{284, 14}], 
         LineBox[{285, 15}], 
         LineBox[{286, 16}], 
         LineBox[{287, 17}], 
         LineBox[{288, 18}], 
         LineBox[{289, 19}], 
         LineBox[{290, 20}], 
         LineBox[{291, 21}], 
         LineBox[{292, 22}], 
         LineBox[{293, 23}], 
         LineBox[{294, 24}], 
         LineBox[{295, 25}], 
         LineBox[{296, 26}], 
         LineBox[{297, 27}], 
         LineBox[{298, 28}], 
         LineBox[{299, 29}], 
         LineBox[{300, 30}], 
         LineBox[{301, 31}], 
         LineBox[{302, 32}], 
         LineBox[{303, 33}], 
         LineBox[{304, 34}], 
         LineBox[{305, 35}], 
         LineBox[{306, 36}], 
         LineBox[{307, 37}], 
         LineBox[{308, 38}], 
         LineBox[{309, 39}], 
         LineBox[{310, 40}], 
         LineBox[{311, 41}], 
         LineBox[{312, 42}], 
         LineBox[{313, 43}], 
         LineBox[{314, 44}], 
         LineBox[{315, 45}], 
         LineBox[{316, 46}], 
         LineBox[{317, 47}], 
         LineBox[{318, 48}], 
         LineBox[{319, 49}], 
         LineBox[{320, 50}], 
         LineBox[{321, 51}], 
         LineBox[{322, 52}], 
         LineBox[{323, 53}], 
         LineBox[{324, 54}], 
         LineBox[{325, 55}], 
         LineBox[{326, 56}], 
         LineBox[{327, 57}], 
         LineBox[{328, 58}], 
         LineBox[{329, 59}], 
         LineBox[{330, 60}], 
         LineBox[{331, 61}], 
         LineBox[{332, 62}], 
         LineBox[{333, 63}], 
         LineBox[{334, 64}], 
         LineBox[{335, 65}], 
         LineBox[{336, 66}], 
         LineBox[{337, 67}], 
         LineBox[{338, 68}], 
         LineBox[{339, 69}], 
         LineBox[{340, 70}], 
         LineBox[{341, 71}], 
         LineBox[{342, 72}], 
         LineBox[{343, 73}], 
         LineBox[{344, 74}], 
         LineBox[{345, 75}], 
         LineBox[{346, 76}], 
         LineBox[{347, 77}], 
         LineBox[{348, 78}], 
         LineBox[{349, 79}], 
         LineBox[{350, 80}], 
         LineBox[{351, 81}], 
         LineBox[{352, 82}], 
         LineBox[{353, 83}], 
         LineBox[{354, 84}], 
         LineBox[{355, 85}], 
         LineBox[{356, 86}], 
         LineBox[{357, 87}], 
         LineBox[{358, 88}], 
         LineBox[{359, 89}], 
         LineBox[{360, 90}], 
         LineBox[{361, 91}], 
         LineBox[{362, 92}], 
         LineBox[{363, 93}], 
         LineBox[{364, 94}], 
         LineBox[{365, 95}], 
         LineBox[{366, 96}], 
         LineBox[{367, 97}], 
         LineBox[{368, 98}], 
         LineBox[{369, 99}], 
         LineBox[{370, 100}], 
         LineBox[{371, 101}], 
         LineBox[{372, 102}], 
         LineBox[{373, 103}], 
         LineBox[{374, 104}], 
         LineBox[{375, 105}], 
         LineBox[{376, 106}], 
         LineBox[{377, 107}], 
         LineBox[{378, 108}], 
         LineBox[{379, 109}], 
         LineBox[{380, 110}], 
         LineBox[{381, 111}], 
         LineBox[{382, 112}], 
         LineBox[{383, 113}], 
         LineBox[{384, 114}], 
         LineBox[{385, 115}], 
         LineBox[{386, 116}], 
         LineBox[{387, 117}], 
         LineBox[{388, 118}], 
         LineBox[{389, 119}], 
         LineBox[{390, 120}], 
         LineBox[{391, 121}], 
         LineBox[{392, 122}], 
         LineBox[{393, 123}], 
         LineBox[{394, 124}]}, {}, {
         Directive[
          RGBColor[0.365248, 0.427802, 0.758297], 
          Opacity[0.3]], 
         LineBox[{198, 125}], 
         LineBox[{199, 126}], 
         LineBox[{200, 127}], 
         LineBox[{201, 128}], 
         LineBox[{202, 129}], 
         LineBox[{203, 130}], 
         LineBox[{204, 131}], 
         LineBox[{205, 132}], 
         LineBox[{206, 133}], 
         LineBox[{207, 134}], 
         LineBox[{208, 135}], 
         LineBox[{209, 136}], 
         LineBox[{210, 137}], 
         LineBox[{211, 138}], 
         LineBox[{212, 139}], 
         LineBox[{213, 140}], 
         LineBox[{214, 141}], 
         LineBox[{215, 142}], 
         LineBox[{216, 143}], 
         LineBox[{217, 144}], 
         LineBox[{218, 145}], 
         LineBox[{219, 146}], 
         LineBox[{220, 147}], 
         LineBox[{221, 148}], 
         LineBox[{222, 149}], 
         LineBox[{223, 150}], 
         LineBox[{224, 151}], 
         LineBox[{225, 152}], 
         LineBox[{226, 153}], 
         LineBox[{227, 154}], 
         LineBox[{228, 155}], 
         LineBox[{229, 156}], 
         LineBox[{230, 157}], 
         LineBox[{231, 158}], 
         LineBox[{232, 159}], 
         LineBox[{233, 160}], 
         LineBox[{234, 161}], 
         LineBox[{235, 162}], 
         LineBox[{236, 163}], 
         LineBox[{237, 164}], 
         LineBox[{238, 165}], 
         LineBox[{239, 166}], 
         LineBox[{240, 167}], 
         LineBox[{241, 168}], 
         LineBox[{242, 169}], 
         LineBox[{243, 170}], 
         LineBox[{244, 171}], 
         LineBox[{245, 172}], 
         LineBox[{246, 173}], 
         LineBox[{247, 174}], 
         LineBox[{248, 175}], 
         LineBox[{249, 176}], 
         LineBox[{250, 177}], 
         LineBox[{251, 178}], 
         LineBox[{252, 179}], 
         LineBox[{253, 180}], 
         LineBox[{254, 181}], 
         LineBox[{255, 182}], 
         LineBox[{256, 183}], 
         LineBox[{257, 184}], 
         LineBox[{258, 185}], 
         LineBox[{259, 186}], 
         LineBox[{260, 187}], 
         LineBox[{261, 188}], 
         LineBox[{262, 189}], 
         LineBox[{263, 190}], 
         LineBox[{264, 191}], 
         LineBox[{265, 192}], 
         LineBox[{266, 193}], 
         LineBox[{267, 194}], 
         LineBox[{268, 195}], 
         LineBox[{269, 196}], 
         LineBox[{270, 197}]}}, {{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.9, 0.36, 0.054], 
          CapForm["Butt"], 
          AbsoluteThickness[1.6]], 
         PointBox[CompressedData["
1:eJwV0VVWVQEAQNH7EJgHU3IIDAAmwAxIpRsJUaS7G6QUJSSku7t787HXOv8n
Kjr2Y0woCII44kUCiSSRTAqf+EwqaaSTQSZZZJNDLnnkU0AhRXyhmBJKKeMr
5XzjOxX8oJIqqqmhljrqaaCRJpppoZU22umgky666aGXPvoZYJAhhvnJCKOM
Mc4Ev/jNJH/4yxTTzDDLP+aYZ4FF/rPEMiusssY6G2yyxTY77LLHPgcccsQx
J5xyxjkXXHLFNTfccsc9DzzyxDMvvL6PDQuCEGF8IJwIInkDhD1c0Q==
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.365248, 0.427802, 0.758297], 
          CapForm["Butt"], 
          AbsoluteThickness[1.6]], 
         PointBox[{519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530,
           531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 
          544, 545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 
          557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 
          570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 
          583, 584, 585, 586, 587, 588, 589, 590, 591}]}, {}}}], {}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 124.}, {0, 242.}}, DisplayFunction -> Identity, 
     AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox["\"Func Calls\"", TraditionalForm], None}, {None, None}}, 
     FrameStyle -> Automatic, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {{0}, {0}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], LabelStyle -> {FontFamily -> "Times"}, 
     Method -> {}, PlotLabel -> 
     FormBox["\"Comparing Built-in to User-definied Function Calls\"", 
       TraditionalForm], PlotRange -> {{0, 124.}, {0, 242.}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"Builtin\"", "\"Defined\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.33000000000000007`], 
                    RGBColor[0.9, 0.36, 0.054], 
                    CapForm["Butt"], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.33000000000000007`], 
                    RGBColor[0.9, 0.36, 0.054], 
                    CapForm["Butt"], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.33000000000000007`], 
                    RGBColor[0.365248, 0.427802, 0.758297], 
                    CapForm["Butt"], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.33000000000000007`], 
                    RGBColor[0.365248, 0.427802, 0.758297], 
                    CapForm["Butt"], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times", FontFamily -> "Arial"}, Background -> 
         Automatic, StripOnInput -> False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.9, 0.36, 0.054], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6000000000000001, 0.24, 0.036000000000000004`],
                     FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.9, 0.36, 0.054]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.9, 0.36, 0.054]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.9, 0.36, 0.054], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"CapForm", "[", "\"Butt\"", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.365248, 0.427802, 0.758297], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2434986666666667, 0.28520133333333336`, 
                    0.5055313333333333], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.365248, 0.427802, 0.758297]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.365248, 0.427802, 0.758297]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.365248, 0.427802, 0.758297], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"CapForm", "[", "\"Butt\"", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6490070188836875`*^9, 3.649007067927788*^9, {3.649007159789974*^9, 
   3.649007171123996*^9}, 3.649007236683132*^9, 3.649007282296234*^9, {
   3.6490073307773333`*^9, 3.6490073557343855`*^9}, {3.6490088482784843`*^9, 
   3.649008868374518*^9}, 3.649010405864788*^9, 3.6490659636983805`*^9, 
   3.649090682279443*^9, 3.6491066186436443`*^9, {3.649106776284939*^9, 
   3.6491068302810345`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Built", "-", 
    RowBox[{
    "in", " ", "function", " ", "calls", " ", "where", " ", "percentage", " ",
      "of", " ", "calls", " ", "greater", " ", "than", " ", "1", "%", " ", 
     "of", " ", "total", " ", "calls"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"N", "@", 
         RowBox[{"Round", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"#", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}], 
            RowBox[{"Total", "@", 
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}]}]], ",", 
           RowBox[{"10", "^", 
            RowBox[{"-", "3"}]}]}], " ", "]"}]}]}], "}"}], "]"}], "&"}], "@", 
    "userDS"}], "//", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{"#", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", "_", ",", "z_"}], "}"}], "/;", 
       RowBox[{"z", "<", " ", "0.01"}]}]}], "]"}], "&"}]}]}]], "Input",
 CellChangeTimes->{{3.649005271012824*^9, 3.6490053079468856`*^9}, {
  3.64900534978095*^9, 3.6490053655379744`*^9}, {3.6490054040350323`*^9, 
  3.6490055901054296`*^9}, {3.649005683232895*^9, 3.649005806848089*^9}, {
  3.6490058756952*^9, 3.6490058778352027`*^9}, {3.649005930464286*^9, 
  3.6490059316202884`*^9}, {3.649006138593752*^9, 3.649006143083761*^9}, {
  3.6490069689445853`*^9, 3.6490069717225904`*^9}, {3.6490704769260554`*^9, 
  3.649070512100109*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"In\"\>", ",", "242", ",", "0.111`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Date\"\>", ",", "237", ",", "0.109`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Range\"\>", ",", "128", ",", "0.059`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Get\"\>", ",", "72", ",", "0.033`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"All\"\>", ",", "64", ",", "0.029`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Or\"\>", ",", "53", ",", "0.024`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Map\"\>", ",", "52", ",", "0.024`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Select\"\>", ",", "49", ",", "0.022`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Length\"\>", ",", "49", ",", "0.022`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Path\"\>", ",", "48", ",", "0.022`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Product\"\>", ",", "46", ",", "0.021`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Block\"\>", ",", "45", ",", "0.021`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"First\"\>", ",", "39", ",", "0.018`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Max\"\>", ",", "37", ",", "0.017`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"List\"\>", ",", "37", ",", "0.017`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"And\"\>", ",", "37", ",", "0.017`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Re\"\>", ",", "36", ",", "0.017`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Value\"\>", ",", "34", ",", "0.016`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Rule\"\>", ",", "34", ",", "0.016`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"If\"\>", ",", "32", ",", "0.015`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Min\"\>", ",", "31", ",", "0.014`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Im\"\>", ",", "31", ",", "0.014`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Short\"\>", ",", "30", ",", "0.014`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Dataset\"\>", ",", "29", ",", "0.013`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Total\"\>", ",", "26", ",", "0.012`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Style\"\>", ",", "25", ",", "0.011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Font\"\>", ",", "25", ",", "0.011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tr\"\>", ",", "24", ",", "0.011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Nor\"\>", ",", "23", ",", "0.011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Plus\"\>", ",", "22", ",", "0.01`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ToString\"\>", ",", "21", ",", "0.01`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6490053087568865`*^9, {3.649005351395953*^9, 3.649005366117975*^9}, {
   3.6490054192380548`*^9, 3.649005436982127*^9}, 3.6490055069773035`*^9, 
   3.6490055483823647`*^9, 3.6490055912254314`*^9, {3.6490056843428965`*^9, 
   3.64900570607893*^9}, 3.649005737332983*^9, {3.6490057843930545`*^9, 
   3.6490058078180904`*^9}, 3.649005878705204*^9, 3.6490059321802893`*^9, 
   3.6490069723425913`*^9, {3.6490088483184843`*^9, 3.6490088684145184`*^9}, 
   3.649010405904788*^9, 3.6490659637139807`*^9, 3.6490906822994423`*^9, 
   3.649106619033645*^9, {3.6491067765033393`*^9, 3.649106830312235*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Highlight Function Locations", "Section",
 CellChangeTimes->{{3.6490907143254924`*^9, 3.6490907207935023`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TextCell", "@", 
    RowBox[{"StringSplit", "[", 
     RowBox[{
      RowBox[{"LoadText", "[", "]"}], ",", 
      RowBox[{"WhitespaceCharacter", "|", 
       RowBox[{"Alternatives", "@@", 
        RowBox[{"Characters", "@", "\"\<{}[]<>():=\>\""}]}]}]}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x_", "/;", 
       RowBox[{"MemberQ", "[", 
        RowBox[{"$UserFunc", ",", "x"}], "]"}]}], "\[RuleDelayed]", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", "Blue"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"y_", "/;", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"SysFunc", "[", "]"}], ",", "y"}], "]"}]}], "\[RuleDelayed]", 
      RowBox[{"Style", "[", 
       RowBox[{"y", ",", "Red"}], "]"}]}], ",", 
     RowBox[{"\"\<\>\"", "\[Rule]", 
      RowBox[{"Sequence", "[", "]"}]}]}], "}"}]}], "/.", 
  RowBox[{
   RowBox[{"x_", "/;", 
    RowBox[{"Not", "@", 
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"$UserFunc", "~", "Join", "~", 
        RowBox[{"SysFunc", "[", "]"}]}], ",", "x"}], "]"}]}]}], 
   "\[RuleDelayed]", 
   RowBox[{"Style", "[", 
    RowBox[{"x", ",", 
     RowBox[{"GrayLevel", "[", "0.8", "]"}], ",", 
     RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.649090726478511*^9, 3.6490908407766857`*^9}, {
  3.649093343883117*^9, 3.6490933461531205`*^9}, {3.649093403410201*^9, 
  3.6490935085553513`*^9}}],

Cell[BoxData[
 StyleBox[
  InterpretationBox[Cell[BoxData[
    RowBox[{"{", 
     RowBox[{"\<\"*\"\>", ",", "\<\"Wolfram\"\>", ",", 
      StyleBox["\<\"Language\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Raw\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Program\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"SetupModel\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", 
      ",", "\<\"dataLink\"\>", ",", "\<\"\\\"https\"\>", 
      ",", "\<\"//docs.google.com/spreadsheet/ccc?key\"\>", 
      ",", "\<\"1MZ5Xc_RydlgQrwsRCp6BStHcrrs553Dg6k4TSHWRm3Y&output\"\>", 
      ",", "\<\"ods\\\";\"\>", ",", "\<\"Dataset`$ElisionThreshold\"\>", 
      ",", "\<\"256;\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"importedData_List\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"totalColumns\"\>", 
      ",", "\<\",\"\>", ",", "\<\"*\"\>", ",", "\<\"Assume\"\>", 
      ",", "\<\"the\"\>", ",", "\<\"first\"\>", ",", "\<\"row\"\>", 
      ",", "\<\"is\"\>", ",", "\<\"a\"\>", ",", "\<\"contiguous\"\>", 
      ",", "\<\"header\"\>", ",", "\<\"*\"\>", ",", "\<\"totalColumns\"\>", 
      ",", 
      StyleBox["\<\"FirstPosition\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"importedData\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"\\\"\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Head\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"totalColumns\"\>", 
      ",", "\<\"Missing,\"\>", ",", "\<\"totalColumns\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"importedData\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"totalColumns\"\>", 
      ",", "\<\"totalColumns\"\>", ",", "\<\"1\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociationThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"importedData\"\>", 
      ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"totalColumns\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"PadRight\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"totalColumns\"\>", ",", "\<\",\"\>", 
      ",", "\<\"totalColumns,\"\>", ",", "\<\"\\\"\\\"\"\>", 
      ",", "\<\"&,\"\>", ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"importedData\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";;\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"\\\",\"\>", ",", "\<\"\\\"\\\",\"\>", 
      ",", "\<\"\\\"\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"RefreshModel\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"StartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"Inventory\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"DailyProductionSchedule\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"DailyProductionSchedule\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"TransportPool\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"VoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"VoyageCommit\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Parameters\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"Parameters\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"MarketSales\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"MarketSales\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"volumePerUnit\"\>", ",", 
      StyleBox["\<\"Parameters\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#ParameterName\"\>", 
      ",", "\<\"\\\"BarrelsPerUnit\\\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ParameterValue\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"VoyageRules\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Location\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"Location\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Products\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"Product\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"DailyConsumptionSchedule\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"DailyConsumptionSchedule\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"MarketPrice\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"MarketPrice\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"InventoryThreshold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AssociateListImport\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Import\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dataLink,\"\>", 
      ",", "\<\"\\\"ODS\\\",\"\>", ",", "\<\"\\\"Sheets\\\",\"\>", 
      ",", "\<\"\\\"InventoryThreshold\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"workingCapitalCharge\"\>", ",", "\<\"0.06;\"\>", ",", 
      StyleBox["\<\"GetStartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"StartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"date\"\>", ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Inventory\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetDailyProduction\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"DailyProductionSchedule\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"date\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>",
       ",", "\<\"locationID&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductionVolume\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetDailyConsumption\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"DailyConsumptionSchedule\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"date\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>",
       ",", "\<\"locationID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductionVolume\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"Values\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AbsoluteTime\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#ReturnToService\"\>", ",", 
      StyleBox["\<\"AbsoluteTime\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"&&\"\>", ",", 
      StyleBox["\<\"AbsoluteTime\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#ReturnToService\"\>", ",", 
      StyleBox["\<\"AbsoluteTime\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\"&&\"\>", ",", "\<\"#DeliveryLocationID\"\>",
       ",", "\<\"locationID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"EquipmentID\\\",\"\>", 
      ",", "\<\"\\\"ReturnToService\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetVesselCapacity\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vesselID_\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"vesselID&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"PhysicalCapacity\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetMarketSales\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"lmdm_\"\>", ",", 
      StyleBox["\<\"With\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"s\"\>", ",", "\<\"lmdm\"\>", 
      ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"date\"\>", ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"SoldToMarket\\\"\"\>", ",", "\<\"*MarketSales\"\>", ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#Date\"\>", 
      ",", "\<\"date\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Units\\\"\"\>", ",", "\<\"*\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Head\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"s\"\>", ",", 
      StyleBox["\<\"Missing\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"s\"\>", ",", "\<\"*\"\>", ",", "\<\"volumePerUnit\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetMarketPurchases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"smdm_\"\>", ",", 
      StyleBox["\<\"With\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"s\"\>", ",", "\<\"smdm\"\>", 
      ",", 
      StyleBox["\<\"SelectFirst\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"date\"\>", ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"PurchasedFromMarket\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Head\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"s\"\>", ",", 
      StyleBox["\<\"Missing\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"s\"\>", ",", "\<\"*\"\>", ",", "\<\"volumePerUnit\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateAmountShipped\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"vesselFill_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"NumberForm\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"PhysicalCapacity\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"*\"\>", ",", "\<\"vesselFill,\"\>", ",", "\<\"40,\"\>", 
      ",", "\<\"0\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DigitBlock\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"3,\"\>", 
      ",", 
      StyleBox["\<\"NumberPoint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"\\\"\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"PhysicalCapacity\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"*\"\>", ",", "\<\"vesselFill\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"SingleVesselVDM\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"locationID_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"vesselName_,\"\>", 
      ",", "\<\"vesselShippingDate_,\"\>", ",", "\<\"vesselFill_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"periodRange\"\>", 
      ",", "\<\",\"\>", ",", "\<\"periodRange\"\>", ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Tuples\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselName\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"periodRange,\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDate\"\>", 
      ",", "\<\",\"\>", ",", "\<\"locationID\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"-\\\"\"\>", 
      ",", "\<\",\"\>", ",", "\<\"0\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Head\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDate\"\>", ",", 
      StyleBox["\<\"Symbol\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"||\"\>", 
      ",", "\<\"vesselShippingDate\"\>", ",", "\<\",\"\>", ",", "\<\",\"\>", 
      ",", "\<\"vesselName,\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDate\"\>", 
      ",", "\<\",\"\>", ",", "\<\"locationID,\"\>", ",", "\<\"productID,\"\>",
       ",", "\<\"shortLocation,\"\>", ",", 
      StyleBox["\<\"CalculateAmountShipped\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vesselName,\"\>", 
      ",", "\<\"vesselFill\"\>", ",", "\<\",\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"2\"\>", ",", "\<\"#2\"\>", 
      ",", "\<\"2\"\>", ",", "\<\"&\"\>", ",", "\<\";\"\>", 
      ",", "\<\"*GenerateVoyageDecisionMatrix\"\>", 
      ",", "\<\"timeWindow_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"shortLocation_,productID_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"voyageMap,\"\>", 
      ",", "\<\"voyageRules\"\>", ",", "\<\",\"\>", ",", "\<\"*Remove\"\>", 
      ",", "\<\"the\"\>", ",", "\<\"hardcoding\"\>", ",", "\<\"when\"\>", 
      ",", "\<\"we\"\>", ",", "\<\"figure\"\>", ",", "\<\"out\"\>", 
      ",", "\<\"how\"\>", ",", "\<\"to\"\>", ",", "\<\"dynamically\"\>", 
      ",", "\<\"create\"\>", ",", "\<\"variables*\"\>", 
      ",", "\<\"vesselName1\"\>", ",", "\<\"\\\"ATL\\\";\"\>", 
      ",", "\<\"vesselName2\"\>", ",", "\<\"\\\"EVE\\\";\"\>", 
      ",", "\<\"voyageMap\"\>", ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"SingleVesselVDM\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"locationID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,vesselName1,\"\>", 
      ",", "\<\"vesselShippingDate1,\"\>", ",", "\<\"vesselFill1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"SingleVesselVDM\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"locationID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,vesselName2,\"\>", 
      ",", "\<\"vesselShippingDate2,\"\>", ",", "\<\"vesselFill2\"\>", 
      ",", "\<\";\"\>", ",", "\<\"voyageRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"Sent\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"5\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"6\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageMap\"\>", ",", "\<\";\"\>", 
      ",", "\<\"Dataset`$ElisionThreshold\"\>", ",", "\<\"128;\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageRules\"\>", ",", "\<\";*\"\>", ",", 
      StyleBox["\<\"GenerateVoyageDecisionMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"productID_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"voyageMap,\"\>", 
      ",", "\<\"voyageRules\"\>", ",", "\<\",\"\>", ",", "\<\"voyageMap\"\>", 
      ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"SingleVesselVDM\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"#3\"\>", ",", "\<\"/.\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"#1,\"\>", ",", "\<\"#2\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"shippingDateVars,\"\>", 
      ",", "\<\"fillVars,\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shippingDateVars\"\>", 
      ",", "\<\",\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"voyageRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"Sent\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"5\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"6\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageMap\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageRules\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateLongMarketDecisionMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"locationID_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"dateRange_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"marketData,\"\>", 
      ",", "\<\"marketRules\"\>", ",", "\<\",\"\>", ",", "\<\"marketData\"\>",
       ",", "\<\"locationID,\"\>", ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", 
      StyleBox["\<\"Round\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"NumberQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueLong\\\"\"\>", 
      ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>",
       ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueLong\\\"\"\>", 
      ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>",
       ",", "\<\"0\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"dateRange;\"\>", ",", "\<\"marketRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"ProductID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"SoldToMarket\\\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\"&,\"\>", ",", "\<\"marketData\"\>", 
      ",", "\<\";\"\>", ",", "\<\"Dataset`$ElisionThreshold\"\>", 
      ",", "\<\"192;\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"marketRules\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateShortMarketDecisionMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"locationID_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"dateRange_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"marketData,\"\>", 
      ",", "\<\"marketRules\"\>", ",", "\<\",\"\>", ",", "\<\"marketData\"\>",
       ",", "\<\"locationID,\"\>", ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", 
      StyleBox["\<\"Round\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"NumberQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueShort\\\"\"\>",
       ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>",
       ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueShort\\\"\"\>",
       ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>",
       ",", "\<\"0\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"dateRange;\"\>", ",", "\<\"marketRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"ProductID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"PurchasedFromMarket\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"4\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"marketData\"\>", ",", "\<\";\"\>", 
      ",", "\<\"Dataset`$ElisionThreshold\"\>", ",", "\<\"128;\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"marketRules\"\>", ",", "\<\";\"\>", 
      ",", "\<\"*GenerateVoyageDecisionMatrix\"\>", 
      ",", "\<\"timeWindow_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"productID_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivals,\"\>", 
      ",", "\<\"voyageMap,\"\>", ",", "\<\"voyageRules\"\>", ",", "\<\",\"\>",
       ",", "\<\"vesselArrivals\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\";\"\>", ",", "\<\"voyageMap\"\>", 
      ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Tuples\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"locationID\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\",\"\>", ",", "\<\"0\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"vesselArrivals\"\>", ",", "\<\",\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", "\<\"voyageRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"Sent\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"5\"\>", ",", "\<\"&,\"\>",
       ",", "\<\"voyageMap\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageRules\"\>", ",", "\<\";*\"\>", ",", 
      StyleBox["\<\"GenerateDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"decisionMatrix_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"productID,\"\>", 
      ",", "\<\"locationID,\"\>", ",", "\<\"shipments,\"\>", 
      ",", "\<\"shipped,\"\>", ",", "\<\"departingVolume\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Clear\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"GetDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"_,_,_\"\>", ",", "\<\"0;\"\>",
       ",", "\<\"*\"\>", ",", "\<\"Make\"\>", ",", "\<\"zero\"\>", 
      ",", "\<\"the\"\>", ",", "\<\"default\"\>", ",", "\<\"*\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\"decisionMatrix\"\>", 
      ",", "\<\"1,\\\"ProductID\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"decisionMatrix\"\>", 
      ",", "\<\"1,\\\"LocationID\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shipments\"\>", ",", "\<\"decisionMatrix\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Sent\"\>", ",", "\<\"!\"\>", 
      ",", "\<\"\\\"-\\\"&\"\>", ",", "\<\";\"\>", ",", "\<\"*shipped\"\>", 
      ",", "\<\"shipments\"\>", ",", "\<\"All,\"\>", ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#,\"\>", 
      ",", "\<\"\\\"Shipped\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"GetVesselCapacity\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"&\"\>", ",", "\<\";*\"\>", ",", "\<\"*\"\>", 
      ",", "\<\"@TODO\"\>", ",", "\<\"The\"\>", ",", "\<\"calculation\"\>", 
      ",", "\<\"below\"\>", ",", "\<\"could\"\>", ",", "\<\"probably\"\>", 
      ",", "\<\"be\"\>", ",", "\<\"made\"\>", ",", "\<\"more\"\>", 
      ",", "\<\"efficient\"\>", ",", "\<\"*\"\>", 
      ",", "\<\"departingVolume\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Date\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"\\\"Shipped\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"2\"\>", ",", "\<\"&,\"\>",
       ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipments\"\>", ",", 
      StyleBox["\<\"GroupBy\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Date\\\"\"\>", 
      ",", "\<\",\"\>", ",", "\<\"Total,\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"GetDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Date\\\"\"\>", 
      ",", "\<\"/.\"\>", ",", "\<\"#\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID\"\>", 
      ",", "\<\"\\\"Shipped\\\"\"\>", ",", "\<\"/.\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"departingVolume\"\>", ",", "\<\";\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetRecievingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"svdm_\"\>", ",", "\<\"svdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"date\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#ProductID\"\>", ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationID\"\>", ",", "\<\"locationID\"\>", ",", "\<\"&\"\>",
       ",", "\<\"Total,\"\>", ",", "\<\"\\\"AmountRecieved\\\"\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#DeliveryLocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#ReturnToService\"\>", ",", "\<\"date\"\>", ",", "\<\"&\"\>", 
      ",", "\<\",\"\>", ",", "\<\"\\\"Volume\\\"\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"0,\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#DeliveryLocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#ReturnToService\"\>", ",", "\<\"date\"\>", ",", "\<\"&\"\>", 
      ",", "\<\",\"\>", ",", "\<\"\\\"Volume\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryLong\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"longLocation_,\"\>", 
      ",", "\<\"lmdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange,\"\>", 
      ",", "\<\"startingInventory\"\>", ",", "\<\",\"\>", 
      ",", "\<\"startingInventory\"\>", ",", 
      StyleBox["\<\"GetStartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", ",", "\<\"dayRange\"\>", 
      ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"FoldList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"+\"\>", 
      ",", 
      StyleBox["\<\"GetDailyProduction\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"GetDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"GetMarketSales\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"lmdm\"\>", ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"startingInventory,\"\>", 
      ",", "\<\"dayRange\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryShort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"svdm_,\"\>", ",", "\<\"smdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"startingInventory,\"\>", 
      ",", "\<\"dayRange\"\>", ",", "\<\",\"\>", 
      ",", "\<\"startingInventory\"\>", ",", 
      StyleBox["\<\"GetStartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\";\"\>", ",", "\<\"dayRange\"\>",
       ",", 
      StyleBox["\<\"Union\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"svdm\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"FoldList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"-\"\>", 
      ",", 
      StyleBox["\<\"GetDailyConsumption\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetRecievingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetMarketPurchases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"smdm\"\>", ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"startingInventory,\"\>", 
      ",", "\<\"dayRange\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateTranportCostPerVessel\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"locationFrom_,\"\>", ",", "\<\"locationTo_,\"\>", 
      ",", "\<\"vdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipmentDaysInfo,\"\>", 
      ",", "\<\"vesselDetails,\"\>", ",", "\<\"totalVoyageDays\"\>", 
      ",", "\<\",\"\>", ",", "\<\"shipmentDaysInfo\"\>", ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", 
      ",", "\<\"locationFrom\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationTo\"\>", ",", "\<\"locationTo\"\>", ",", "\<\"&\"\>",
       ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", "\<\"vesselDetails\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";\"\>", ",", "\<\"totalVoyageDays\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipmentDaysInfo\"\>", 
      ",", "\<\"\\\"DaysLoading\\\",\"\>", 
      ",", "\<\"\\\"DaysUnderway\\\",\"\>", ",", "\<\"\\\"DockWait\\\",\"\>", 
      ",", "\<\"\\\"DaysUnloading\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"FindVesselFill\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID,\"\>", 
      ",", "\<\"vdm\"\>", ",", "\<\"0,\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"vesselDetails\"\>", ",", "\<\"\\\"CharterRatePerDay\\\"\"\>", 
      ",", "\<\"*\"\>", ",", "\<\"totalVoyageDays\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"vesselDetails\"\>", ",", "\<\"\\\"FuelChgPerDay\\\"\"\>", 
      ",", "\<\"*\"\>", ",", "\<\"shipmentDaysInfo\"\>", 
      ",", "\<\"\\\"DaysUnderway\\\"\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"vesselDetails\"\>", ",", "\<\"\\\"CleaningRate\\\"\"\>", 
      ",", "\<\"+\"\>", ",", "\<\"vesselDetails\"\>", 
      ",", "\<\"\\\"HeatingCharge\\\"\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"vesselDetails\"\>", ",", "\<\"\\\"TankerManPortFee\\\"\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateTransportCost\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"decisionMatrix_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipments\"\>", 
      ",", "\<\",\"\>", ",", "\<\"shipments\"\>", 
      ",", "\<\"decisionMatrix\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Sent\"\>", ",", "\<\"!\"\>", 
      ",", "\<\"\\\"-\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shipments\"\>", ",", "\<\"All,\"\>", ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#,\"\>", 
      ",", "\<\"\\\"TransportCost\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"CalculateTranportCostPerVessel\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#EquipmentID,\"\>", 
      ",", "\<\"#LocationID,\"\>", ",", "\<\"#Sent,\"\>", 
      ",", "\<\"decisionMatrix\"\>", ",", "\<\"*NumberForm\"\>", ",", 
      StyleBox["\<\"CalculateTranportCostPerVessel\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#EquipmentID,\"\>", 
      ",", "\<\"#LocationID,\"\>", ",", "\<\"#Sent\"\>", ",", "\<\",\"\>", 
      ",", "\<\"40,\"\>", ",", "\<\"0\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DigitBlock\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"3,\"\>", 
      ",", 
      StyleBox["\<\"NumberPoint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"\\\"\"\>", ",", "\<\"*\"\>", ",", "\<\"&\"\>", 
      ",", "\<\";\"\>", ",", "\<\"*GUI*\"\>", ",", 
      StyleBox["\<\"ProductID\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"PopupMenu\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"productID\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Products\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Product\"\>", 
      ",", "\<\"ID\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"LongLocation\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"PopupMenu\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longLocation\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Location\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"LocationID\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Long\"\>", 
      ",", "\<\"Location\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"ShortLocation\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"PopupMenu\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Location\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"LocationID\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Short\"\>", 
      ",", "\<\"Location\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"TimeWindow\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Row\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"InputField\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", "\<\"String,\"\>", ",", 
      StyleBox["\<\"FieldHint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Format\"\>", ",", "\<\"05/01/2015\\\",\"\>", ",", 
      StyleBox["\<\"ImageSize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"140\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"\"\>", ",", "\<\"to\"\>", 
      ",", "\<\"\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"InputField\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"String,\"\>", ",", 
      StyleBox["\<\"FieldHint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Format\"\>", ",", "\<\"05/01/2015\\\",\"\>", ",", 
      StyleBox["\<\"ImageSize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"140\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Time\"\>", 
      ",", "\<\"Window\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"dateString_\"\>", ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateString,\"\>", 
      ",", "\<\"\\\"Month\\\",\"\>", ",", "\<\"\\\"Day\\\",\"\>", 
      ",", "\<\"\\\"YearShort\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"*Vessel1ShippingControls\"\>", ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Column\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"RadioButtonBar\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDate1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Day\"\>", 
      ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Slider\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselFill1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Vessel\"\>", 
      ",", "\<\"1\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", 
      ",", "\<\"Vessel2ShippingControls\"\>", ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Column\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"RadioButtonBar\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDate2\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Day\"\>", 
      ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Slider\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselFill2\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Vessel\"\>", 
      ",", "\<\"2\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";*\"\>", ",", 
      StyleBox["\<\"VesselShippingControls\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"vesselArrivalDates\"\>", ",", "\<\",\"\>", 
      ",", "\<\"vesselArrivalDates\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"&,\"\>", ",", "\<\"vesselArrivalDates\"\>",
       ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shippingDateVars\"\>", ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], 
      ",", "\<\"\\\"vesselShippingDate\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"fillVars\"\>", ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"vesselFill\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Column\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Row\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"RadioButton\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Enabled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"False\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"\"\>", ",", "\<\"Day\"\>",
       ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Spacer\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"13\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\",\"\>", ",", "\<\"#4\"\>", ",", "\<\"1\"\>",
       ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"1,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"-\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"RadioButtonBar\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Day\"\>", 
      ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>", 
      ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\",\"\>", ",", "\<\"#4\"\>", ",", "\<\"1\"\>",
       ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"1,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Slider\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Vessel\"\>", 
      ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#3\"\>", 
      ",", "\<\"\\\"-\\\"\"\>", ",", "\<\"#3\"\>", ",", "\<\"/.\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"&,\"\>", 
      ",", "\<\"shippingDateVars,\"\>", ",", "\<\"fillVars,\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shippingDateVars\"\>", 
      ",", "\<\",\"\>", ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"MarketPerDayLong\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Row\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MapIndexed\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"InputField\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\",\"\>", 
      ",", "\<\"Number,\"\>", ",", 
      StyleBox["\<\"FieldHint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"0\\\",\"\>", ",", 
      StyleBox["\<\"ImageSize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"35\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"\"\>", ",", "\<\"Day\"\>",
       ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"&,\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueLong\\\"\"\>", 
      ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Text\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Sell\"\>", 
      ",", "\<\"To\"\>", ",", "\<\"Market\\\\n\"\>", ",", 
      StyleBox["\<\"Number\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"of\"\>", 
      ",", "\<\"Parcels\"\>", ",", "\<\"\\\",\"\>", ",", 
      StyleBox["\<\"TextAlignment\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"Center,\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"MarketPerDayShort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"lastVessel,\"\>", 
      ",", "\<\"shipmentDaysInfo,\"\>", ",", "\<\"totalVoyageDays\"\>", 
      ",", "\<\",\"\>", ",", "\<\"lastVessel\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shipmentDaysInfo\"\>", ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"lastVessel\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationTo\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"totalVoyageDays\"\>", ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipmentDaysInfo\"\>", 
      ",", "\<\"\\\"DaysLoading\\\",\"\>", 
      ",", "\<\"\\\"DaysUnderway\\\",\"\>", ",", "\<\"\\\"DockWait\\\",\"\>", 
      ",", "\<\"\\\"DaysUnloading\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Row\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MapIndexed\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Labeled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"InputField\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\",\"\>", 
      ",", "\<\"Number,\"\>", ",", 
      StyleBox["\<\"FieldHint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"0\\\",\"\>", ",", 
      StyleBox["\<\"ImageSize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"35\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"\"\>", ",", "\<\"Day\"\>",
       ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",Left\"\>", ",", "\<\"&,\"\>",
       ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueShort\\\"\"\>",
       ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Text\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Purchase\"\>", 
      ",", "\<\"From\"\>", ",", "\<\"Market\"\>", ",", "\<\"\\\\n\"\>", ",", 
      StyleBox["\<\"Number\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"of\"\>", 
      ",", "\<\"Parcels\"\>", ",", "\<\"\\\",\"\>", ",", 
      StyleBox["\<\"TextAlignment\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"Center,\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"SetInitialControls\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", 
      ",", "\<\"lastVessel\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shipmentDaysInfo\"\>", ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"lastVessel\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationTo\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"totalVoyageDays\"\>", ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipmentDaysInfo\"\>", 
      ",", "\<\"\\\"DaysLoading\\\",\"\>", 
      ",", "\<\"\\\"DaysUnderway\\\",\"\>", ",", "\<\"\\\"DockWait\\\",\"\>", 
      ",", "\<\"\\\"DaysUnloading\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"initControls\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Waiting\"\>", 
      ",", "\<\"for\"\>", ",", "\<\"initial\"\>", 
      ",", "\<\"controls\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"16\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"Button\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Set\"\>", 
      ",", "\<\"Initial\"\>", ",", "\<\"Controls\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"16\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Clear\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueLong\\\"\"\>", 
      ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Clear\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"marketValueShort\\\"\"\>",
       ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Clear\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"\\\"vesselShippingDate\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&/@\"\>", 
      ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longLocation\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Clear\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"\\\"vesselFill\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longLocation\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", "\<\"initControls\"\>", ",", 
      StyleBox["\<\"Column\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"*Vessel1ShippingControls\"\>",
       ",", "\<\",\"\>", ",", "\<\"Vessel2ShippingControls\"\>", 
      ",", "\<\",*\"\>", ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VesselShippingControls\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"MarketPerDayLong\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"MarketPerDayShort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Spacings\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Method\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Queued\\\",\"\>", ",", 
      StyleBox["\<\"ImageSize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"150,\"\>", 
      ",", "\<\"35\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Results\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"extendedDateRange\"\>", ",", "\<\",\"\>", 
      ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\";\"\>", ",", "\<\"extendedDateRange\"\>", 
      ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\";\"\>",
       ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"GenerateVoyageDecisionMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"productID\"\>", 
      ",", "\<\";\"\>", ",", "\<\"lmdm\"\>", ",", 
      StyleBox["\<\"GenerateLongMarketDecisionMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"dateRange\"\>", ",", "\<\";\"\>", 
      ",", "\<\"smdm\"\>", ",", 
      StyleBox["\<\"GenerateShortMarketDecisionMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"extendedDateRange\"\>", 
      ",", "\<\";\"\>", ",", "\<\"svdm\"\>", ",", 
      StyleBox["\<\"GenerateShortVoyageDisplayMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"Grid\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm,\"\>", ",", 
      StyleBox["\<\"Column\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"lmdm,\"\>", 
      ",", "\<\"smdm\"\>", ",", "\<\",Alignment-\"\>", 
      ",", "\<\"Left,Top\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"SetAndShowResults\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"\\\"PAR\\\";\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\"\\\"NOR\\\";\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\"\\\"LSVGO\\\";\"\>", 
      ",", "\<\"timeWindow1\"\>", ",", "\<\"\\\"05/01/2015\\\";\"\>", 
      ",", "\<\"timeWindow2\"\>", ",", "\<\"\\\"05/10/2015\\\";\"\>", ",", 
      StyleBox["\<\"Grid\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Initial\"\>", 
      ",", "\<\"Controls\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"18,\"\>", ",", 
      StyleBox["\<\"Bold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"ProductID\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"LongLocation\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"ShortLocation\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"TimeWindow\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"SetInitialControls\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Secondary\"\>", 
      ",", "\<\"Controls\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"18,\"\>", ",", 
      StyleBox["\<\"Bold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"initControls\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Results\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"18,\"\>", ",", 
      StyleBox["\<\"Bold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Evaluate\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Dynamic\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"initControls\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Waiting\"\>", 
      ",", "\<\"for\"\>", ",", "\<\"initial\"\>", 
      ",", "\<\"controls\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"16\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Waiting\"\>", 
      ",", "\<\"for\"\>", ",", "\<\"input\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", "\<\"16\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Results\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Alignment\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"Left,\"\>", 
      ",", 
      StyleBox["\<\"Top\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Spacings\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\",\"\>", 
      ",", "\<\"0,\"\>", ",", "\<\"1,\"\>", ",", "\<\"1,\"\>", 
      ",", "\<\"1,\"\>", ",", "\<\"1,\"\>", ",", "\<\"1,\"\>", 
      ",", "\<\"3\"\>", ",", "\<\"*End\"\>", ",", "\<\"of\"\>", 
      ",", "\<\"inital\"\>", ",", "\<\"controls*\"\>", ",", "\<\",\"\>", 
      ",", "\<\"2,\"\>", ",", "\<\"3,\"\>", ",", "\<\"2\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Dividers\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\",\"\>", 
      ",", "\<\"7\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Darker\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Gray,\"\>", ",", "\<\".4\"\>",
       ",", "\<\",\"\>", ",", "\<\"-3\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Darker\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Gray,\"\>", ",", "\<\".4\"\>",
       ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateShortVoyageDisplayMatrix\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselsUnordered,\"\>", 
      ",", "\<\"vessels,\"\>", ",", "\<\"shipmentDaysInfo,\"\>", 
      ",", "\<\"totalVoyageDaysPerVessel,\"\>", ",", "\<\"arrivalDates,\"\>", 
      ",", "\<\"dateRange,\"\>", ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"periodRange\"\>", ",", "\<\",\"\>", 
      ",", "\<\"vesselsUnordered\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Sent\"\>", ",", "\<\"!\"\>", 
      ",", "\<\"\\\"-\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"|\\\"EquipmentID\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#,\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"\\\"LocationID\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"\\\"ProductID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"\\\"Sent\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"\\\"AmountShipped\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"0|\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Complement\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Sent\"\>", ",", "\<\"!\"\>", 
      ",", "\<\"\\\"-\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vessels\"\>", ",", "\<\"vesselsUnordered\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselsUnordered\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"/.\"\>", ",", 
      StyleBox["\<\"Reverse\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shipmentDaysInfo\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"vessels\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", ",", "\<\"vessels\"\>",
       ",", "\<\"i,\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationTo\"\>", ",", "\<\"vessels\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"\\\"Sent\\\"\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vessels\"\>", 
      ",", "\<\";\"\>", ",", "\<\"totalVoyageDaysPerVessel\"\>", ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", 
      ",", "\<\"\\\"DaysLoading\\\",\"\>", 
      ",", "\<\"\\\"DaysUnderway\\\",\"\>", ",", "\<\"\\\"DockWait\\\",\"\>", 
      ",", "\<\"\\\"DaysUnloading\\\"\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"shipmentDaysInfo\"\>", ",", "\<\";\"\>", 
      ",", "\<\"arrivalDates\"\>", ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"MapIndexed\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#1\"\>", ",", "\<\"\\\"EquipmentID\\\"\"\>",
       ",", "\<\",\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"totalVoyageDaysPerVessel\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountRecieved\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"\\\"AmountShipped\\\"\"\>", 
      ",", "\<\"&,\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vessels\"\>", 
      ",", "\<\";\"\>", ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", 
      ",", "\<\"Last,\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Max\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"totalVoyageDaysPerVessel\"\>",
       ",", "\<\";\"\>", ",", "\<\"timeWindow\"\>", ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\";\"\>", ",", "\<\"periodRange\"\>", ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountRecieved\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"5\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>",
       ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Tuples\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", 
      ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"periodRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\",\"\>", ",", "\<\"0\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Head\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"Symbol,\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"AmountRecieved\\\"\"\>", 
      ",", "\<\",\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"arrivalDates,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"RecievedInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"svdm_\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"svdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountRecieved\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"ShippedInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"vdm_\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\",\"\>", ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"ToExpression\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MarketPrice\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>",
       ",", "\<\"productID\"\>", ",", "\<\"&&\"\>", ",", "\<\"#Date\"\>", 
      ",", "\<\"dateRange\"\>", ",", "\<\"i\"\>", ",", "\<\"&\"\>", 
      ",", "\<\",\"\>", ",", "\<\"\\\"DeliveredPrice\\\"\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateSpreadValue\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"longLocation_,\"\>", 
      ",", "\<\"shortLocation_,\"\>", ",", "\<\"vesselOrder_,\"\>", 
      ",", "\<\"totalVoyageDays_,\"\>", ",", "\<\"vdm_,\"\>", 
      ",", "\<\"svdm_\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"RecievedInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"svdm\"\>", 
      ",", "\<\".FindMarketPrices\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", 
      ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"ShippedInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"vdm\"\>", 
      ",", "\<\".FindMarketPrices\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\"All,\"\>", ",", "\<\"2\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateIntransitInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"vesselOrder_,\"\>", ",", "\<\"totalVoyageDays_,\"\>", 
      ",", "\<\"vdm_,\"\>", ",", "\<\"svdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange,\"\>", 
      ",", "\<\"startingIntransitInventory,\"\>", ",", "\<\"shipped,\"\>", 
      ",", "\<\"recieved,\"\>", ",", "\<\"shippedPadded\"\>", 
      ",", "\<\",\"\>", ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", 
      ",", "\<\";\"\>", ",", "\<\"startingIntransitInventory\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"dayRange\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\";\"\>", ",", "\<\"shipped\"\>", 
      ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Plus,\"\>", ",", 
      StyleBox["\<\"ShippedInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"vdm\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"recieved\"\>", ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Plus,\"\>", ",", 
      StyleBox["\<\"RecievedInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"svdm\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shippedPadded\"\>", ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipped,\"\>", ",", 
      StyleBox["\<\"ConstantArray\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"0,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"recieved\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shipped\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"FoldList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"shippedPadded\"\>", ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange,\"\>", 
      ",", "\<\"#2\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"recieved\"\>", ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange,\"\>", 
      ",", "\<\"#2\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"startingIntransitInventory,\"\>", 
      ",", "\<\"dayRange\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateWorkingCapitalCost\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"longLocation_,\"\>", 
      ",", "\<\"shortLocation_,\"\>", ",", "\<\"vesselOrder_,\"\>", 
      ",", "\<\"totalVoyageDays_,\"\>", ",", "\<\"vdm_,\"\>", 
      ",", "\<\"svdm_,\"\>", ",", "\<\"lmdm_,\"\>", ",", "\<\"smdm_\"\>", 
      ",", "\<\"workingCapitalCharge\"\>", ",", "\<\"/\"\>", 
      ",", "\<\"365\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\".\"\>", ",", 
      StyleBox["\<\"Drop\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateNetInventoryLong\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"lmdm\"\>", ",", "\<\",\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"+\"\>", ",", "\<\"workingCapitalCharge\"\>", ",", "\<\"/\"\>",
       ",", "\<\"365\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", 
      ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\".\"\>", ",", 
      StyleBox["\<\"Drop\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateNetInventoryShort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"svdm,\"\>", 
      ",", "\<\"smdm\"\>", ",", "\<\",\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"+\"\>", ",", "\<\"workingCapitalCharge\"\>", ",", "\<\"/\"\>",
       ",", "\<\"365\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", 
      ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\".\"\>", ",", 
      StyleBox["\<\"Drop\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateIntransitInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"totalVoyageDays,\"\>", ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\",\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetCharterRate\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"CharterRatePerDay\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"FindVesselFill\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"vdm_\"\>", ",", "\<\"N\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\"/GetVesselCapacity\"\>",
       ",", "\<\"equipmentID\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateSubleasCredit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"locationID_,\"\>", ",", "\<\"shippingDateVars_,\"\>", 
      ",", "\<\"vdm_\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"FindVesselFill\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#1\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", "\<\"vdm\"\>", ",", "\<\"0\"\>", 
      ",", "\<\"&&\"\>", ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"7,\"\>", ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"1\"\>", ",", "\<\"*\"\>",
       ",", 
      StyleBox["\<\"GetCharterRate\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#1\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"#2\"\>", ",", "\<\"1\"\>", ",", "\<\"7,\"\>", ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"#2\"\>", ",", "\<\"1\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"GetCharterRate\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#1\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", "\<\"0\"\>", ",", "\<\"&,\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"locationID\"\>", 
      ",", "\<\",\"\>", ",", "\<\"shippingDateVars\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"ShippedPerDay\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"vdm_\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"RecievedPerDay\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"equipmentID_,\"\>", 
      ",", "\<\"svdm_\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"svdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"equipmentID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountRecieved\\\"\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateInventoryHoldingMargin\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"vdm_,\"\>", 
      ",", "\<\"svdm_,\"\>", ",", "\<\"lmdm_,\"\>", ",", "\<\"smdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventory,\"\>", 
      ",", "\<\"longMarketPrices,\"\>", ",", "\<\"longSoldToMarket,\"\>", 
      ",", "\<\"shortInventory,\"\>", ",", "\<\"shortMarketPrices,\"\>", 
      ",", "\<\"shortPurchasedFromMarket,\"\>", ",", "\<\"dayRange\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longInventory\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryLong\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"lmdm\"\>", ",", "\<\";\"\>", ",", "\<\"longMarketPrices\"\>", 
      ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longSoldToMarket\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"lmdm\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"SoldToMarket\\\"\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortInventory\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryShort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"svdm,\"\>", ",", "\<\"smdm\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shortMarketPrices\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"7\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortPurchasedFromMarket\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"smdm\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"PurchasedFromMarket\\\"\"\>", 
      ",", "\<\";\"\>", ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"7\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ShippedPerDay\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"vdm\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", 
      ",", "\<\"longSoldToMarket,\"\>", 
      ",", "\<\"longSoldToMarket*Parameters\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"ParameterValue\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\".longMarketPrices\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetDailyProduction\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\".longMarketPrices\"\>", ",", "\<\"+\"\>", 
      ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetDailyConsumption\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"dayRange\"\>", 
      ",", "\<\".shortMarketPrices\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"RecievedPerDay\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"svdm\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"dayRange\"\>", 
      ",", "\<\".shortMarketPrices\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"shortPurchasedFromMarket\"\>", ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"Parameters\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"ParameterValue\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\".shortMarketPrices\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"ObjectiveValue\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"longLocation_,\"\>", 
      ",", "\<\"shortLocation_,vdm_,\"\>", ",", "\<\"svdm_,\"\>", 
      ",", "\<\"lmdm_,\"\>", ",", "\<\"smdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"GenerateDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"CalculateSpreadValue\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"totalVoyageDays,\"\>", ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateTransportCost\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm\"\>", ",", "\<\"All,\"\>",
       ",", "\<\"\\\"TransportCost\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"CalculateWorkingCapitalCost\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"totalVoyageDays,\"\>", ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm,\"\>", ",", "\<\"lmdm,\"\>", ",", "\<\"smdm\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"CalculateInventoryHoldingMargin\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"vdm,\"\>", ",", "\<\"svdm,\"\>",
       ",", "\<\"lmdm,\"\>", ",", "\<\"smdm\"\>", ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"CalculateSubleasCredit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shippingDateVars,\"\>", 
      ",", "\<\"vdm\"\>", ",", "\<\";\"\>", ",", "\<\"*PerPath\"\>", 
      ",", "\<\"Functions*\"\>", ",", 
      StyleBox["\<\"AddDayToPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"growingPath_List,\"\>", 
      ",", "\<\"vesselArrivalDays_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"currentDay,\"\>", 
      ",", "\<\"availableVessels,\"\>", ",", "\<\"allOptions\"\>", 
      ",", "\<\",\"\>", ",", "\<\"currentDay\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"growingPath\"\>", 
      ",", "\<\"2\"\>", ",", "\<\"+\"\>", ",", "\<\"1;\"\>", 
      ",", "\<\"availableVessels\"\>", ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"growingPath\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Keys\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDays,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"currentDay\"\>", ",", "\<\"&\"\>", 
      ",", "\<\";\"\>", ",", "\<\"allOptions\"\>", ",", 
      StyleBox["\<\"Subsets\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"availableVessels\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Complement\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"availableVessels,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"growingPath\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"#\"\>", ",", "\<\"&,\"\>",
       ",", "\<\"allOptions\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"AddDayToPaths\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"growingPaths_List,\"\>", 
      ",", "\<\"vesselArrivalDays_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AddDayToPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"vesselArrivalDays\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"growingPaths\"\>", ",", "\<\",\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateAllPaths\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1_,\"\>", 
      ",", "\<\"date2_,\"\>", ",", "\<\"longLocation_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"dayRange,\"\>", ",", "\<\"timePeriodLength,\"\>", 
      ",", "\<\"vesselArrivalDates,\"\>", ",", "\<\"vesselArrivalDays,\"\>", 
      ",", "\<\"vesselArrivalDaysAssociation\"\>", ",", "\<\",\"\>", 
      ",", "\<\"timeWindow\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", "\<\"timePeriodLength\"\>", 
      ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange\"\>", 
      ",", "\<\";\"\>", ",", "\<\"vesselArrivalDates\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"\\\"PAR\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselArrivalDays\"\>", ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", 
      ",", "\<\"3\"\>", ",", "\<\",\"\>", ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2,\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselArrivalDaysAssociation\"\>", ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"vesselArrivalDays\"\>", ",", "\<\"i\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,Length\"\>", 
      ",", "\<\"vesselArrivalDates\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Nest\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"AddDayToPaths\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"vesselArrivalDaysAssociation\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\",\"\>", ",", "\<\",\"\>", ",", "\<\"timePeriodLength\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateVoyageDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"vesselOrder_,\"\>", 
      ",", "\<\"fillVars_,\"\>", ",", "\<\"path_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shippingDateVars,\"\>", 
      ",", "\<\"voyageMap,\"\>", ",", "\<\"voyageRules\"\>", ",", "\<\",\"\>",
       ",", "\<\"shippingDateVars\"\>", ",", 
      StyleBox["\<\"ShippingDateVars\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"path,\"\>", ",", "\<\"vesselOrder\"\>", ",", "\<\";\"\>", 
      ",", "\<\"voyageMap\"\>", ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"SingleVesselVDM\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"#3\"\>", ",", "\<\"/.\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"#1,\"\>", ",", "\<\"#2\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"shippingDateVars,\"\>", ",", 
      StyleBox["\<\"Values\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"fillVars\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shippingDateVars\"\>", 
      ",", "\<\",\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"voyageRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"Sent\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"5\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountShipped\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"6\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageMap\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"voyageRules\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateShortVoyageDisplayMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"longLocation_,\"\>", 
      ",", "\<\"shortLocation_,\"\>", ",", "\<\"vesselArrivalDates_,\"\>", 
      ",", "\<\"vesselOrder_,\"\>", ",", "\<\"vdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselsUnordered,\"\>", 
      ",", "\<\"vessels,\"\>", ",", "\<\"shipmentDaysInfo,\"\>", 
      ",", "\<\"totalVoyageDaysPerVessel,\"\>", ",", "\<\"arrivalDates,\"\>", 
      ",", "\<\"dateRange,\"\>", ",", "\<\"periodRange\"\>", ",", "\<\",\"\>",
       ",", "\<\"vesselsUnordered\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Sent\"\>", ",", "\<\"!\"\>", 
      ",", "\<\"\\\"-\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"|\\\"EquipmentID\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#,\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>",
       ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"\\\"ProductID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"\\\"Sent\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"\\\"AmountShipped\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"0|\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Complement\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Sent\"\>", ",", "\<\"!\"\>", 
      ",", "\<\"\\\"-\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vessels\"\>", ",", "\<\"vesselsUnordered\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselsUnordered\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"/.\"\>", ",", 
      StyleBox["\<\"Reverse\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\";\"\>", 
      ",", "\<\"shipmentDaysInfo\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"vessels\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", ",", "\<\"vessels\"\>",
       ",", "\<\"i,\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationTo\"\>", ",", "\<\"vessels\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"\\\"Sent\\\"\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>", 
      ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vessels\"\>", 
      ",", "\<\";\"\>", ",", "\<\"totalVoyageDaysPerVessel\"\>", ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", 
      ",", "\<\"\\\"DaysLoading\\\",\"\>", 
      ",", "\<\"\\\"DaysUnderway\\\",\"\>", ",", "\<\"\\\"DockWait\\\",\"\>", 
      ",", "\<\"\\\"DaysUnloading\\\"\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"shipmentDaysInfo\"\>", ",", "\<\";\"\>", 
      ",", "\<\"arrivalDates\"\>", ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"MapIndexed\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#1\"\>", ",", "\<\"\\\"EquipmentID\\\"\"\>",
       ",", "\<\",\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"totalVoyageDaysPerVessel\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountRecieved\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"\\\"AmountShipped\\\"\"\>", 
      ",", "\<\"&,\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vessels\"\>", 
      ",", "\<\";\"\>", ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", 
      ",", "\<\"First,\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm\"\>", 
      ",", "\<\"Last,\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"Max\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"totalVoyageDaysPerVessel\"\>",
       ",", "\<\";\"\>", ",", "\<\"periodRange\"\>", ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"EquipmentID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductID\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"4\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"AmountRecieved\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"5\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>",
       ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Tuples\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", 
      ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"periodRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID\"\>", ",", "\<\",\"\>", ",", "\<\"0\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Head\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"Symbol,\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"EquipmentID\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"\\\"AmountRecieved\\\"\"\>", 
      ",", "\<\",\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"arrivalDates,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"InventoryThreshold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"MaxInventory\\\"\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>",
       ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"locationID_\"\>", ",", 
      StyleBox["\<\"InventoryThreshold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#LocationID\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"MinInventory\\\"\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>",
       ",", 
      StyleBox["\<\"CalculateNetInventoryLongPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], 
      ",", "\<\"longInventoryAndMarket_List\"\>", ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventoryAndMarket\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Rest\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventoryAndMarket\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateLongMarketDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"longInventoryAndMarket_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"marketData,\"\>", ",", "\<\"marketRules\"\>", 
      ",", "\<\",\"\>", ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>",
       ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>",
       ",", "\<\";\"\>", ",", "\<\"marketData\"\>", 
      ",", "\<\"locationID,\"\>", ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"m\"\>", ",", "\<\"/.\"\>", ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventoryAndMarket\"\>", 
      ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\"+\"\>",
       ",", "\<\"1\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"dateRange;\"\>", ",", "\<\"marketRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"ProductID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"SoldToMarket\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>",
       ",", "\<\"4\"\>", ",", "\<\"&,\"\>", ",", "\<\"marketData\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"marketRules\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateMarketValueLongNeeded\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"currentInventory_,\"\>", 
      ",", "\<\"maxInventory_,\"\>", ",", "\<\"minInventory_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"solution,\"\>", 
      ",", "\<\"correctCurrentInventory\"\>", ",", "\<\",\"\>", 
      ",", "\<\"correctCurrentInventory\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ListQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"currentInventory\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"currentInventory\"\>", 
      ",", "\<\",\"\>", ",", "\<\"currentInventory\"\>", ",", "\<\";\"\>", 
      ",", "\<\"solution\"\>", ",", 
      StyleBox["\<\"Quiet\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Maximize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"correctCurrentInventory\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"volumePerUnit*m\"\>", ",", "\<\",\"\>", 
      ",", "\<\"correctCurrentInventory\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"volumePerUnit*m\"\>", ",", "\<\"minInventory\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"correctCurrentInventory\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"volumePerUnit*m\"\>", 
      ",", "\<\"maxInventory\"\>", ",", "\<\"&&\"\>", ",", "\<\"m\"\>", 
      ",", "\<\"0\"\>", ",", "\<\"&&\"\>", ",", "\<\"m\"\>", 
      ",", "\<\"\\\\\"\>", ",", 
      StyleBox["\<\"Element\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Integers,\"\>", 
      ",", "\<\"m\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"NumberQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"m\"\>", ",", "\<\"/.\"\>", 
      ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"solution\"\>", 
      ",", "\<\",\"\>", ",", "\<\"solution,\"\>", ",", "\<\"Null,\"\>", 
      ",", "\<\"m\"\>", ",", "\<\"-\"\>", ",", "\<\"0\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"NetInventoryAndMarketValuesLongPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"maxInventory_,\"\>", ",", "\<\"minInventory_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange,\"\>", 
      ",", "\<\"startingInventory\"\>", ",", "\<\",\"\>", 
      ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", "\<\"startingInventory\"\>", 
      ",", 
      StyleBox["\<\"GetStartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Quiet\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"FoldList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateMarketValueLongNeeded\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#1\"\>", ",", "\<\"+\"\>", 
      ",", 
      StyleBox["\<\"GetDailyProduction\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID\"\>", ",", "\<\"-\"\>", 
      ",", 
      StyleBox["\<\"GetDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID\"\>", ",", "\<\"+\"\>", 
      ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID\"\>", ",", "\<\",\"\>", 
      ",", "\<\"maxInventory,\"\>", ",", "\<\"minInventory\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"startingInventory,\"\>", 
      ",", "\<\"dayRange\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryShortPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], 
      ",", "\<\"shortInventoryAndMarket_List\"\>", ",", 
      StyleBox["\<\"Flatten\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Append\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventoryAndMarket\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Rest\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventoryAndMarket\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateShortMarketDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"longInventoryAndMarket_,\"\>", 
      ",", "\<\"totalVoyageDays_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"marketData,\"\>", ",", "\<\"marketRules\"\>", 
      ",", "\<\",\"\>", ",", "\<\"dateRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>",
       ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateObject\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>",
       ",", "\<\",\"\>", ",", "\<\"totalVoyageDays\"\>", ",", "\<\";\"\>", 
      ",", "\<\"marketData\"\>", ",", "\<\"locationID,\"\>", 
      ",", "\<\"#,\"\>", ",", "\<\"productID,\"\>", ",", "\<\"m\"\>", 
      ",", "\<\"/.\"\>", ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventoryAndMarket\"\>", 
      ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dateRange,\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\"+\"\>",
       ",", "\<\"1\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", 
      ",", "\<\"dateRange;\"\>", ",", "\<\"marketRules\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"LocationID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"Date\\\"\"\>", ",", "\<\"-\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"ProductID\\\"\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"#\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"PurchasedFromMarket\\\"\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#\"\>", ",", "\<\"4\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"marketData\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Dataset\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Association\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", "\<\"marketRules\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"NetInventoryAndMarketValuesShortPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"locationID_,\"\>", 
      ",", "\<\"maxInventory_,\"\>", ",", "\<\"minInventory_,\"\>", 
      ",", "\<\"svdm_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"dayRange,\"\>", 
      ",", "\<\"startingInventory\"\>", ",", "\<\",\"\>", 
      ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"Map\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&,\"\>", 
      ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"7\"\>", ",", "\<\";\"\>", 
      ",", "\<\"startingInventory\"\>", ",", 
      StyleBox["\<\"GetStartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"locationID\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Quiet\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"FoldList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateMarketValueShortNeeded\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#1\"\>", ",", "\<\"-\"\>", 
      ",", 
      StyleBox["\<\"GetDailyConsumption\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID\"\>", ",", "\<\"+\"\>", 
      ",", 
      StyleBox["\<\"GetRecievingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#2,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"locationID\"\>", ",", "\<\",\"\>", 
      ",", "\<\"maxInventory,\"\>", ",", "\<\"minInventory\"\>", 
      ",", "\<\"&,\"\>", ",", "\<\"startingInventory,\"\>", 
      ",", "\<\"dayRange\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateMarketValueShortNeeded\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"currentInventory_,\"\>", 
      ",", "\<\"maxInventory_,\"\>", ",", "\<\"minInventory_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"solution,\"\>", 
      ",", "\<\"correctCurrentInventory\"\>", ",", "\<\",\"\>", 
      ",", "\<\"correctCurrentInventory\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ListQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"currentInventory\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"currentInventory\"\>", 
      ",", "\<\",\"\>", ",", "\<\"currentInventory\"\>", ",", "\<\";\"\>", 
      ",", "\<\"solution\"\>", ",", 
      StyleBox["\<\"Quiet\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Minimize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"correctCurrentInventory\"\>", 
      ",", "\<\"+\"\>", ",", "\<\"volumePerUnit*m\"\>", ",", "\<\",\"\>", 
      ",", "\<\"correctCurrentInventory\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"volumePerUnit*m\"\>", ",", "\<\"minInventory\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"correctCurrentInventory\"\>", 
      ",", "\<\"+\"\>", ",", "\<\"volumePerUnit*m\"\>", 
      ",", "\<\"maxInventory\"\>", ",", "\<\"&&\"\>", ",", "\<\"m\"\>", 
      ",", "\<\"0\"\>", ",", "\<\"&&\"\>", ",", "\<\"m\"\>", 
      ",", "\<\"\\\\\"\>", ",", 
      StyleBox["\<\"Element\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Integers,\"\>", 
      ",", "\<\"m\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"NumberQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"m\"\>", ",", "\<\"/.\"\>", 
      ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"solution\"\>", 
      ",", "\<\",\"\>", ",", "\<\"solution,\"\>", ",", "\<\"Null,\"\>", 
      ",", "\<\"m\"\>", ",", "\<\"-\"\>", ",", "\<\"0\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"CalculateInventoryHoldingMarginPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"vesselOrder_,\"\>", 
      ",", "\<\"vdm_,\"\>", ",", "\<\"svdm_,\"\>", ",", "\<\"lmdm_,\"\>", 
      ",", "\<\"smdm_,\"\>", ",", "\<\"longInventoryAndMarket_,\"\>", 
      ",", "\<\"shortInventoryAndMarket_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventory,\"\>", 
      ",", "\<\"longMarketPrices,\"\>", ",", "\<\"longSoldToMarket,\"\>", 
      ",", "\<\"shortInventory,\"\>", ",", "\<\"shortMarketPrices,\"\>", 
      ",", "\<\"shortPurchasedFromMarket,\"\>", ",", "\<\"dayRange\"\>", 
      ",", "\<\",\"\>", ",", "\<\"longInventory\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryLongPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longInventoryAndMarket\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longMarketPrices\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longSoldToMarket\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"lmdm\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"SoldToMarket\\\"\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortInventory\"\>", ",", 
      StyleBox["\<\"CalculateNetInventoryShortPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortInventoryAndMarket\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMarketPrices\"\>", ",", 
      StyleBox["\<\"FindMarketPrices\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"7\"\>", ",", "\<\",\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortPurchasedFromMarket\"\>", ",", 
      StyleBox["\<\"Normal\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"smdm\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"\\\"PurchasedFromMarket\\\"\"\>", 
      ",", "\<\";\"\>", ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"7\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventory\"\>", 
      ",", "\<\"*Last\"\>", ",", "\<\"longMarketPrices\"\>", ",", "\<\"+\"\>",
       ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ShippedPerDay\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"vdm\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", 
      ",", "\<\"longSoldToMarket,\"\>", ",", "\<\"longSoldToMarket*\"\>", ",", 
      StyleBox["\<\"Parameters\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"ParameterValue\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\".longMarketPrices\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetDailyProduction\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\".longMarketPrices\"\>", ",", "\<\"+\"\>", 
      ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"GetDailyConsumption\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"dayRange\"\>", 
      ",", "\<\".shortMarketPrices\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventory\"\>", 
      ",", "\<\"*\"\>", ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortMarketPrices\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Join\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"RecievedPerDay\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", ",", "\<\"svdm\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"GetVoyageCommit\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", "\<\"dayRange\"\>", 
      ",", "\<\".shortMarketPrices\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"shortPurchasedFromMarket*\"\>", ",", 
      StyleBox["\<\"Parameters\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"All,\"\>", 
      ",", "\<\"\\\"ParameterValue\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\".shortMarketPrices\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"ShippingDateVars\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"path_,\"\>", ",", "\<\"vesselOrder_\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>",
       ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"#\"\>",
       ",", "\<\"2\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"i\"\>", ",", "\<\"/.\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"path,\"\>", ",", "\<\"i\"\>", 
      ",", "\<\"/.\"\>", ",", "\<\"vesselOrder\"\>", ",", "\<\"0,\"\>", ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"path,\"\>", ",", "\<\"i\"\>", 
      ",", "\<\"/.\"\>", ",", "\<\"vesselOrder\"\>", ",", "\<\"1,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"path,\"\>", ",", "\<\"i\"\>", 
      ",", "\<\"/.\"\>", ",", "\<\"vesselOrder\"\>", ",", "\<\",\"\>", 
      ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselOrder\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"CalculateSubleasCreditPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"fillVars_,\"\>", 
      ",", "\<\"vesselOrder_,\"\>", ",", "\<\"path_\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"/.\"\>", ",", "\<\"fillVars\"\>", ",", "\<\"0\"\>", 
      ",", "\<\"&&\"\>", ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"7,\"\>", ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"*GetCharterRate\"\>", ",", "\<\"#1\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"timeWindow\"\>", ",", "\<\"1\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#2\"\>", ",", "\<\"1\"\>", ",", "\<\"7,\"\>", ",", 
      StyleBox["\<\"DateDifference\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"2,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>",
       ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", ",", "\<\"1\"\>", 
      ",", "\<\";;\"\>", ",", "\<\"3\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#2\"\>", ",", "\<\"1\"\>", ",", "\<\"*GetCharterRate\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"0\"\>",
       ",", "\<\"&,\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", "\<\"longLocation\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"ShippingDateVars\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"path,\"\>", ",", "\<\"vesselOrder\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"ObjectiveValuePerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"productID_,\"\>", ",", "\<\"longLocation_,\"\>", 
      ",", "\<\"shortLocation_,\"\>", ",", "\<\"vesselArrivalDates_,\"\>", 
      ",", "\<\"vesselOrder_,\"\>", ",", "\<\"totalVoyageDays_,\"\>", 
      ",", "\<\"fillPercent_,\"\>", ",", "\<\"path_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm,\"\>", ",", "\<\"longMaxInventory,\"\>", 
      ",", "\<\"longMinInventory,\"\>", ",", "\<\"shortMaxInventory,\"\>", 
      ",", "\<\"shortMinInventory,\"\>", 
      ",", "\<\"longInventoryAndMarket,\"\>", 
      ",", "\<\"shortInventoryAndMarket,\"\>", ",", "\<\"lmdm,\"\>", 
      ",", "\<\"smdm\"\>", ",", "\<\",\"\>", ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"GenerateVoyageDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"fillPercent,\"\>", ",", "\<\"path\"\>", ",", "\<\";\"\>", 
      ",", "\<\"svdm\"\>", ",", 
      StyleBox["\<\"GenerateShortVoyageDisplayMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselArrivalDates,\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"vdm\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm\"\>", ",", "\<\";\"\>", 
      ",", "\<\"longMaxInventory\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longMinInventory\"\>", ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMaxInventory\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMinInventory\"\>", ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longInventoryAndMarket\"\>", ",", 
      StyleBox["\<\"NetInventoryAndMarketValuesLongPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"longMaxInventory,\"\>", ",", "\<\"longMinInventory\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortInventoryAndMarket\"\>", ",", 
      StyleBox["\<\"NetInventoryAndMarketValuesShortPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"shortMaxInventory,\"\>", ",", "\<\"shortMinInventory,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\";\"\>", ",", "\<\"lmdm\"\>", ",", 
      StyleBox["\<\"GenerateLongMarketDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"longInventoryAndMarket\"\>", ",", "\<\";\"\>", 
      ",", "\<\"smdm\"\>", ",", 
      StyleBox["\<\"GenerateShortMarketDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"shortInventoryAndMarket,\"\>", ",", "\<\"totalVoyageDays\"\>",
       ",", "\<\";\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"NumberQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Rest\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longInventoryAndMarket\"\>", 
      ",", "\<\"&&\"\>", ",", 
      StyleBox["\<\"NumberQ\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Rest\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"shortInventoryAndMarket\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"CalculateSpreadValue\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"totalVoyageDays,\"\>", ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"CalculateTransportCost\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm\"\>", ",", "\<\"All,\"\>",
       ",", "\<\"\\\"TransportCost\\\"\"\>", ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"CalculateWorkingCapitalCost\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"totalVoyageDays,\"\>", ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm,\"\>", ",", "\<\"lmdm,\"\>", ",", "\<\"smdm\"\>", 
      ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"CalculateInventoryHoldingMarginPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"vdm,\"\>", ",", "\<\"svdm,\"\>", ",", "\<\"lmdm,\"\>", 
      ",", "\<\"smdm,\"\>", ",", "\<\"longInventoryAndMarket,\"\>", 
      ",", "\<\"shortInventoryAndMarket\"\>", ",", "\<\"+\"\>", ",", 
      StyleBox["\<\"CalculateSubleasCreditPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"fillPercent,\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"path\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"No\"\>", ",", "\<\"Solution\\\"\"\>", ",", "\<\";\"\>", 
      ",", 
      StyleBox["\<\"ObjectiveValueOverPaths\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1_,\"\>", 
      ",", "\<\"date2_,\"\>", ",", "\<\"productID_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"paths_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], 
      ",", "\<\"timeWindow,vesselArrivalDates,\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"totalVoyageDays,\"\>", 
      ",", "\<\"fillPercent\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>",
       ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselArrivalDates\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"&,\"\>", ",", "\<\"vesselArrivalDates\"\>",
       ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"totalVoyageDays\"\>", ",", 
      StyleBox["\<\"Max\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\"All,\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"i\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationTo\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>",
       ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"fillPercent\"\>", ",", "\<\"#\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"1\"\>", ",", "\<\"*Will\"\>", 
      ",", "\<\"be\"\>", ",", "\<\"changed\"\>", ",", "\<\"to\"\>", 
      ",", "\<\"a\"\>", ",", "\<\"rule\"\>", ",", "\<\"depending\"\>", 
      ",", "\<\"on\"\>", ",", "\<\"heuristic*\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"vesselOrder;\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"ObjectiveValuePerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselArrivalDates,\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"totalVoyageDays,\"\>", 
      ",", "\<\"fillPercent,\"\>", ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"paths\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"MatricesPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1_,\"\>", 
      ",", "\<\"date2_,\"\>", ",", "\<\"productID_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"path_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"vesselArrivalDates,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"totalVoyageDays,\"\>", ",", "\<\"fillPercent,\"\>", 
      ",", "\<\"longMaxInventory,\"\>", ",", "\<\"longMinInventory,\"\>", 
      ",", "\<\"shortMaxInventory,\"\>", ",", "\<\"shortMinInventory,\"\>", 
      ",", "\<\"longInventoryAndMarket,\"\>", 
      ",", "\<\"shortInventoryAndMarket\"\>", ",", "\<\",\"\>", 
      ",", "\<\"timeWindow\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselArrivalDates\"\>", ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"&,\"\>", ",", "\<\"vesselArrivalDates\"\>",
       ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"totalVoyageDays\"\>", ",", 
      StyleBox["\<\"Max\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"vesselOrder\"\>", ",", "\<\"All,\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"i\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationTo\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>",
       ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselOrder\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"fillPercent\"\>", ",", "\<\"#\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"1\"\>", ",", "\<\"*Will\"\>", 
      ",", "\<\"be\"\>", ",", "\<\"changed\"\>", ",", "\<\"to\"\>", 
      ",", "\<\"a\"\>", ",", "\<\"rule\"\>", ",", "\<\"depending\"\>", 
      ",", "\<\"on\"\>", ",", "\<\"heuristic*\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"vesselOrder;\"\>", ",", "\<\"vdm\"\>", ",", 
      StyleBox["\<\"GenerateVoyageDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"vesselOrder,\"\>", 
      ",", "\<\"fillPercent,\"\>", ",", "\<\"path\"\>", ",", "\<\";\"\>", 
      ",", "\<\"svdm\"\>", ",", 
      StyleBox["\<\"GenerateShortVoyageDisplayMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"shortLocation,\"\>", ",", "\<\"vesselArrivalDates,\"\>", 
      ",", "\<\"vesselOrder,\"\>", ",", "\<\"vdm\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"GenerateDepartingInventory\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"vdm\"\>", ",", "\<\";\"\>", 
      ",", "\<\"longMaxInventory\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longMinInventory\"\>", ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMaxInventory\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMinInventory\"\>", ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longInventoryAndMarket\"\>", ",", 
      StyleBox["\<\"NetInventoryAndMarketValuesLongPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"longMaxInventory,\"\>", ",", "\<\"longMinInventory\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortInventoryAndMarket\"\>", ",", 
      StyleBox["\<\"NetInventoryAndMarketValuesShortPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"shortMaxInventory,\"\>", ",", "\<\"shortMinInventory,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\";\"\>", ",", "\<\"lmdm\"\>", ",", 
      StyleBox["\<\"GenerateLongMarketDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"longLocation,\"\>", 
      ",", "\<\"longInventoryAndMarket\"\>", ",", "\<\";\"\>", 
      ",", "\<\"smdm\"\>", ",", 
      StyleBox["\<\"GenerateShortMarketDecisionMatrixPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"productID,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"shortInventoryAndMarket,\"\>", ",", "\<\"totalVoyageDays\"\>",
       ",", "\<\";\"\>", ",", "\<\"Dataset`$ElisionThreshold\"\>", 
      ",", "\<\"256;\"\>", ",", 
      StyleBox["\<\"Grid\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vdm,\"\>", 
      ",", "\<\"svdm\"\>", ",", "\<\",\"\>", ",", "\<\"lmdm,\"\>", 
      ",", "\<\"smdm\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Alignment\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"Left,\"\>", 
      ",", 
      StyleBox["\<\"Left\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Top\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Spacings\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"3\"\>", ",", "\<\",\"\>", ",", "\<\"0,\"\>", ",", "\<\"3\"\>",
       ",", "\<\";\"\>", ",", 
      StyleBox["\<\"HeuristicResults\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1_,\"\>", 
      ",", "\<\"date2_,\"\>", ",", "\<\"productID_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"paths\"\>", ",", "\<\",\"\>", 
      ",", "\<\"paths\"\>", ",", 
      StyleBox["\<\"GenerateAllPaths\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1,\"\>", 
      ",", "\<\"date2,\"\>", ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"solutions\"\>", ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"ObjectiveValueOverPaths\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1,\"\>", 
      ",", "\<\"date2,\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"paths\"\>", ",", "\<\",\"\>", ",", "\<\"x_\"\>", 
      ",", "\<\"/;\"\>", ",", "\<\"x\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"\\\"No\"\>", ",", "\<\"Solution\\\"\"\>", ",", "\<\",\"\>", 
      ",", "\<\"#1\"\>", ",", "\<\"2\"\>", ",", "\<\"#2\"\>", 
      ",", "\<\"2\"\>", ",", "\<\"&\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"Manipulate\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Column\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"\\\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Objective\"\>", ",", 
      StyleBox["\<\"Value\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"$\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"NumberForm\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"path\"\>", ",", "\<\"/.\"\>", 
      ",", "\<\"solutions,\"\>", ",", 
      StyleBox["\<\"DigitBlock\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"3,\"\>", 
      ",", 
      StyleBox["\<\"NumberPoint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"\\\"\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", 
      StyleBox["\<\"Darker\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Gray,\"\>", ",", "\<\".4\"\>",
       ",", "\<\",\"\>", ",", "\<\"22,\"\>", ",", 
      StyleBox["\<\"Bold\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\",\"\>", 
      ",", "\<\"\\\"\\\",\"\>", ",", 
      StyleBox["\<\"MatricesPerPath\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1,\"\>", 
      ",", "\<\"date2,\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"path\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Spacings\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\".5\"\>", 
      ",", "\<\",\"\>", ",", "\<\"path,\"\>", ",", "\<\"solutions\"\>", 
      ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Style\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"\\\"Ranked\"\>", 
      ",", "\<\"Solutions\\\",\"\>", ",", 
      StyleBox["\<\"FontFamily\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Calibri\\\",\"\>", ",", 
      StyleBox["\<\"Darker\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"Gray,\"\>", ",", "\<\".4\"\>",
       ",", "\<\",\"\>", ",", "\<\"18\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"MapThread\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"\\\"Solution\"\>", ",", "\<\"\\\"\"\>", ",", 
      StyleBox["\<\"ToString\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"&,\"\>", 
      ",", 
      StyleBox["\<\"Range\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"solutions\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", 
      ",", "\<\"solutions\"\>", ",", "\<\"All,\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"ImageSize\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", "\<\"100\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"ControlType\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", 
      ",", "\<\"PopupMenu,\"\>", ",", 
      StyleBox["\<\"Paneled\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"False\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>", ",", 
      StyleBox["\<\"SinglePathTestor\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow_,\"\>", 
      ",", "\<\"dayRange_,\"\>", ",", "\<\"productID_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"longMaxInventory_,\"\>", ",", "\<\"longMinInventory_,\"\>", 
      ",", "\<\"shortMaxInventory_,\"\>", ",", "\<\"shortMinInventory_,\"\>", 
      ",", "\<\"vesselArrivalDates_,\"\>", ",", "\<\"vesselCapacity_,\"\>", 
      ",", "\<\"voyageDays_,\"\>", ",", "\<\"path_\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDates,\"\>", 
      ",", "\<\"dayRangeBetweenVesselShipments,\"\>", 
      ",", "\<\"dayRangeBetweenVesselArrivals,\"\>", 
      ",", "\<\"productionBetweenShipments,\"\>", 
      ",", "\<\"consumptionBetweenShipments,\"\>", 
      ",", "\<\"amountShipped\"\>", ",", "\<\",\"\>", 
      ",", "\<\"vesselShippingDates\"\>", ",", "\<\"#\"\>", ",", "\<\"-\"\>", 
      ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"path,\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"0,\"\>", ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"Position\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"path,\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"1,\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"&\"\>",
       ",", "\<\"/@\"\>", ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"dayRangeBetweenVesselShipments\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"#1,\"\>", ",", "\<\"timeWindow\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"#2,\"\>", ",", "\<\"timeWindow\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"@@\"\>", ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"dayRangeBetweenVesselArrivals\"\>", ",", 
      StyleBox["\<\"DateRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#1\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"#1,\"\>", ",", "\<\"timeWindow\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#2\"\>", ",", "\<\"0,\"\>", 
      ",", "\<\"#2,\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Max\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"voyageDays\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"@@\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\"0,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselShippingDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\",\"\>", 
      ",", "\<\"timeWindow\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Last\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Sort\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"0,\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"2\"\>", 
      ",", "\<\",\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\"/.\"\>",
       ",", "\<\"voyageDays\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"DatePlus\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\",\"\>", ",", 
      StyleBox["\<\"Max\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"voyageDays\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"2\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"vesselShippingDates\"\>", ",", "\<\";\"\>",
       ",", "\<\"productionBetweenShipments\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DailyProductionSchedule\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"dayRangeBetweenVesselShipments\"\>", ",", "\<\"i\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>", ",", "\<\"productID\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductionVolume\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], 
      ",", "\<\"dayRangeBetweenVesselShipments\"\>", ",", "\<\";\"\>", 
      ",", "\<\"consumptionBetweenShipments\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DailyConsumptionSchedule\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#Date\"\>", 
      ",", "\<\"dayRangeBetweenVesselArrivals\"\>", ",", "\<\"i\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#ProductID\"\>", ",", "\<\"productID\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationID\"\>", 
      ",", "\<\"shortLocation\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"ProductionVolume\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\",\"\>", ",", "\<\"i,\"\>", ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], 
      ",", "\<\"dayRangeBetweenVesselArrivals\"\>", ",", "\<\";\"\>", 
      ",", "\<\"amountShipped\"\>", ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"/.\"\>", 
      ",", "\<\"vesselCapacity\"\>", ",", "\<\"&\"\>", ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#\"\>", ",", "\<\"2\"\>", 
      ",", "\<\"1,\"\>", ",", "\<\"#\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>",
       ",", "\<\"&\"\>", ",", "\<\"/@vesselShippingDates\"\>", 
      ",", "\<\",\"\>", ",", "\<\";\"\>", ",", 
      StyleBox["\<\"If\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"longMaxInventory\"\>", 
      ",", "\<\"-\"\>", ",", "\<\"amountShipped\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"productionBetweenShipments\"\>", 
      ",", "\<\"longMinInventory\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"shortMinInventory\"\>", ",", "\<\"+\"\>", 
      ",", "\<\"amountShipped\"\>", ",", "\<\"-\"\>", 
      ",", "\<\"consumptionBetweenShipments\"\>", 
      ",", "\<\"shortMaxInventory,\"\>", ",", "\<\"path\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"PathEliminator\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1_,\"\>", 
      ",", "\<\"date2_,\"\>", ",", "\<\"productID_,\"\>", 
      ",", "\<\"longLocation_,\"\>", ",", "\<\"shortLocation_,\"\>", 
      ",", "\<\"paths_List\"\>", ",", 
      StyleBox["\<\"Block\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"dayRange,\"\>", ",", "\<\"vesselArrivalDates,\"\>", 
      ",", "\<\"voyageDays,\"\>", ",", "\<\"vesselCapacity,\"\>", 
      ",", "\<\"longMaxInventory,\"\>", ",", "\<\"longMinInventory,\"\>", 
      ",", "\<\"shortMaxInventory,\"\>", ",", "\<\"shortMinInventory\"\>", 
      ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date1\"\>", ",", "\<\",\"\>", 
      ",", 
      StyleBox["\<\"DateConvert\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"date2\"\>", ",", "\<\";\"\>", 
      ",", "\<\"dayRange\"\>", ",", 
      StyleBox["\<\"DateList\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"/@\"\>", ",", 
      StyleBox["\<\"DayRange\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"timeWindow\"\>", 
      ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"timeWindow\"\>", 
      ",", "\<\"2\"\>", ",", "\<\";\"\>", ",", "\<\"vesselArrivalDates\"\>", 
      ",", 
      StyleBox["\<\"GetArrivingVessels\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\";\"\>", 
      ",", "\<\"voyageDays\"\>", ",", 
      StyleBox["\<\"Table\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\"i\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"Ceiling\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"First\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"Total\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"VoyageRules\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#VesselTypeID\"\>", ",", 
      StyleBox["\<\"TransportPool\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", 
      StyleBox["\<\"Select\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"#EquipmentID\"\>", 
      ",", "\<\"vesselArrivalDates\"\>", ",", "\<\"All,\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"i\"\>", ",", "\<\"&\"\>", ",", "\<\",\"\>", 
      ",", "\<\"\\\"VesselTypeID\\\"\"\>", ",", "\<\"1\"\>", 
      ",", "\<\"&&\"\>", ",", "\<\"#LocationFrom\"\>", 
      ",", "\<\"longLocation\"\>", ",", "\<\"&&\"\>", 
      ",", "\<\"#LocationTo\"\>", ",", "\<\"shortLocation\"\>", 
      ",", "\<\"&\"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\"i,\"\>",
       ",", "\<\"1,\"\>", ",", 
      StyleBox["\<\"Length\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\";\"\>", ",", "\<\"vesselCapacity\"\>", ",", "\<\"#\"\>", 
      ",", "\<\"-\"\>", ",", 
      StyleBox["\<\"GetVesselCapacity\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"vesselArrivalDates\"\>", 
      ",", "\<\"All,\"\>", ",", "\<\"1\"\>", ",", "\<\";\"\>", 
      ",", "\<\"longMaxInventory\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"longMinInventory\"\>", ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"longLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMaxInventory\"\>", ",", 
      StyleBox["\<\"GetMaxInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", "\<\"shortMinInventory\"\>", ",", 
      StyleBox["\<\"GetMinInventoryConstraint\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"shortLocation\"\>", 
      ",", "\<\";\"\>", ",", 
      StyleBox["\<\"DeleteCases\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", 
      StyleBox["\<\"SinglePathTestor\"\>",
       StripOnInput->False,
       LineColor->RGBColor[0, 0, 1],
       FrontFaceColor->RGBColor[0, 0, 1],
       BackFaceColor->RGBColor[0, 0, 1],
       GraphicsColor->RGBColor[0, 0, 1],
       FontColor->RGBColor[0, 0, 1]], ",", "\<\"timeWindow,\"\>", 
      ",", "\<\"dayRange,\"\>", ",", "\<\"productID,\"\>", 
      ",", "\<\"longLocation,\"\>", ",", "\<\"shortLocation,\"\>", 
      ",", "\<\"longMaxInventory,\"\>", ",", "\<\"longMinInventory,\"\>", 
      ",", "\<\"shortMaxInventory,\"\>", ",", "\<\"shortMinInventory,\"\>", 
      ",", "\<\"vesselArrivalDates,\"\>", ",", "\<\"vesselCapacity,\"\>", 
      ",", "\<\"voyageDays,\"\>", ",", "\<\"#\"\>", ",", "\<\"&\"\>", 
      ",", "\<\"/@\"\>", ",", "\<\"paths,\"\>", ",", 
      StyleBox["\<\"Null\"\>",
       StripOnInput->False,
       LineColor->RGBColor[1, 0, 0],
       FrontFaceColor->RGBColor[1, 0, 0],
       BackFaceColor->RGBColor[1, 0, 0],
       GraphicsColor->RGBColor[1, 0, 0],
       FontColor->RGBColor[1, 0, 0]], ",", "\<\";\"\>"}], "}"}]]],
   TextCell[{"*", "Wolfram", 
     Style["Language", 
      RGBColor[1, 0, 0]], 
     Style["Raw", 
      RGBColor[1, 0, 0]], "Program", "*", 
     Style["SetupModel", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", "dataLink", "\"https", 
     "//docs.google.com/spreadsheet/ccc?key", 
     "1MZ5Xc_RydlgQrwsRCp6BStHcrrs553Dg6k4TSHWRm3Y&output", "ods\";", 
     "Dataset`$ElisionThreshold", "256;", ";", 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], "importedData_List", 
     Style["Block", 
      RGBColor[1, 0, 0]], "totalColumns", ",", "*", "Assume", "the", "first", 
     "row", "is", "a", "contiguous", "header", "*", "totalColumns", 
     Style["FirstPosition", 
      RGBColor[1, 0, 0]], "importedData", "1", ",", "\"\"", ";", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Head", 
      RGBColor[1, 0, 0]], "totalColumns", "Missing,", "totalColumns", 
     Style["Length", 
      RGBColor[1, 0, 0]], "importedData", "1", ",", "totalColumns", 
     "totalColumns", "1", "-", "1", ";", 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["AssociationThread", 
      RGBColor[1, 0, 0]], "importedData", "1,", "1", ";;", "totalColumns", 
     "-", 
     Style["PadRight", 
      RGBColor[1, 0, 0]], "#", "1", ";;", "totalColumns", ",", 
     "totalColumns,", "\"\"", "&,", 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], "importedData", "2", ";;", ",", "\"\",", "\"\",", 
     "\"\"", ";", 
     Style["RefreshModel", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", 
     Style["StartingInventory", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"Inventory\"", ";", 
     Style["DailyProductionSchedule", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"DailyProductionSchedule\"", ";", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"TransportPool\"", ";", 
     Style["VoyageCommit", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"VoyageCommit\"", ";", 
     Style["Parameters", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"Parameters\"", ";", 
     Style["MarketSales", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"MarketSales\"", ";", "volumePerUnit", 
     Style["Parameters", 
      RGBColor[0, 0, 1]], 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#ParameterName", "\"BarrelsPerUnit\"&", ",", 
     "\"ParameterValue\"", ";", 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"VoyageRules\"", ";", 
     Style["Location", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"Location\"", ";", 
     Style["Products", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"Product\"", ";", 
     Style["DailyConsumptionSchedule", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"DailyConsumptionSchedule\"", ";", 
     Style["MarketPrice", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"MarketPrice\"", ";", 
     Style["InventoryThreshold", 
      RGBColor[0, 0, 1]], 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["AssociateListImport", 
      RGBColor[0, 0, 1]], 
     Style["Import", 
      RGBColor[1, 0, 0]], "dataLink,", "\"ODS\",", "\"Sheets\",", 
     "\"InventoryThreshold\"", ";", "workingCapitalCharge", "0.06;", 
     Style["GetStartingInventory", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_", 
     Style["StartingInventory", 
      RGBColor[0, 0, 1]], 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#Date", "date", "&&", "#LocationID", "locationID", 
     "&&", "#ProductID", "productID", "&", ",", "\"Inventory\"", ";", 
     Style["GetDailyProduction", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_", 
     Style["DailyProductionSchedule", 
      RGBColor[0, 0, 1]], 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#Date", "date", "&&", "#ProductID", "productID", 
     "&&", "#LocationID", "locationID&", ",", "\"ProductionVolume\"", ";", 
     Style["GetDailyConsumption", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_", 
     Style["DailyConsumptionSchedule", 
      RGBColor[0, 0, 1]], 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#Date", "date", "&&", "#ProductID", "productID", 
     "&&", "#LocationID", "locationID", "&", ",", "\"ProductionVolume\"", ";", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow_,", "locationID_", 
     Style["Values", 
      RGBColor[1, 0, 0]], 
     Style["Normal", 
      RGBColor[1, 0, 0]], 
     Style["VoyageCommit", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], 
     Style["AbsoluteTime", 
      RGBColor[1, 0, 0]], "#ReturnToService", 
     Style["AbsoluteTime", 
      RGBColor[1, 0, 0]], "timeWindow", "1", "&&", 
     Style["AbsoluteTime", 
      RGBColor[1, 0, 0]], "#ReturnToService", 
     Style["AbsoluteTime", 
      RGBColor[1, 0, 0]], "timeWindow", "2", "&&", "#DeliveryLocationID", 
     "locationID", "&", ",", "\"EquipmentID\",", "\"ReturnToService\"", ";", 
     Style["GetVesselCapacity", 
      RGBColor[0, 0, 1]], "vesselID_", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#EquipmentID", "vesselID&", ",", 
     "\"PhysicalCapacity\"", ";", 
     Style["GetMarketSales", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_,", "lmdm_", 
     Style["With", 
      RGBColor[1, 0, 0]], "s", "lmdm", 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#Date", "date", "&&", "#LocationID", "locationID", 
     "&&", "#ProductID", "productID", "&", ",", "\"SoldToMarket\"", 
     "*MarketSales", 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#LocationID", "locationID", "&&", "#ProductID", 
     "productID", "&&", "#Date", "date", "&", ",", "\"Units\"", "*", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Head", 
      RGBColor[1, 0, 0]], "s", 
     Style["Missing", 
      RGBColor[1, 0, 0]], ",", "0,", "s", "*", "volumePerUnit", ";", 
     Style["GetMarketPurchases", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_,", "smdm_", 
     Style["With", 
      RGBColor[1, 0, 0]], "s", "smdm", 
     Style["SelectFirst", 
      RGBColor[1, 0, 0]], "#Date", "date", "&&", "#LocationID", "locationID", 
     "&&", "#ProductID", "productID", "&", ",", "\"PurchasedFromMarket\"", 
     ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Head", 
      RGBColor[1, 0, 0]], "s", 
     Style["Missing", 
      RGBColor[1, 0, 0]], ",", "0,", "s", "*", "volumePerUnit", ";", 
     Style["CalculateAmountShipped", 
      RGBColor[0, 0, 1]], "equipmentID_,", "vesselFill_", 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", "*", 
     Style["NumberForm", 
      RGBColor[1, 0, 0]], 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"PhysicalCapacity\"", "1", "*", "vesselFill,", "40,", "0", ",", 
     Style["DigitBlock", 
      RGBColor[1, 0, 0]], "-", "3,", 
     Style["NumberPoint", 
      RGBColor[1, 0, 0]], "-", "\"\"", "*", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"PhysicalCapacity\"", "1", "*", "vesselFill", ";", 
     Style["SingleVesselVDM", 
      RGBColor[0, 0, 1]], "timeWindow_,", "locationID_,", "shortLocation_,", 
     "productID_,", "vesselName_,", "vesselShippingDate_,", "vesselFill_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "periodRange", ",", "periodRange", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     Style["Sort", 
      RGBColor[1, 0, 0]], 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], 
     Style["Tuples", 
      RGBColor[1, 0, 0]], "vesselName", ",", 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], "periodRange,", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "vesselShippingDate", ",", "locationID", ",", 
     "productID", ",", "\"-\"", ",", "0", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Head", 
      RGBColor[1, 0, 0]], "vesselShippingDate", 
     Style["Symbol", 
      RGBColor[1, 0, 0]], "||", "vesselShippingDate", ",", ",", "vesselName,", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "vesselShippingDate", ",", "locationID,", 
     "productID,", "shortLocation,", 
     Style["CalculateAmountShipped", 
      RGBColor[0, 0, 1]], "vesselName,", "vesselFill", ",", ",", "#1", "2", 
     "#2", "2", "&", ";", "*GenerateVoyageDecisionMatrix", "timeWindow_,", 
     "locationID_,", "shortLocation_,productID_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "voyageMap,", "voyageRules", ",", "*Remove", "the", 
     "hardcoding", "when", "we", "figure", "out", "how", "to", "dynamically", 
     "create", "variables*", "vesselName1", "\"ATL\";", "vesselName2", 
     "\"EVE\";", "voyageMap", 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["SingleVesselVDM", 
      RGBColor[0, 0, 1]], "timeWindow,", "locationID,", "shortLocation,", 
     "productID,vesselName1,", "vesselShippingDate1,", "vesselFill1", ",", 
     Style["SingleVesselVDM", 
      RGBColor[0, 0, 1]], "timeWindow,", "locationID,", "shortLocation,", 
     "productID,vesselName2,", "vesselShippingDate2,", "vesselFill2", ";", 
     "voyageRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"LocationID\"", "-", "#", "3", ",", 
     "\"ProductID\"", "-", "#", "4", ",", "\"Sent\"", "-", "#", "5", ",", 
     "\"AmountShipped\"", "-", "#", "6", "&,", "voyageMap", ";", 
     "Dataset`$ElisionThreshold", "128;", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "voyageRules", ";*", 
     Style["GenerateVoyageDecisionMatrix", 
      RGBColor[0, 0, 1]], "timeWindow_,", "longLocation_,", "shortLocation_,",
      "productID_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "voyageMap,", "voyageRules", ",", "voyageMap", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["MapThread", 
      RGBColor[1, 0, 0]], 
     Style["SingleVesselVDM", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation,", "shortLocation,", 
     "productID,", "#3", "/.", "vesselOrder,", "#1,", "#2", "&,", 
     "shippingDateVars,", "fillVars,", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "shippingDateVars", ",", "1", ";", "voyageRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"LocationID\"", "-", "#", "3", ",", 
     "\"ProductID\"", "-", "#", "4", ",", "\"Sent\"", "-", "#", "5", ",", 
     "\"AmountShipped\"", "-", "#", "6", "&,", "voyageMap", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "voyageRules", ";", 
     Style["GenerateLongMarketDecisionMatrix", 
      RGBColor[0, 0, 1]], "locationID_,", "productID_,", "dateRange_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "marketData,", "marketRules", ",", "marketData", 
     "locationID,", "#,", "productID,", 
     Style["Round", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["NumberQ", 
      RGBColor[1, 0, 0]], 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"marketValueLong\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange,", "#", "1,", "1", ",", 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"marketValueLong\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange,", "#", "1,", "1", ",", "0", "&", "/@", 
     "dateRange;", "marketRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"LocationID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"ProductID\"", "-", "#", "3", ",", 
     "\"SoldToMarket\"-", "#", "4", "&,", "marketData", ";", 
     "Dataset`$ElisionThreshold", "192;", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "marketRules", ";", 
     Style["GenerateShortMarketDecisionMatrix", 
      RGBColor[0, 0, 1]], "locationID_,", "productID_,", "dateRange_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "marketData,", "marketRules", ",", "marketData", 
     "locationID,", "#,", "productID,", 
     Style["Round", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["NumberQ", 
      RGBColor[1, 0, 0]], 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"marketValueShort\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange,", "#", "1,", "1", ",", 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"marketValueShort\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange,", "#", "1,", "1", ",", "0", "&", "/@", 
     "dateRange;", "marketRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"LocationID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"ProductID\"", "-", "#", "3", ",", 
     "\"PurchasedFromMarket\"", "-", "#", "4", "&,", "marketData", ";", 
     "Dataset`$ElisionThreshold", "128;", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "marketRules", ";", 
     "*GenerateVoyageDecisionMatrix", "timeWindow_,", "locationID_,", 
     "productID_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "vesselArrivals,", "voyageMap,", "voyageRules", ",",
      "vesselArrivals", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow,", "locationID", ";", "voyageMap", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Tuples", 
      RGBColor[1, 0, 0]], "#", "1", ",", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "#", "2", ",", "timeWindow", "2", ",", "locationID",
      ",", "productID", ",", "0", "&,", "vesselArrivals", ",", "1", ";", 
     "voyageRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"LocationID\"", "-", "#", "3", ",", 
     "\"ProductID\"", "-", "#", "4", ",", "\"Sent\"", "-", "#", "5", "&,", 
     "voyageMap", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "voyageRules", ";*", 
     Style["GenerateDepartingInventory", 
      RGBColor[0, 0, 1]], "decisionMatrix_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "productID,", "locationID,", "shipments,", 
     "shipped,", "departingVolume", ",", 
     Style["Clear", 
      RGBColor[1, 0, 0]], 
     Style["GetDepartingInventory", 
      RGBColor[0, 0, 1]], ";", 
     Style["GetDepartingInventory", 
      RGBColor[0, 0, 1]], "_,_,_", "0;", "*", "Make", "zero", "the", 
     "default", "*", "productID", "decisionMatrix", "1,\"ProductID\"", ";", 
     "locationID", "decisionMatrix", "1,\"LocationID\"", ";", "shipments", 
     "decisionMatrix", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Sent", "!", "\"-\"&", ";", "*shipped", 
     "shipments", "All,", 
     Style["Append", 
      RGBColor[1, 0, 0]], "#,", "\"Shipped\"", "-", 
     Style["GetVesselCapacity", 
      RGBColor[0, 0, 1]], "#EquipmentID", "&", ";*", "*", "@TODO", "The", 
     "calculation", "below", "could", "probably", "be", "made", "more", 
     "efficient", "*", "departingVolume", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"Date\"", "-", "#", "1", ",", "\"ProductID\"", 
     "-", "productID,", "\"Shipped\"", "-", "#", "2", "&,", 
     Style["Normal", 
      RGBColor[1, 0, 0]], 
     Style["Normal", 
      RGBColor[1, 0, 0]], "shipments", 
     Style["GroupBy", 
      RGBColor[1, 0, 0]], "\"Date\"", ",", "Total,", "\"AmountShipped\"", ";", 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["GetDepartingInventory", 
      RGBColor[0, 0, 1]], 
     Style["DateList", 
      RGBColor[1, 0, 0]], "\"Date\"", "/.", "#", ",", "productID,", 
     "locationID", "\"Shipped\"", "/.", "#", "&,", "departingVolume", ";", 
     ";", 
     Style["GetRecievingInventory", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_,", "svdm_", 
     "svdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Date", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "date", "1", ";;", "3", "&&", "#ProductID", 
     "productID", "&&", "#LocationID", "locationID", "&", "Total,", 
     "\"AmountRecieved\"", ";", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "date_,", "productID_,", "locationID_", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["VoyageCommit", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#DeliveryLocationID", "locationID", "&&", 
     "#ProductID", "productID", "&&", "#ReturnToService", "date", "&", ",", 
     "\"Volume\"", "0,", "0,", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["VoyageCommit", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#DeliveryLocationID", "locationID", "&&", 
     "#ProductID", "productID", "&&", "#ReturnToService", "date", "&", ",", 
     "\"Volume\"", ";", 
     Style["CalculateNetInventoryLong", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "longLocation_,", 
     "lmdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dayRange,", "startingInventory", ",", 
     "startingInventory", 
     Style["GetStartingInventory", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "productID,", 
     "longLocation", ";", "dayRange", 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["DateList", 
      RGBColor[1, 0, 0]], "#", "&,", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     Style["FoldList", 
      RGBColor[1, 0, 0]], "#1", "+", 
     Style["GetDailyProduction", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "longLocation", "-", 
     Style["GetDepartingInventory", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "longLocation", "-", 
     Style["GetMarketSales", 
      RGBColor[0, 0, 1]], 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "#2", "1", ";;", "3", ",", "productID,", 
     "longLocation,", "lmdm", "+", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "longLocation", "&,", 
     "startingInventory,", "dayRange", ";", 
     Style["CalculateNetInventoryShort", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "shortLocation_,", 
     "svdm_,", "smdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "startingInventory,", "dayRange", ",", 
     "startingInventory", 
     Style["GetStartingInventory", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "productID,", 
     "shortLocation", ";", "dayRange", 
     Style["Union", 
      RGBColor[1, 0, 0]], 
     Style["DateList", 
      RGBColor[1, 0, 0]], "/@", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "svdm", "All,", "\"Date\"", ";", 
     Style["FoldList", 
      RGBColor[1, 0, 0]], "#1", "-", 
     Style["GetDailyConsumption", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "shortLocation", "+", 
     Style["GetRecievingInventory", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "shortLocation,", "svdm", "+", 
     Style["GetMarketPurchases", 
      RGBColor[0, 0, 1]], 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "#2", "1", ";;", "3", ",", "productID,", 
     "shortLocation,", "smdm", "+", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "shortLocation", "&,", 
     "startingInventory,", "dayRange", ";", 
     Style["CalculateTranportCostPerVessel", 
      RGBColor[0, 0, 1]], "equipmentID_,", "locationFrom_,", "locationTo_,", 
     "vdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "shipmentDaysInfo,", "vesselDetails,", 
     "totalVoyageDays", ",", "shipmentDaysInfo", 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "locationFrom", "&&", 
     "#LocationTo", "locationTo", "&", "1", ";", "vesselDetails", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", "1", ";", 
     "totalVoyageDays", 
     Style["Total", 
      RGBColor[1, 0, 0]], "shipmentDaysInfo", "\"DaysLoading\",", 
     "\"DaysUnderway\",", "\"DockWait\",", "\"DaysUnloading\"", ";", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["FindVesselFill", 
      RGBColor[0, 0, 1]], "equipmentID,", "vdm", "0,", "0,", "vesselDetails", 
     "\"CharterRatePerDay\"", "*", "totalVoyageDays", "+", "vesselDetails", 
     "\"FuelChgPerDay\"", "*", "shipmentDaysInfo", "\"DaysUnderway\"", "+", 
     "vesselDetails", "\"CleaningRate\"", "+", "vesselDetails", 
     "\"HeatingCharge\"", "+", "vesselDetails", "\"TankerManPortFee\"", ";", 
     Style["CalculateTransportCost", 
      RGBColor[0, 0, 1]], "decisionMatrix_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "shipments", ",", "shipments", "decisionMatrix", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Sent", "!", "\"-\"", "&", ";", "shipments", 
     "All,", 
     Style["Append", 
      RGBColor[1, 0, 0]], "#,", "\"TransportCost\"", "-", 
     Style["CalculateTranportCostPerVessel", 
      RGBColor[0, 0, 1]], "#EquipmentID,", "#LocationID,", "#Sent,", 
     "decisionMatrix", "*NumberForm", 
     Style["CalculateTranportCostPerVessel", 
      RGBColor[0, 0, 1]], "#EquipmentID,", "#LocationID,", "#Sent", ",", 
     "40,", "0", ",", 
     Style["DigitBlock", 
      RGBColor[1, 0, 0]], "-", "3,", 
     Style["NumberPoint", 
      RGBColor[1, 0, 0]], "-", "\"\"", "*", "&", ";", "*GUI*", 
     Style["ProductID", 
      RGBColor[0, 0, 1]], 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["PopupMenu", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "productID", ",", 
     Style["Normal", 
      RGBColor[1, 0, 0]], 
     Style["Products", 
      RGBColor[0, 0, 1]], "All,", "\"ProductID\"", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Product", "ID\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", 
     Style["LongLocation", 
      RGBColor[0, 0, 1]], 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["PopupMenu", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "longLocation", ",", 
     Style["Normal", 
      RGBColor[1, 0, 0]], 
     Style["Location", 
      RGBColor[0, 0, 1]], "All,", "\"LocationID\"", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Long", "Location\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", 
     Style["ShortLocation", 
      RGBColor[0, 0, 1]], 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["PopupMenu", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "shortLocation", ",", 
     Style["Normal", 
      RGBColor[1, 0, 0]], 
     Style["Location", 
      RGBColor[0, 0, 1]], "All,", "\"LocationID\"", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Short", "Location\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", 
     Style["TimeWindow", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["Row", 
      RGBColor[1, 0, 0]], 
     Style["InputField", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "timeWindow1", ",", "String,", 
     Style["FieldHint", 
      RGBColor[1, 0, 0]], "-", "\"Format", "05/01/2015\",", 
     Style["ImageSize", 
      RGBColor[1, 0, 0]], "-", "140", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"", "to", "\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["InputField", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "timeWindow2", ",", "String,", 
     Style["FieldHint", 
      RGBColor[1, 0, 0]], "-", "\"Format", "05/01/2015\",", 
     Style["ImageSize", 
      RGBColor[1, 0, 0]], "-", "140", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Time", "Window\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "dateString_", 
     Style["DateList", 
      RGBColor[1, 0, 0]], "dateString,", "\"Month\",", "\"Day\",", 
     "\"YearShort\"", ";", "*Vessel1ShippingControls", 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["Column", 
      RGBColor[1, 0, 0]], 
     Style["RadioButtonBar", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "vesselShippingDate1", ",", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", "i,", "1", ";;", "3", "-", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Day", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", 
     Style["Slider", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "vesselFill1", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Vessel", "1\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", "Vessel2ShippingControls", 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["Column", 
      RGBColor[1, 0, 0]], 
     Style["RadioButtonBar", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "vesselShippingDate2", ",", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", "i,", "1", ";;", "3", "-", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Day", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", 
     Style["Slider", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "vesselFill2", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Vessel", "2\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";*", 
     Style["VesselShippingControls", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], "dateRange,", "vesselArrivalDates", ",", 
     "vesselArrivalDates", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "longLocation", ";", 
     "vesselOrder", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], "#2", "-", "#1", "&,", "vesselArrivalDates", "All,",
      "1", ",", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "All,", "1", ";", 
     "shippingDateVars", 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"vesselShippingDate\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "All,", "1", ";", "fillVars", 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"vesselFill\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "All,", "1", ";", "dateRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ";", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["Column", 
      RGBColor[1, 0, 0]], 
     Style["Row", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["RadioButton", 
      RGBColor[1, 0, 0]], 
     Style["Enabled", 
      RGBColor[1, 0, 0]], "-", 
     Style["False", 
      RGBColor[1, 0, 0]], ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"", "Day", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Spacer", 
      RGBColor[1, 0, 0]], "13", ",", "i,", "1,", 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange", "All,", "1", ";;", "3", ",", "#4", "1",
      ";;", "3", "1,", "1", "-", "1", ",", 
     Style["RadioButtonBar", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "#1", ",", 
     Style["Table", 
      RGBColor[1, 0, 0]], "dateRange", "i,", "1", ";;", "3", "-", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Day", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", "i,", 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange", "All,", "1", ";;", "3", ",", "#4", "1",
      ";;", "3", "1,", "1", ",", 
     Style["Length", 
      RGBColor[1, 0, 0]], "dateRange", ",", 
     Style["Slider", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "#2", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Vessel", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "#3", "\"-\"", "#3", "/.", "vesselOrder", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], "&,", "shippingDateVars,", "fillVars,", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "shippingDateVars", ",", "vesselArrivalDates", 
     "All,", "2", ";", 
     Style["MarketPerDayLong", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["Row", 
      RGBColor[1, 0, 0]], 
     Style["MapIndexed", 
      RGBColor[1, 0, 0]], 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["InputField", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "#", ",", "Number,", 
     Style["FieldHint", 
      RGBColor[1, 0, 0]], "-", "\"0\",", 
     Style["ImageSize", 
      RGBColor[1, 0, 0]], "-", "35", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"", "Day", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "#2", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], "&,", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"marketValueLong\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", 
     Style["Text", 
      RGBColor[1, 0, 0]], 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Sell", "To", "Market\\n", 
     Style["Number", 
      RGBColor[1, 0, 0]], "of", "Parcels", "\",", 
     Style["TextAlignment", 
      RGBColor[1, 0, 0]], "-", "Center,", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", 
     Style["MarketPerDayShort", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], "lastVessel,", "shipmentDaysInfo,", 
     "totalVoyageDays", ",", "lastVessel", 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Last", 
      RGBColor[1, 0, 0]], 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "longLocation", ";", 
     "shipmentDaysInfo", 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "lastVessel", "&", ",", 
     "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "longLocation", "&&", 
     "#LocationTo", "shortLocation", "&", "1", ";", "totalVoyageDays", 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], "shipmentDaysInfo", "\"DaysLoading\",", 
     "\"DaysUnderway\",", "\"DockWait\",", "\"DaysUnloading\"", ";", 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["Row", 
      RGBColor[1, 0, 0]], 
     Style["MapIndexed", 
      RGBColor[1, 0, 0]], 
     Style["Labeled", 
      RGBColor[1, 0, 0]], 
     Style["InputField", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "#", ",", "Number,", 
     Style["FieldHint", 
      RGBColor[1, 0, 0]], "-", "\"0\",", 
     Style["ImageSize", 
      RGBColor[1, 0, 0]], "-", "35", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"", "Day", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "#2", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",Left", "&,", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "\"marketValueShort\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "totalVoyageDays", ",", 
     Style["Text", 
      RGBColor[1, 0, 0]], 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Purchase", "From", "Market", "\\n", 
     Style["Number", 
      RGBColor[1, 0, 0]], "of", "Parcels", "\",", 
     Style["TextAlignment", 
      RGBColor[1, 0, 0]], "-", "Center,", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\"", ",", 
     Style["Left", 
      RGBColor[1, 0, 0]], ";", 
     Style["SetInitialControls", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", "lastVessel", 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Last", 
      RGBColor[1, 0, 0]], 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "longLocation", ";", 
     "shipmentDaysInfo", 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "lastVessel", "&", ",", 
     "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "longLocation", "&&", 
     "#LocationTo", "shortLocation", "&", "1", ";", "totalVoyageDays", 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], "shipmentDaysInfo", "\"DaysLoading\",", 
     "\"DaysUnderway\",", "\"DockWait\",", "\"DaysUnloading\"", ";", 
     "initControls", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Waiting", "for", "initial", "controls\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "16", ";", 
     Style["Button", 
      RGBColor[1, 0, 0]], 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Set", "Initial", "Controls\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "16", ",", 
     Style["Clear", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Table", 
      RGBColor[1, 0, 0]], "\"marketValueLong\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ";", 
     Style["Clear", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Table", 
      RGBColor[1, 0, 0]], "\"marketValueShort\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "i", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "totalVoyageDays", ";", 
     Style["Clear", 
      RGBColor[1, 0, 0]], "#", "&", "/@", "\"vesselShippingDate\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "#", "&/@", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "longLocation", "All,", "1", 
     ";", 
     Style["Clear", 
      RGBColor[1, 0, 0]], "#", "&", "/@", "\"vesselFill\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "longLocation", "All,", "1", 
     ";", "initControls", 
     Style["Column", 
      RGBColor[1, 0, 0]], "*Vessel1ShippingControls", ",", 
     "Vessel2ShippingControls", ",*", 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["VesselShippingControls", 
      RGBColor[0, 0, 1]], ",", 
     Style["MarketPerDayLong", 
      RGBColor[0, 0, 1]], ",", 
     Style["MarketPerDayShort", 
      RGBColor[0, 0, 1]], ",", 
     Style["Spacings", 
      RGBColor[1, 0, 0]], "-", "1", ";", ",", 
     Style["Method", 
      RGBColor[1, 0, 0]], "-", "\"Queued\",", 
     Style["ImageSize", 
      RGBColor[1, 0, 0]], "-", "150,", "35", ";", 
     Style["Results", 
      RGBColor[0, 0, 1]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], 
     Style["Block", 
      RGBColor[1, 0, 0]], "dateRange,", "extendedDateRange", ",", "dateRange", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", "All,", "1", ";;", "3", ";", 
     "extendedDateRange", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "totalVoyageDays", "All,", "1", 
     ";;", "3", ";", "vdm", 
     Style["GenerateVoyageDecisionMatrix", 
      RGBColor[0, 0, 1]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow2", ",", "longLocation,", 
     "shortLocation,", "productID", ";", "lmdm", 
     Style["GenerateLongMarketDecisionMatrix", 
      RGBColor[0, 0, 1]], "longLocation,", "productID,", "dateRange", ";", 
     "smdm", 
     Style["GenerateShortMarketDecisionMatrix", 
      RGBColor[0, 0, 1]], "shortLocation,", "productID,", "extendedDateRange",
      ";", "svdm", 
     Style["GenerateShortVoyageDisplayMatrix", 
      RGBColor[0, 0, 1]], "vdm", ";", 
     Style["Grid", 
      RGBColor[1, 0, 0]], "vdm,", 
     Style["Column", 
      RGBColor[1, 0, 0]], "lmdm,", "smdm", ",Alignment-", "Left,Top", ";", 
     Style["SetAndShowResults", 
      RGBColor[0, 0, 1]], 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", "longLocation", "\"PAR\";", "shortLocation", 
     "\"NOR\";", "productID", "\"LSVGO\";", "timeWindow1", "\"05/01/2015\";", 
     "timeWindow2", "\"05/10/2015\";", 
     Style["Grid", 
      RGBColor[1, 0, 0]], 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Initial", "Controls\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "18,", 
     Style["Bold", 
      RGBColor[1, 0, 0]], ",", 
     Style["ProductID", 
      RGBColor[0, 0, 1]], ",", 
     Style["LongLocation", 
      RGBColor[0, 0, 1]], ",", 
     Style["ShortLocation", 
      RGBColor[0, 0, 1]], ",", 
     Style["TimeWindow", 
      RGBColor[0, 0, 1]], ",", 
     Style["SetInitialControls", 
      RGBColor[0, 0, 1]], ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Secondary", "Controls\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "18,", 
     Style["Bold", 
      RGBColor[1, 0, 0]], ",", 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], "initControls", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Results\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "18,", 
     Style["Bold", 
      RGBColor[1, 0, 0]], ",", 
     Style["Evaluate", 
      RGBColor[1, 0, 0]], 
     Style["Dynamic", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], "initControls", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Waiting", "for", "initial", "controls\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "16", ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Waiting", "for", "input\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", "16", ",", 
     Style["Results", 
      RGBColor[0, 0, 1]], ",", 
     Style["Alignment", 
      RGBColor[1, 0, 0]], "-", "Left,", 
     Style["Top", 
      RGBColor[1, 0, 0]], ",", 
     Style["Spacings", 
      RGBColor[1, 0, 0]], "-", ",", "0,", "1,", "1,", "1,", "1,", "1,", "3", 
     "*End", "of", "inital", "controls*", ",", "2,", "3,", "2", ",", 
     Style["Dividers", 
      RGBColor[1, 0, 0]], "-", ",", "7", "-", 
     Style["Darker", 
      RGBColor[1, 0, 0]], "Gray,", ".4", ",", "-3", "-", 
     Style["Darker", 
      RGBColor[1, 0, 0]], "Gray,", ".4", ";", 
     Style["GenerateShortVoyageDisplayMatrix", 
      RGBColor[0, 0, 1]], "vdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "vesselsUnordered,", "vessels,", 
     "shipmentDaysInfo,", "totalVoyageDaysPerVessel,", "arrivalDates,", 
     "dateRange,", "timeWindow,", "periodRange", ",", "vesselsUnordered", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Sent", "!", "\"-\"", "&", ",", "|\"EquipmentID\"",
      "-", "#,", "\"Date\"", "-", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", "1", ";;", "3", ",", 
     "\"LocationID\"", "-", "longLocation,", "\"ProductID\"", "-", 
     "productID,", "\"Sent\"", "-", "shortLocation,", "\"AmountShipped\"", 
     "-", "0|", "&", "/@", 
     Style["Complement", 
      RGBColor[1, 0, 0]], "vesselOrder", "All,", "2", ",", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Sent", "!", "\"-\"", "&", "All,", 
     "\"EquipmentID\"", ";", "vessels", "vesselsUnordered", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vesselsUnordered", "All,", "\"EquipmentID\"", "/.", 
     Style["Reverse", 
      RGBColor[1, 0, 0]], "/@", "vesselOrder", ";", "shipmentDaysInfo", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "vessels", "i,", "\"EquipmentID\"", 
     "&", ",", "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "vessels", 
     "i,", "\"LocationID\"", "&&", "#LocationTo", "vessels", "i,", "\"Sent\"",
      "&", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "vessels", ";", "totalVoyageDaysPerVessel", 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], "#", "\"DaysLoading\",", "\"DaysUnderway\",", 
     "\"DockWait\",", "\"DaysUnloading\"", "&", "/@", "shipmentDaysInfo", ";",
      "arrivalDates", 
     Style["Association", 
      RGBColor[1, 0, 0]], "/@", 
     Style["MapIndexed", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#1", "\"EquipmentID\"", 
     ",", "\"Date\"", "-", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "#1", "\"Date\"", ",", "totalVoyageDaysPerVessel", 
     Style["First", 
      RGBColor[1, 0, 0]], "#2", ",", "\"AmountRecieved\"", "-", "#1", 
     "\"AmountShipped\"", "&,", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vessels", ";", "dateRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "timeWindow1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "vdm", "Last,", "\"Date\"", ",", 
     Style["Max", 
      RGBColor[1, 0, 0]], "totalVoyageDaysPerVessel", ";", "timeWindow", 
     Style["DateList", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "dateRange", ",", 
     Style["DateList", 
      RGBColor[1, 0, 0]], 
     Style["Last", 
      RGBColor[1, 0, 0]], "dateRange", ";", "periodRange", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"LocationID\"", "-", "#", "3", ",", 
     "\"ProductID\"", "-", "#", "4", ",", "\"AmountRecieved\"", "-", "#", "5",
      "&", "/@", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Sort", 
      RGBColor[1, 0, 0]], 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], 
     Style["Tuples", 
      RGBColor[1, 0, 0]], "#", "\"EquipmentID\"", ",", 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], "periodRange,", "#", "\"Date\"", ",", 
     "shortLocation", ",", "productID", ",", "0", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Head", 
      RGBColor[1, 0, 0]], "#", "\"Date\"", "Symbol,", ",", "#", 
     "\"EquipmentID\"", ",", "#", "\"Date\"", ",", "shortLocation,", 
     "productID,", "#", "\"AmountRecieved\"", ",", "&", "/@", "arrivalDates,",
      "1", ";", 
     Style["RecievedInventory", 
      RGBColor[0, 0, 1]], "equipmentID_,", "svdm_", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "svdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"AmountRecieved\"", ";", 
     Style["ShippedInventory", 
      RGBColor[0, 0, 1]], "equipmentID_,", "vdm_", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"AmountShipped\"", ";", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "locationID_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dateRange", ",", "dateRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     Style["ToExpression", 
      RGBColor[1, 0, 0]], "/@", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["MarketPrice", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#LocationID", "locationID", "&&", "#ProductID", 
     "productID", "&&", "#Date", "dateRange", "i", "&", ",", 
     "\"DeliveredPrice\"", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "dateRange", ";", 
     Style["CalculateSpreadValue", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "longLocation_,", 
     "shortLocation_,", "vesselOrder_,", "totalVoyageDays_,", "vdm_,", 
     "svdm_", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["RecievedInventory", 
      RGBColor[0, 0, 1]], "#,", "svdm", ".FindMarketPrices", "timeWindow", 
     "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "totalVoyageDays", ",", 
     "productID,", "shortLocation", "-", 
     Style["ShippedInventory", 
      RGBColor[0, 0, 1]], "#,", "vdm", ".FindMarketPrices", "timeWindow", "1",
      ",", "timeWindow", "2", ",", "productID,", "longLocation", "&", "/@", 
     "vesselOrder", "All,", "2", ";", 
     Style["CalculateIntransitInventory", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "shortLocation_,", 
     "vesselOrder_,", "totalVoyageDays_,", "vdm_,", "svdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dayRange,", "startingIntransitInventory,", 
     "shipped,", "recieved,", "shippedPadded", ",", "dayRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "totalVoyageDays", ";", 
     "startingIntransitInventory", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "dayRange", "1", ",", "productID,", "shortLocation",
      ";", "shipped", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], "Plus,", 
     Style["ShippedInventory", 
      RGBColor[0, 0, 1]], "#,", "vdm", "&", "/@", "vesselOrder", "All,", "2", 
     ";", "recieved", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], "Plus,", 
     Style["RecievedInventory", 
      RGBColor[0, 0, 1]], "#,", "svdm", "&", "/@", "vesselOrder", "All,", "2",
      ";", "shippedPadded", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], "shipped,", 
     Style["ConstantArray", 
      RGBColor[1, 0, 0]], "0,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "recieved", "-", 
     Style["Length", 
      RGBColor[1, 0, 0]], "shipped", ";", 
     Style["FoldList", 
      RGBColor[1, 0, 0]], "#1", "+", "shippedPadded", 
     Style["Position", 
      RGBColor[1, 0, 0]], "dayRange,", "#2", "1,", "1", "-", "recieved", 
     Style["Position", 
      RGBColor[1, 0, 0]], "dayRange,", "#2", "1,", "1", "-", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "shortLocation", "&,", 
     "startingIntransitInventory,", "dayRange", ";", 
     Style["CalculateWorkingCapitalCost", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "longLocation_,", 
     "shortLocation_,", "vesselOrder_,", "totalVoyageDays_,", "vdm_,", 
     "svdm_,", "lmdm_,", "smdm_", "workingCapitalCharge", "/", "365", "*", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "timeWindow", "2", ",", 
     "productID,", "longLocation", ".", 
     Style["Drop", 
      RGBColor[1, 0, 0]], 
     Style["CalculateNetInventoryLong", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "lmdm", ",", "1", "+", "workingCapitalCharge", "/", "365", "*", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "totalVoyageDays", ",", 
     "productID,", "shortLocation", ".", 
     Style["Drop", 
      RGBColor[1, 0, 0]], 
     Style["CalculateNetInventoryShort", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "timeWindow", "2", ",", 
     "productID,", "shortLocation,", "svdm,", "smdm", ",", "1", "+", 
     "workingCapitalCharge", "/", "365", "*", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "totalVoyageDays", ",", 
     "productID,", "longLocation", ".", 
     Style["Drop", 
      RGBColor[1, 0, 0]], 
     Style["CalculateIntransitInventory", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "timeWindow", "2", ",", 
     "productID,", "shortLocation,", "vesselOrder,", "totalVoyageDays,", 
     "vdm,", "svdm", ",", "1", ";", 
     Style["GetCharterRate", 
      RGBColor[0, 0, 1]], "equipmentID_", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"CharterRatePerDay\"", "1", ";", 
     Style["FindVesselFill", 
      RGBColor[0, 0, 1]], "equipmentID_,", "vdm_", "N", 
     Style["Total", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID&", ",", 
     "\"AmountShipped\"", "/GetVesselCapacity", "equipmentID", ";", 
     Style["CalculateSubleasCredit", 
      RGBColor[0, 0, 1]], "timeWindow_,", "locationID_,", 
     "shippingDateVars_,", "vdm_", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["MapThread", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["FindVesselFill", 
      RGBColor[0, 0, 1]], "#1", "1", ",", "vdm", "0", "&&", 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", "timeWindow", "2", 
     "1", ";;", "3", "1", "7,", 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", "timeWindow", "2", 
     "1", ";;", "3", "1", "*", 
     Style["GetCharterRate", 
      RGBColor[0, 0, 1]], "#1", "1", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", "#2", "1", "7,", 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", "#2", "1", "*", 
     Style["GetCharterRate", 
      RGBColor[0, 0, 1]], "#1", "1", ",", "0", "&,", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "timeWindow", "2", ",", 
     "locationID", ",", "shippingDateVars", ";", 
     Style["ShippedPerDay", 
      RGBColor[0, 0, 1]], "equipmentID_,", "vdm_", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"AmountShipped\"", ";", 
     Style["RecievedPerDay", 
      RGBColor[0, 0, 1]], "equipmentID_,", "svdm_", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "svdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "equipmentID", "&", ",", 
     "\"AmountRecieved\"", ";", 
     Style["CalculateInventoryHoldingMargin", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "shortLocation_,", 
     "longLocation_,", "vdm_,", "svdm_,", "lmdm_,", "smdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "longInventory,", "longMarketPrices,", 
     "longSoldToMarket,", "shortInventory,", "shortMarketPrices,", 
     "shortPurchasedFromMarket,", "dayRange", ",", "longInventory", 
     Style["CalculateNetInventoryLong", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "lmdm", ";", "longMarketPrices", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation", ";", 
     "longSoldToMarket", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "lmdm", "All,", "\"SoldToMarket\"", ";", 
     "shortInventory", 
     Style["CalculateNetInventoryShort", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "svdm,", "smdm", ";", "shortMarketPrices", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "7", ",", "productID,", 
     "shortLocation", ";", "shortPurchasedFromMarket", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "smdm", "All,", "\"PurchasedFromMarket\"", ";", 
     "dayRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "7", ";", 
     Style["Last", 
      RGBColor[1, 0, 0]], "longInventory", "*", 
     Style["Last", 
      RGBColor[1, 0, 0]], "longMarketPrices", "+", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["ShippedPerDay", 
      RGBColor[0, 0, 1]], "#,", "vdm", "&", "/@", "vesselOrder", "All,", "2", 
     ",", "longSoldToMarket,", "longSoldToMarket*Parameters", "All,", 
     "\"ParameterValue\"", "1", ".longMarketPrices", "-", 
     Style["First", 
      RGBColor[1, 0, 0]], "longInventory", "*", 
     Style["First", 
      RGBColor[1, 0, 0]], "longMarketPrices", "+", 
     Style["GetDailyProduction", 
      RGBColor[0, 0, 1]], "#,", "productID,", "longLocation", "&", "/@", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", 
     ".longMarketPrices", "+", 
     Style["Last", 
      RGBColor[1, 0, 0]], "shortInventory", "*", 
     Style["Last", 
      RGBColor[1, 0, 0]], "shortMarketPrices", "+", 
     Style["GetDailyConsumption", 
      RGBColor[0, 0, 1]], "#,", "productID,", "shortLocation", "&", "/@", 
     "dayRange", ".shortMarketPrices", "-", 
     Style["First", 
      RGBColor[1, 0, 0]], "shortInventory", "*", 
     Style["First", 
      RGBColor[1, 0, 0]], "shortMarketPrices", "+", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["RecievedPerDay", 
      RGBColor[0, 0, 1]], "#,", "svdm", "&", "/@", "vesselOrder", "All,", "2",
      ",", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#,", "productID,", "shortLocation", "&", "/@", 
     "dayRange", ".shortMarketPrices", "+", "shortPurchasedFromMarket", "*", 
     Style["Parameters", 
      RGBColor[0, 0, 1]], "All,", "\"ParameterValue\"", "1", 
     ".shortMarketPrices", ";", 
     Style["ObjectiveValue", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "longLocation_,", 
     "shortLocation_,vdm_,", "svdm_,", "lmdm_,", "smdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", 
     Style["GenerateDepartingInventory", 
      RGBColor[0, 0, 1]], "vdm", ";", 
     Style["CalculateSpreadValue", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselOrder,", "totalVoyageDays,", "vdm,", "svdm", 
     "-", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["CalculateTransportCost", 
      RGBColor[0, 0, 1]], "vdm", "All,", "\"TransportCost\"", "-", 
     Style["CalculateWorkingCapitalCost", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselOrder,", "totalVoyageDays,", "vdm,", "svdm,", 
     "lmdm,", "smdm", "+", 
     Style["CalculateInventoryHoldingMargin", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "longLocation,", "vdm,", "svdm,", "lmdm,", "smdm", "+", 
     Style["CalculateSubleasCredit", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation,", "shippingDateVars,",
      "vdm", ";", "*PerPath", "Functions*", 
     Style["AddDayToPath", 
      RGBColor[0, 0, 1]], "growingPath_List,", "vesselArrivalDays_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "currentDay,", "availableVessels,", "allOptions", 
     ",", "currentDay", 
     Style["Length", 
      RGBColor[1, 0, 0]], "growingPath", "2", "+", "1;", "availableVessels", 
     Style["Join", 
      RGBColor[1, 0, 0]], "growingPath", "1", ",", 
     Style["Keys", 
      RGBColor[1, 0, 0]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "vesselArrivalDays,", "#", "currentDay", "&", ";", 
     "allOptions", 
     Style["Subsets", 
      RGBColor[1, 0, 0]], "availableVessels", ";", 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Complement", 
      RGBColor[1, 0, 0]], "availableVessels,", "#", ",", 
     Style["Append", 
      RGBColor[1, 0, 0]], "growingPath", "2", ",", "#", "&,", "allOptions", 
     ";", 
     Style["AddDayToPaths", 
      RGBColor[0, 0, 1]], "growingPaths_List,", "vesselArrivalDays_", 
     Style["Block", 
      RGBColor[1, 0, 0]], ",", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["AddDayToPath", 
      RGBColor[0, 0, 1]], "#,", "vesselArrivalDays", "&,", "growingPaths", 
     ",", "1", ";", 
     Style["GenerateAllPaths", 
      RGBColor[0, 0, 1]], "date1_,", "date2_,", "longLocation_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "timeWindow,", "dayRange,", "timePeriodLength,", 
     "vesselArrivalDates,", "vesselArrivalDays,", 
     "vesselArrivalDaysAssociation", ",", "timeWindow", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date2", ";", "dayRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     "timePeriodLength", 
     Style["Length", 
      RGBColor[1, 0, 0]], "dayRange", ";", "vesselArrivalDates", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow,", "\"PAR\"", ";", "vesselArrivalDays", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "dayRange", "All,", "1", ";;", "3", ",", "#", "&", 
     "/@", "vesselArrivalDates", "All,", "2,", "1", ";;", "3", ";", 
     "vesselArrivalDaysAssociation", 
     Style["Association", 
      RGBColor[1, 0, 0]], 
     Style["Table", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "i,", "1", "-", 
     "vesselArrivalDays", "i", ",", "i,", "1,Length", "vesselArrivalDates", 
     ";", 
     Style["Nest", 
      RGBColor[1, 0, 0]], 
     Style["AddDayToPaths", 
      RGBColor[0, 0, 1]], "#,", "vesselArrivalDaysAssociation", "&,", ",", 
     ",", "timePeriodLength", "All,", "2", ";", 
     Style["GenerateVoyageDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "longLocation_,", "shortLocation_,",
      "productID_,", "vesselOrder_,", "fillVars_,", "path_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "shippingDateVars,", "voyageMap,", "voyageRules", 
     ",", "shippingDateVars", 
     Style["ShippingDateVars", 
      RGBColor[0, 0, 1]], "timeWindow,", "path,", "vesselOrder", ";", 
     "voyageMap", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["MapThread", 
      RGBColor[1, 0, 0]], 
     Style["SingleVesselVDM", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation,", "shortLocation,", 
     "productID,", "#3", "/.", "vesselOrder,", "#1,", "#2", "&,", 
     "shippingDateVars,", 
     Style["Values", 
      RGBColor[1, 0, 0]], "fillVars", ",", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "shippingDateVars", ",", "1", ";", "voyageRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"LocationID\"", "-", "#", "3", ",", 
     "\"ProductID\"", "-", "#", "4", ",", "\"Sent\"", "-", "#", "5", ",", 
     "\"AmountShipped\"", "-", "#", "6", "&,", "voyageMap", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "voyageRules", ";", 
     Style["GenerateShortVoyageDisplayMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "longLocation_,", 
     "shortLocation_,", "vesselArrivalDates_,", "vesselOrder_,", "vdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "vesselsUnordered,", "vessels,", 
     "shipmentDaysInfo,", "totalVoyageDaysPerVessel,", "arrivalDates,", 
     "dateRange,", "periodRange", ",", "vesselsUnordered", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Sent", "!", "\"-\"", "&", ",", "|\"EquipmentID\"",
      "-", "#,", "\"Date\"", "-", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "timeWindow", "1", "1", ";;", "3", ",", 
     "\"LocationID\"", "-", "longLocation,", "\"ProductID\"", "-", 
     "productID,", "\"Sent\"", "-", "shortLocation,", "\"AmountShipped\"", 
     "-", "0|", "&", "/@", 
     Style["Complement", 
      RGBColor[1, 0, 0]], "vesselOrder", "All,", "2", ",", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vdm", 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Sent", "!", "\"-\"", "&", "All,", 
     "\"EquipmentID\"", ";", "vessels", "vesselsUnordered", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vesselsUnordered", "All,", "\"EquipmentID\"", "/.", 
     Style["Reverse", 
      RGBColor[1, 0, 0]], "/@", "vesselOrder", ";", "shipmentDaysInfo", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "vessels", "i,", "\"EquipmentID\"", 
     "&", ",", "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "vessels", 
     "i,", "\"LocationID\"", "&&", "#LocationTo", "vessels", "i,", "\"Sent\"",
      "&", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "vessels", ";", "totalVoyageDaysPerVessel", 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], "#", "\"DaysLoading\",", "\"DaysUnderway\",", 
     "\"DockWait\",", "\"DaysUnloading\"", "&", "/@", "shipmentDaysInfo", ";",
      "arrivalDates", 
     Style["Association", 
      RGBColor[1, 0, 0]], "/@", 
     Style["MapIndexed", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#1", "\"EquipmentID\"", 
     ",", "\"Date\"", "-", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "#1", "\"Date\"", ",", "totalVoyageDaysPerVessel", 
     Style["First", 
      RGBColor[1, 0, 0]], "#2", ",", "\"AmountRecieved\"", "-", "#1", 
     "\"AmountShipped\"", "&,", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "vessels", ";", "dateRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "vdm", "First,", "\"Date\"", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "vdm", "Last,", "\"Date\"", ",", 
     Style["Max", 
      RGBColor[1, 0, 0]], "totalVoyageDaysPerVessel", ";", "periodRange", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], 
     Style["DateList", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "dateRange", ",", 
     Style["DateList", 
      RGBColor[1, 0, 0]], 
     Style["Last", 
      RGBColor[1, 0, 0]], "dateRange", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "\"EquipmentID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"LocationID\"", "-", "#", "3", ",", 
     "\"ProductID\"", "-", "#", "4", ",", "\"AmountRecieved\"", "-", "#", "5",
      "&", "/@", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Sort", 
      RGBColor[1, 0, 0]], 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], 
     Style["Tuples", 
      RGBColor[1, 0, 0]], "#", "\"EquipmentID\"", ",", 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], "periodRange,", "#", "\"Date\"", ",", 
     "shortLocation", ",", "productID", ",", "0", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Head", 
      RGBColor[1, 0, 0]], "#", "\"Date\"", "Symbol,", ",", "#", 
     "\"EquipmentID\"", ",", "#", "\"Date\"", ",", "shortLocation,", 
     "productID,", "#", "\"AmountRecieved\"", ",", "&", "/@", "arrivalDates,",
      "1", ";", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "locationID_", 
     Style["InventoryThreshold", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#LocationID", "locationID", "&", ",", 
     "\"MaxInventory\"", "1", ";", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "locationID_", 
     Style["InventoryThreshold", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#LocationID", "locationID", "&", ",", 
     "\"MinInventory\"", "1", ";", 
     Style["CalculateNetInventoryLongPerPath", 
      RGBColor[0, 0, 1]], "longInventoryAndMarket_List", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "longInventoryAndMarket", ",", 
     Style["First", 
      RGBColor[1, 0, 0]], "/@", 
     Style["Rest", 
      RGBColor[1, 0, 0]], "longInventoryAndMarket", ";", 
     Style["GenerateLongMarketDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "locationID_,", 
     "longInventoryAndMarket_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dateRange,", "marketData,", "marketRules", ",", 
     "dateRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "timeWindow", "1", "1", ";;", "3", ",", 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "timeWindow", "2", "1", ";;", "3", ";", 
     "marketData", "locationID,", "#,", "productID,", "m", "/.", 
     Style["Last", 
      RGBColor[1, 0, 0]], "longInventoryAndMarket", 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange,", "#", "1,", "1", "+", "1", "&", "/@", 
     "dateRange;", "marketRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"LocationID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"ProductID\"", "-", "#", "3", ",", 
     "\"SoldToMarket\"", "-", "#", "4", "&,", "marketData", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "marketRules", ";", 
     Style["CalculateMarketValueLongNeeded", 
      RGBColor[0, 0, 1]], "currentInventory_,", "maxInventory_,", 
     "minInventory_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "solution,", "correctCurrentInventory", ",", 
     "correctCurrentInventory", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["ListQ", 
      RGBColor[1, 0, 0]], "currentInventory", ",", 
     Style["First", 
      RGBColor[1, 0, 0]], "currentInventory", ",", "currentInventory", ";", 
     "solution", 
     Style["Quiet", 
      RGBColor[1, 0, 0]], 
     Style["Maximize", 
      RGBColor[1, 0, 0]], "correctCurrentInventory", "-", "volumePerUnit*m", 
     ",", "correctCurrentInventory", "-", "volumePerUnit*m", "minInventory", 
     "&&", "correctCurrentInventory", "-", "volumePerUnit*m", "maxInventory", 
     "&&", "m", "0", "&&", "m", "\\", 
     Style["Element", 
      RGBColor[1, 0, 0]], "Integers,", "m", ";", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["NumberQ", 
      RGBColor[1, 0, 0]], "m", "/.", 
     Style["Last", 
      RGBColor[1, 0, 0]], "solution", ",", "solution,", "Null,", "m", "-", 
     "0", ";", 
     Style["NetInventoryAndMarketValuesLongPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "locationID_,", 
     "maxInventory_,", "minInventory_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dayRange,", "startingInventory", ",", "dayRange", 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["DateList", 
      RGBColor[1, 0, 0]], "#", "&,", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     "startingInventory", 
     Style["GetStartingInventory", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "productID,", "locationID", 
     ";", 
     Style["Quiet", 
      RGBColor[1, 0, 0]], 
     Style["FoldList", 
      RGBColor[1, 0, 0]], 
     Style["CalculateMarketValueLongNeeded", 
      RGBColor[0, 0, 1]], "#1", "+", 
     Style["GetDailyProduction", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "locationID", "-", 
     Style["GetDepartingInventory", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "locationID", "+", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "locationID", ",", 
     "maxInventory,", "minInventory", "&,", "startingInventory,", "dayRange", 
     ";", 
     Style["CalculateNetInventoryShortPerPath", 
      RGBColor[0, 0, 1]], "shortInventoryAndMarket_List", 
     Style["Flatten", 
      RGBColor[1, 0, 0]], 
     Style["Append", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "shortInventoryAndMarket", ",", 
     Style["First", 
      RGBColor[1, 0, 0]], "/@", 
     Style["Rest", 
      RGBColor[1, 0, 0]], "shortInventoryAndMarket", ";", 
     Style["GenerateShortMarketDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "locationID_,", 
     "longInventoryAndMarket_,", "totalVoyageDays_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dateRange,", "marketData,", "marketRules", ",", 
     "dateRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "timeWindow", "1", "1", ";;", "3", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], 
     Style["DateObject", 
      RGBColor[1, 0, 0]], "timeWindow", "2", "1", ";;", "3", ",", 
     "totalVoyageDays", ";", "marketData", "locationID,", "#,", "productID,", 
     "m", "/.", 
     Style["Last", 
      RGBColor[1, 0, 0]], "longInventoryAndMarket", 
     Style["Position", 
      RGBColor[1, 0, 0]], "dateRange,", "#", "1,", "1", "+", "1", "&", "/@", 
     "dateRange;", "marketRules", 
     Style["Map", 
      RGBColor[1, 0, 0]], "\"LocationID\"", "-", "#", "1", ",", "\"Date\"", 
     "-", "#", "2", ",", "\"ProductID\"", "-", "#", "3", ",", 
     "\"PurchasedFromMarket\"", "-", "#", "4", "&,", "marketData", ";", 
     Style["Dataset", 
      RGBColor[1, 0, 0]], 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["Association", 
      RGBColor[1, 0, 0]], "#", "&,", "marketRules", ";", 
     Style["NetInventoryAndMarketValuesShortPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "locationID_,", 
     "maxInventory_,", "minInventory_,", "svdm_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "dayRange,", "startingInventory", ",", "dayRange", 
     Style["Map", 
      RGBColor[1, 0, 0]], 
     Style["DateList", 
      RGBColor[1, 0, 0]], "#", "&,", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "7", ";", 
     "startingInventory", 
     Style["GetStartingInventory", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "productID,", "locationID", 
     ";", 
     Style["Quiet", 
      RGBColor[1, 0, 0]], 
     Style["FoldList", 
      RGBColor[1, 0, 0]], 
     Style["CalculateMarketValueShortNeeded", 
      RGBColor[0, 0, 1]], "#1", "-", 
     Style["GetDailyConsumption", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "locationID", "+", 
     Style["GetRecievingInventory", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "locationID,", "svdm", "+", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#2,", "productID,", "locationID", ",", 
     "maxInventory,", "minInventory", "&,", "startingInventory,", "dayRange", 
     ";", 
     Style["CalculateMarketValueShortNeeded", 
      RGBColor[0, 0, 1]], "currentInventory_,", "maxInventory_,", 
     "minInventory_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "solution,", "correctCurrentInventory", ",", 
     "correctCurrentInventory", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["ListQ", 
      RGBColor[1, 0, 0]], "currentInventory", ",", 
     Style["First", 
      RGBColor[1, 0, 0]], "currentInventory", ",", "currentInventory", ";", 
     "solution", 
     Style["Quiet", 
      RGBColor[1, 0, 0]], 
     Style["Minimize", 
      RGBColor[1, 0, 0]], "correctCurrentInventory", "+", "volumePerUnit*m", 
     ",", "correctCurrentInventory", "+", "volumePerUnit*m", "minInventory", 
     "&&", "correctCurrentInventory", "+", "volumePerUnit*m", "maxInventory", 
     "&&", "m", "0", "&&", "m", "\\", 
     Style["Element", 
      RGBColor[1, 0, 0]], "Integers,", "m", ";", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["NumberQ", 
      RGBColor[1, 0, 0]], "m", "/.", 
     Style["Last", 
      RGBColor[1, 0, 0]], "solution", ",", "solution,", "Null,", "m", "-", 
     "0", ";", 
     Style["CalculateInventoryHoldingMarginPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "shortLocation_,", 
     "longLocation_,", "vesselOrder_,", "vdm_,", "svdm_,", "lmdm_,", "smdm_,",
      "longInventoryAndMarket_,", "shortInventoryAndMarket_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "longInventory,", "longMarketPrices,", 
     "longSoldToMarket,", "shortInventory,", "shortMarketPrices,", 
     "shortPurchasedFromMarket,", "dayRange", ",", "longInventory", 
     Style["CalculateNetInventoryLongPerPath", 
      RGBColor[0, 0, 1]], "longInventoryAndMarket", ";", "longMarketPrices", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation", ";", 
     "longSoldToMarket", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "lmdm", "All,", "\"SoldToMarket\"", ";", 
     "shortInventory", 
     Style["CalculateNetInventoryShortPerPath", 
      RGBColor[0, 0, 1]], "shortInventoryAndMarket", ";", "shortMarketPrices", 
     Style["FindMarketPrices", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "7", ",", "productID,", 
     "shortLocation", ";", "shortPurchasedFromMarket", 
     Style["Normal", 
      RGBColor[1, 0, 0]], "smdm", "All,", "\"PurchasedFromMarket\"", ";", 
     "dayRange", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", "7", ";", 
     Style["Last", 
      RGBColor[1, 0, 0]], "longInventory", "*Last", "longMarketPrices", "+", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["ShippedPerDay", 
      RGBColor[0, 0, 1]], "#,", "vdm", "&", "/@", "vesselOrder", "All,", "2", 
     ",", "longSoldToMarket,", "longSoldToMarket*", 
     Style["Parameters", 
      RGBColor[0, 0, 1]], "All,", "\"ParameterValue\"", "1", 
     ".longMarketPrices", "-", 
     Style["First", 
      RGBColor[1, 0, 0]], "longInventory", "*", 
     Style["First", 
      RGBColor[1, 0, 0]], "longMarketPrices", "+", 
     Style["GetDailyProduction", 
      RGBColor[0, 0, 1]], "#,", "productID,", "longLocation", "&", "/@", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", 
     ".longMarketPrices", "+", 
     Style["Last", 
      RGBColor[1, 0, 0]], "shortInventory", "*", 
     Style["Last", 
      RGBColor[1, 0, 0]], "shortMarketPrices", "+", 
     Style["GetDailyConsumption", 
      RGBColor[0, 0, 1]], "#,", "productID,", "shortLocation", "&", "/@", 
     "dayRange", ".shortMarketPrices", "-", 
     Style["First", 
      RGBColor[1, 0, 0]], "shortInventory", "*", 
     Style["First", 
      RGBColor[1, 0, 0]], "shortMarketPrices", "+", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["Join", 
      RGBColor[1, 0, 0]], 
     Style["RecievedPerDay", 
      RGBColor[0, 0, 1]], "#,", "svdm", "&", "/@", "vesselOrder", "All,", "2",
      ",", 
     Style["GetVoyageCommit", 
      RGBColor[0, 0, 1]], "#,", "productID,", "shortLocation", "&", "/@", 
     "dayRange", ".shortMarketPrices", "+", "shortPurchasedFromMarket*", 
     Style["Parameters", 
      RGBColor[0, 0, 1]], "All,", "\"ParameterValue\"", "1", 
     ".shortMarketPrices", ";", 
     Style["ShippingDateVars", 
      RGBColor[0, 0, 1]], "timeWindow_,", "path_,", "vesselOrder_", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", "1", ";;", "3", ",", 
     "timeWindow", "2", "1", ";;", "3", "#", "2", "&", "/@", 
     Style["Table", 
      RGBColor[1, 0, 0]], "i", "/.", "vesselOrder", "-", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "path,", "i", "/.", "vesselOrder", "0,", 
     Style["Position", 
      RGBColor[1, 0, 0]], "path,", "i", "/.", "vesselOrder", "1,", "1", ",", 
     Style["Position", 
      RGBColor[1, 0, 0]], "path,", "i", "/.", "vesselOrder", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselOrder", ";", 
     Style["CalculateSubleasCreditPerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "longLocation_,", "fillVars_,", 
     "vesselOrder_,", "path_", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["MapThread", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], "#1", "1", "/.", "fillVars", "0", "&&", 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", "timeWindow", "2", 
     "1", ";;", "3", "1", "7,", 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", "timeWindow", "2", 
     "1", ";;", "3", "1", "*GetCharterRate", "#1", "1", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#2", "0,", "timeWindow", "1", "1", ";;", "3", ",", 
     "#2", "1", "7,", 
     Style["DateDifference", 
      RGBColor[1, 0, 0]], "#1", "2,", "1", ";;", "3", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#2", "0,", "timeWindow", "2", "1", ";;", "3", ",", 
     "#2", "1", "*GetCharterRate", "#1", "1", ",", "0", "&,", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow", "1", ",", "timeWindow", "2", ",", 
     "longLocation", ",", 
     Style["ShippingDateVars", 
      RGBColor[0, 0, 1]], "timeWindow,", "path,", "vesselOrder", ";", 
     Style["ObjectiveValuePerPath", 
      RGBColor[0, 0, 1]], "timeWindow_,", "productID_,", "longLocation_,", 
     "shortLocation_,", "vesselArrivalDates_,", "vesselOrder_,", 
     "totalVoyageDays_,", "fillPercent_,", "path_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "vdm,", "svdm,", "longMaxInventory,", 
     "longMinInventory,", "shortMaxInventory,", "shortMinInventory,", 
     "longInventoryAndMarket,", "shortInventoryAndMarket,", "lmdm,", "smdm", 
     ",", "vdm", 
     Style["GenerateVoyageDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation,", "shortLocation,", 
     "productID,", "vesselOrder,", "fillPercent,", "path", ";", "svdm", 
     Style["GenerateShortVoyageDisplayMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselArrivalDates,", "vesselOrder,", "vdm", ";", 
     Style["GenerateDepartingInventory", 
      RGBColor[0, 0, 1]], "vdm", ";", "longMaxInventory", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "longLocation", ";", "longMinInventory", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "longLocation", ";", "shortMaxInventory", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "shortLocation", ";", "shortMinInventory", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "shortLocation", ";", "longInventoryAndMarket", 
     Style["NetInventoryAndMarketValuesLongPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "longMaxInventory,", "longMinInventory", ";", "shortInventoryAndMarket", 
     Style["NetInventoryAndMarketValuesShortPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "shortMaxInventory,", "shortMinInventory,", "svdm", ";", "lmdm", 
     Style["GenerateLongMarketDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "longInventoryAndMarket", ";", "smdm", 
     Style["GenerateShortMarketDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "shortInventoryAndMarket,", "totalVoyageDays", ";", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["NumberQ", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "/@", 
     Style["Rest", 
      RGBColor[1, 0, 0]], "longInventoryAndMarket", "&&", 
     Style["NumberQ", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], "/@", 
     Style["Rest", 
      RGBColor[1, 0, 0]], "shortInventoryAndMarket", ",", 
     Style["CalculateSpreadValue", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselOrder,", "totalVoyageDays,", "vdm,", "svdm", 
     "-", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["CalculateTransportCost", 
      RGBColor[0, 0, 1]], "vdm", "All,", "\"TransportCost\"", "-", 
     Style["CalculateWorkingCapitalCost", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselOrder,", "totalVoyageDays,", "vdm,", "svdm,", 
     "lmdm,", "smdm", "+", 
     Style["CalculateInventoryHoldingMarginPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "longLocation,", "vesselOrder,", "vdm,", "svdm,", "lmdm,", "smdm,", 
     "longInventoryAndMarket,", "shortInventoryAndMarket", "+", 
     Style["CalculateSubleasCreditPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation,", "fillPercent,", 
     "vesselOrder,", "path", ",", "\"No", "Solution\"", ";", 
     Style["ObjectiveValueOverPaths", 
      RGBColor[0, 0, 1]], "date1_,", "date2_,", "productID_,", 
     "longLocation_,", "shortLocation_,", "paths_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "timeWindow,vesselArrivalDates,", "vesselOrder,", 
     "totalVoyageDays,", "fillPercent", ",", "timeWindow", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date2", ";", "vesselArrivalDates", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation", ";", "vesselOrder", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], "#2", "-", "#1", "&,", "vesselArrivalDates", "All,",
      "1", ",", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "All,", "1", ";", 
     "totalVoyageDays", 
     Style["Max", 
      RGBColor[1, 0, 0]], 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "vesselOrder", "All,", "2", "i", 
     "&", ",", "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "longLocation",
      "&&", "#LocationTo", "shortLocation", "&", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselOrder", "All,", "2", ";", "fillPercent", "#",
      "2", "-", "1", "*Will", "be", "changed", "to", "a", "rule", "depending",
      "on", "heuristic*", "&", "/@", "vesselOrder;", "#", "-", 
     Style["ObjectiveValuePerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselArrivalDates,", "vesselOrder,", 
     "totalVoyageDays,", "fillPercent,", "#", "&", "/@", "paths", ";", 
     Style["MatricesPerPath", 
      RGBColor[0, 0, 1]], "date1_,", "date2_,", "productID_,", 
     "longLocation_,", "shortLocation_,", "path_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "timeWindow,", "vesselArrivalDates,", 
     "vesselOrder,", "totalVoyageDays,", "fillPercent,", "longMaxInventory,", 
     "longMinInventory,", "shortMaxInventory,", "shortMinInventory,", 
     "longInventoryAndMarket,", "shortInventoryAndMarket", ",", "timeWindow", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date2", ";", "vesselArrivalDates", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation", ";", "vesselOrder", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], "#2", "-", "#1", "&,", "vesselArrivalDates", "All,",
      "1", ",", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "All,", "1", ";", 
     "totalVoyageDays", 
     Style["Max", 
      RGBColor[1, 0, 0]], 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], "#", "&", "/@", 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "vesselOrder", "All,", "2", "i", 
     "&", ",", "\"VesselTypeID\"", "1", "&&", "#LocationFrom", "longLocation",
      "&&", "#LocationTo", "shortLocation", "&", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselOrder", "All,", "2", ";", "fillPercent", "#",
      "2", "-", "1", "*Will", "be", "changed", "to", "a", "rule", "depending",
      "on", "heuristic*", "&", "/@", "vesselOrder;", "vdm", 
     Style["GenerateVoyageDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation,", "shortLocation,", 
     "productID,", "vesselOrder,", "fillPercent,", "path", ";", "svdm", 
     Style["GenerateShortVoyageDisplayMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "shortLocation,", "vesselArrivalDates,", "vesselOrder,", "vdm", ";", 
     Style["GenerateDepartingInventory", 
      RGBColor[0, 0, 1]], "vdm", ";", "longMaxInventory", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "longLocation", ";", "longMinInventory", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "longLocation", ";", "shortMaxInventory", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "shortLocation", ";", "shortMinInventory", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "shortLocation", ";", "longInventoryAndMarket", 
     Style["NetInventoryAndMarketValuesLongPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "longMaxInventory,", "longMinInventory", ";", "shortInventoryAndMarket", 
     Style["NetInventoryAndMarketValuesShortPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "shortMaxInventory,", "shortMinInventory,", "svdm", ";", "lmdm", 
     Style["GenerateLongMarketDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "longLocation,", 
     "longInventoryAndMarket", ";", "smdm", 
     Style["GenerateShortMarketDecisionMatrixPerPath", 
      RGBColor[0, 0, 1]], "timeWindow,", "productID,", "shortLocation,", 
     "shortInventoryAndMarket,", "totalVoyageDays", ";", 
     "Dataset`$ElisionThreshold", "256;", 
     Style["Grid", 
      RGBColor[1, 0, 0]], "vdm,", "svdm", ",", "lmdm,", "smdm", ",", 
     Style["Alignment", 
      RGBColor[1, 0, 0]], "-", "Left,", 
     Style["Left", 
      RGBColor[1, 0, 0]], ",", 
     Style["Top", 
      RGBColor[1, 0, 0]], ",", 
     Style["Spacings", 
      RGBColor[1, 0, 0]], "-", "0,", "3", ",", "0,", "3", ";", 
     Style["HeuristicResults", 
      RGBColor[0, 0, 1]], "date1_,", "date2_,", "productID_,", 
     "longLocation_,", "shortLocation_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "paths", ",", "paths", 
     Style["GenerateAllPaths", 
      RGBColor[0, 0, 1]], "date1,", "date2,", "longLocation", ";", 
     "solutions", 
     Style["Sort", 
      RGBColor[1, 0, 0]], 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], 
     Style["ObjectiveValueOverPaths", 
      RGBColor[0, 0, 1]], "date1,", "date2,", "productID,", "longLocation,", 
     "shortLocation,", "paths", ",", "x_", "/;", "x", "2", "\"No", 
     "Solution\"", ",", "#1", "2", "#2", "2", "&", ";", 
     Style["Manipulate", 
      RGBColor[1, 0, 0]], 
     Style["Column", 
      RGBColor[1, 0, 0]], "\"\",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Objective", 
     Style["Value", 
      RGBColor[1, 0, 0]], "$\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], 
     Style["NumberForm", 
      RGBColor[1, 0, 0]], "path", "/.", "solutions,", 
     Style["DigitBlock", 
      RGBColor[1, 0, 0]], "-", "3,", 
     Style["NumberPoint", 
      RGBColor[1, 0, 0]], "-", "\"\"", ",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", 
     Style["Darker", 
      RGBColor[1, 0, 0]], "Gray,", ".4", ",", "22,", 
     Style["Bold", 
      RGBColor[1, 0, 0]], ",", "\"\",", 
     Style["MatricesPerPath", 
      RGBColor[0, 0, 1]], "date1,", "date2,", "productID,", "longLocation,", 
     "shortLocation,", "path", ",", 
     Style["Spacings", 
      RGBColor[1, 0, 0]], "-", ".5", ",", "path,", "solutions", "1,", "1", 
     ",", 
     Style["Style", 
      RGBColor[1, 0, 0]], "\"Ranked", "Solutions\",", 
     Style["FontFamily", 
      RGBColor[1, 0, 0]], "-", "\"Calibri\",", 
     Style["Darker", 
      RGBColor[1, 0, 0]], "Gray,", ".4", ",", "18", ",", 
     Style["MapThread", 
      RGBColor[1, 0, 0]], "#2", "-", "\"Solution", "\"", 
     Style["ToString", 
      RGBColor[1, 0, 0]], "#1", "&,", 
     Style["Range", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "solutions", "All,", "1", ",", "solutions", "All,", 
     "1", ",", 
     Style["ImageSize", 
      RGBColor[1, 0, 0]], "-", "100", ",", 
     Style["ControlType", 
      RGBColor[1, 0, 0]], "-", "PopupMenu,", 
     Style["Paneled", 
      RGBColor[1, 0, 0]], "-", 
     Style["False", 
      RGBColor[1, 0, 0]], ";", 
     Style["SinglePathTestor", 
      RGBColor[0, 0, 1]], "timeWindow_,", "dayRange_,", "productID_,", 
     "longLocation_,", "shortLocation_,", "longMaxInventory_,", 
     "longMinInventory_,", "shortMaxInventory_,", "shortMinInventory_,", 
     "vesselArrivalDates_,", "vesselCapacity_,", "voyageDays_,", "path_", 
     Style["Block", 
      RGBColor[1, 0, 0]], "vesselShippingDates,", 
     "dayRangeBetweenVesselShipments,", "dayRangeBetweenVesselArrivals,", 
     "productionBetweenShipments,", "consumptionBetweenShipments,", 
     "amountShipped", ",", "vesselShippingDates", "#", "-", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["Position", 
      RGBColor[1, 0, 0]], "path,", "#", "0,", "dayRange", 
     Style["Position", 
      RGBColor[1, 0, 0]], "path,", "#", "1,", "1", ",", "&", "/@", 
     "vesselArrivalDates", "All,", "1", ";", "dayRangeBetweenVesselShipments", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#1", "0,", "#1,", "timeWindow", "1", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#2", "0,", "#2,", "timeWindow", "2", "&", "@@", 
     Style["Sort", 
      RGBColor[1, 0, 0]], "vesselShippingDates", "All,", "2", ";", 
     "dayRangeBetweenVesselArrivals", 
     Style["DateRange", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#1", "0,", "#1,", "timeWindow", "1", ",", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#2", "0,", "#2,", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", 
     Style["Max", 
      RGBColor[1, 0, 0]], "voyageDays", "All,", "2", "&", "@@", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Sort", 
      RGBColor[1, 0, 0]], "vesselShippingDates", "All,", "2", "0,", 
     Style["Length", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Sort", 
      RGBColor[1, 0, 0]], "vesselShippingDates", "All,", "2", ",", 
     "timeWindow", "1", ",", 
     Style["Last", 
      RGBColor[1, 0, 0]], 
     Style["Sort", 
      RGBColor[1, 0, 0]], 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#", "2", "0,", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "#", "2", ",", "#", "1", "/.", "voyageDays", ",", 
     Style["DatePlus", 
      RGBColor[1, 0, 0]], "timeWindow", "2", ",", 
     Style["Max", 
      RGBColor[1, 0, 0]], "voyageDays", "All,", "2", "&", "/@", 
     "vesselShippingDates", ";", "productionBetweenShipments", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["DailyProductionSchedule", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Date", "dayRangeBetweenVesselShipments", "i", 
     "&&", "#ProductID", "productID", "&&", "#LocationID", "longLocation", 
     "&", ",", "\"ProductionVolume\"", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "dayRangeBetweenVesselShipments", ";", 
     "consumptionBetweenShipments", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["Table", 
      RGBColor[1, 0, 0]], 
     Style["DailyConsumptionSchedule", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#Date", "dayRangeBetweenVesselArrivals", "i", "&&",
      "#ProductID", "productID", "&&", "#LocationID", "shortLocation", "&", 
     ",", "\"ProductionVolume\"", "1", ",", "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "dayRangeBetweenVesselArrivals", ";", 
     "amountShipped", 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], "#", "/.", "vesselCapacity", "&", "/@", 
     Style["If", 
      RGBColor[1, 0, 0]], 
     Style["Length", 
      RGBColor[1, 0, 0]], "#", "2", "1,", "#", "1", ",", "&", 
     "/@vesselShippingDates", ",", ";", 
     Style["If", 
      RGBColor[1, 0, 0]], "longMaxInventory", "-", "amountShipped", "+", 
     "productionBetweenShipments", "longMinInventory", "&&", 
     "shortMinInventory", "+", "amountShipped", "-", 
     "consumptionBetweenShipments", "shortMaxInventory,", "path", ";", 
     Style["PathEliminator", 
      RGBColor[0, 0, 1]], "date1_,", "date2_,", "productID_,", 
     "longLocation_,", "shortLocation_,", "paths_List", 
     Style["Block", 
      RGBColor[1, 0, 0]], "timeWindow,", "dayRange,", "vesselArrivalDates,", 
     "voyageDays,", "vesselCapacity,", "longMaxInventory,", 
     "longMinInventory,", "shortMaxInventory,", "shortMinInventory", ",", 
     "timeWindow", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date1", ",", 
     Style["DateConvert", 
      RGBColor[0, 0, 1]], "date2", ";", "dayRange", 
     Style["DateList", 
      RGBColor[1, 0, 0]], "/@", 
     Style["DayRange", 
      RGBColor[1, 0, 0]], "timeWindow", "1", ",", "timeWindow", "2", ";", 
     "vesselArrivalDates", 
     Style["GetArrivingVessels", 
      RGBColor[0, 0, 1]], "timeWindow,", "longLocation", ";", "voyageDays", 
     Style["Table", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", "All,", "1", "i", "-", 
     Style["Ceiling", 
      RGBColor[1, 0, 0]], 
     Style["First", 
      RGBColor[1, 0, 0]], 
     Style["Total", 
      RGBColor[1, 0, 0]], 
     Style["VoyageRules", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#VesselTypeID", 
     Style["TransportPool", 
      RGBColor[0, 0, 1]], 
     Style["Select", 
      RGBColor[1, 0, 0]], "#EquipmentID", "vesselArrivalDates", "All,", "1", 
     "i", "&", ",", "\"VesselTypeID\"", "1", "&&", "#LocationFrom", 
     "longLocation", "&&", "#LocationTo", "shortLocation", "&", "1", ",", 
     "i,", "1,", 
     Style["Length", 
      RGBColor[1, 0, 0]], "vesselArrivalDates", ";", "vesselCapacity", "#", 
     "-", 
     Style["GetVesselCapacity", 
      RGBColor[0, 0, 1]], "#", "&", "/@", "vesselArrivalDates", "All,", "1", 
     ";", "longMaxInventory", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "longLocation", ";", "longMinInventory", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "longLocation", ";", "shortMaxInventory", 
     Style["GetMaxInventoryConstraint", 
      RGBColor[0, 0, 1]], "shortLocation", ";", "shortMinInventory", 
     Style["GetMinInventoryConstraint", 
      RGBColor[0, 0, 1]], "shortLocation", ";", 
     Style["DeleteCases", 
      RGBColor[1, 0, 0]], 
     Style["SinglePathTestor", 
      RGBColor[0, 0, 1]], "timeWindow,", "dayRange,", "productID,", 
     "longLocation,", "shortLocation,", "longMaxInventory,", 
     "longMinInventory,", "shortMaxInventory,", "shortMinInventory,", 
     "vesselArrivalDates,", "vesselCapacity,", "voyageDays,", "#", "&", "/@", 
     "paths,", 
     Style["Null", 
      RGBColor[1, 0, 0]], ";"}]],
  StripOnInput->False,
  LineColor->GrayLevel[0.8],
  FrontFaceColor->GrayLevel[0.8],
  BackFaceColor->GrayLevel[0.8],
  GraphicsColor->GrayLevel[0.8],
  FontSize->8,
  FontColor->GrayLevel[0.8]]], "Output",
 CellChangeTimes->{{3.6490934512002697`*^9, 3.649093512145356*^9}, 
   3.6491066192520456`*^9, {3.6491067765501394`*^9, 3.6491068008015823`*^9}, 
   3.649106832121838*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Illustration of Nesting", "Section",
 CellChangeTimes->{{3.6490655867206917`*^9, 3.6490656188903494`*^9}}],

Cell["\<\
In the below plot, each function, either system or user-defined is located \
within the imported code string. All functions are converted into numeric \
values. The lighter colors are the user-defined functions. By comparing the \
distance between lighter patches, we obtain a loose qualitative assumption \
about the nesting occuring within the user functions. The more deeply nested \
functions would be a prudent starting location for code examination and \
optimizations.\
\>", "Text",
 CellChangeTimes->{{3.6490151134905767`*^9, 3.6490151632396526`*^9}, {
  3.6490153324679165`*^9, 3.6490154462522297`*^9}, {3.649015574176428*^9, 
  3.649015683741599*^9}, {3.64906564038179*^9, 3.649065641676593*^9}}],

Cell[TextData[{
 "The dark strip along the bottom represents the padded values necessary to \
create the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", " ", "x", " ", "n"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " square matrix."
}], "Text",
 CellChangeTimes->{{3.6490658772348213`*^9, 3.6490659192421*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"len", ",", "nX", ",", "toPad", ",", "nXn"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numericList", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"StringSplit", "[", 
        RowBox[{
         RowBox[{"LoadText", "[", "]"}], ",", 
         RowBox[{"WhitespaceCharacter", "|", 
          RowBox[{"Alternatives", "@@", 
           RowBox[{"Characters", "@", "\"\<{}[]<>():=\>\""}]}]}]}], "]"}], "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x_", "/;", 
           RowBox[{"MemberQ", "[", 
            RowBox[{"$UserFunc", ",", "x"}], "]"}]}], "\[RuleDelayed]", "2"}],
          ",", 
         RowBox[{
          RowBox[{"y_", "/;", 
           RowBox[{"MemberQ", "[", 
            RowBox[{
             RowBox[{"SysFunc", "[", "]"}], ",", "y"}], "]"}]}], 
          "\[RuleDelayed]", "1"}]}], "}"}]}], "/.", 
      RowBox[{
       RowBox[{"x_", "/;", 
        RowBox[{"StringQ", "[", "x", "]"}]}], "\[RuleDelayed]", 
       RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"len", "=", 
     RowBox[{"Length", "@", "numericList"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"nX", "=", 
     RowBox[{
      RowBox[{"Ceiling", "[", 
       SqrtBox["len"], "]"}], "^", "2"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"toPad", "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"nX", "-", "len"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"nXn", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{"numericList", ",", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", "toPad"}], "]"}]}], "]"}], "//", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"#", ",", 
          SqrtBox["nX"]}], "]"}], "&"}]}], "//", 
      RowBox[{
       RowBox[{"MatrixPlot", "[", 
        RowBox[{"#", ",", 
         RowBox[{"ColorFunction", "\[Rule]", "\"\<AvocadoColors\>\""}], ",", 
         RowBox[{
         "PlotLabel", "\[Rule]", 
          "\"\<Qualitative View:\\nFunctions and Nesting\>\""}]}], "]"}], 
       "&"}]}]}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.649013901630681*^9, 3.6490142128031664`*^9}, {
  3.649014243513214*^9, 3.649014319008334*^9}, {3.6490143694024105`*^9, 
  3.649014522265658*^9}, {3.6490146631618743`*^9, 3.649014847638158*^9}, {
  3.6490148871662197`*^9, 3.649014935297295*^9}, {3.6490149664583416`*^9, 
  3.649014967228343*^9}, {3.6490150135994186`*^9, 3.649015055711485*^9}, {
  3.6490151056365643`*^9, 3.649015107787568*^9}, {3.649015172789669*^9, 
  3.649015175499673*^9}, {3.6490156916916103`*^9, 3.6490157315606723`*^9}, {
  3.6490171731926517`*^9, 3.6490171758858056`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJztmK9LRFEQhR/4D4jYtLgg2wWLLLwuFi0Wk7BR7AoiaDbarVajQbAb1mIV
ZEVE0GgUfzQxPLjjfOfuWVh2OVzum/vNmZm7u7C9uzGcapqm9/P+/P79emu/
Pg5f2/2r0cncwU3bVZ/fWnkcPIzb/sza8sXpc9uf7d1Pn193Xj/ae19aP75t
dzafjoYv43awujg4u7u0bh2h/+XbrnrXulB/blb8pfoYjWd0H540ntatE3Sa
/2l9hpYvlbzUqtP8GX0/qTXvKnm0Xlan+ZDm5yz+zu//5IV2Xt9DtHyl0k9o
ejTPrP9PaDxLnSuajzp/n7duPtF15LnA1M0zl4PrzrqiXson0fvQ+GT1AZp/
ao1fhZs6Z887rbqjzQuVuoj2LW0fFV3Fb1n8S/k22ofRvqXtX4onzYfqcWb5
hMaHFn+p9TT/Z/UBmp5Vj7Xq5qOlq88FdV2Fm+PMjTPrXNFzsBQHmq7uWxVu
Kj5332D6gVbvWXxo+9PqjsYt2j8q/Gm6Cjf7lukf69YJ9Wudmd9SfdK61u8+
60zd/qmbm3qc0feHaA40ztbryEupus7yv/pzs/xTa7/yuXLnIO33nUp/mzQ+
NJ60uZx1rlJ+UOGf5VvaPjTO1s2ZoEfzVJmb6rrKfKzVn7R9aJyzfEg7l0qc
0Zy93usnYX3XfXyPcr/y+t/rPwAnidsH
   "], {{0, 0}, {34, 34}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{33.5, 
       FormBox["1", TraditionalForm]}, {24.5, 
       FormBox["10", TraditionalForm]}, {14.5, 
       FormBox["20", TraditionalForm]}, {0.5, 
       FormBox["34", TraditionalForm]}}, {{33.5, 
       FormBox["1", TraditionalForm]}, {24.5, 
       FormBox["10", TraditionalForm]}, {14.5, 
       FormBox["20", TraditionalForm]}, {0.5, 
       FormBox["34", TraditionalForm]}}}, {{{0.5, 
       FormBox["1", TraditionalForm]}, {9.5, 
       FormBox["10", TraditionalForm]}, {19.5, 
       FormBox["20", TraditionalForm]}, {33.5, 
       FormBox["34", TraditionalForm]}}, {{0.5, 
       FormBox["1", TraditionalForm]}, {9.5, 
       FormBox["10", TraditionalForm]}, {19.5, 
       FormBox["20", TraditionalForm]}, {33.5, 
       FormBox["34", TraditionalForm]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultPlotStyle" -> Automatic, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05]},
  PlotLabel->FormBox[
   "\"Qualitative View:\\nFunctions and Nesting\"", 
    TraditionalForm]]], "Output",
 CellChangeTimes->{
  3.64901438827244*^9, {3.6490144479245353`*^9, 3.649014484863597*^9}, 
   3.649014516426648*^9, {3.6490146749868927`*^9, 3.6490146960709257`*^9}, 
   3.649014728156974*^9, {3.6490147609080257`*^9, 3.6490148211371164`*^9}, 
   3.6490148513481627`*^9, {3.649014914900264*^9, 3.649014940062302*^9}, 
   3.64901497675036*^9, {3.649015034389452*^9, 3.649015059518491*^9}, 
   3.649015180059679*^9, 3.649015701869627*^9, 3.6490157354076786`*^9, 
   3.6490171851003323`*^9, 3.6490659672551866`*^9, 3.6490906858094473`*^9, 
   3.649106619532846*^9, {3.64910677679974*^9, 3.6491068010511827`*^9}, 
   3.649106835852245*^9}]
}, Open  ]],

Cell["\<\
The plot can be analyzed to determine the various levels of nesting. The \
user-functions, having a value of 1 are naively-assumed to only call built-in \
functions, values of 2. The pattern matching seeks all built-in functions \
occuring within the bounds of two user functions. \
\>", "Text",
 CellChangeTimes->{{3.649017029787449*^9, 3.649017067619613*^9}, {
  3.649065661270628*^9, 3.6490657083955135`*^9}, {3.6490657411707745`*^9, 
  3.649065785933456*^9}}],

Cell["1:2,2,2,2,2 \[Implies] User function with five calls to built-ins", \
"Text",
 CellChangeTimes->{{3.6490657948898716`*^9, 3.6490658333229427`*^9}}],

Cell["1:2,2 \[Implies] User function with two calls to built-ins.", "Text",
 CellChangeTimes->{{3.649065835836547*^9, 3.6490658542953796`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Nesting", " ", "Depth"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"nestDepth", "=", 
    RowBox[{"ReplaceList", "[", 
     RowBox[{"numericList", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"___", ",", "1", ",", 
         RowBox[{"p", ":", 
          RowBox[{"2", ".."}]}], ",", "1", ",", "___"}], "}"}], ":>", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "p", "}"}], "]"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.6490157427456894`*^9, 3.649015977719056*^9}, {
   3.6490160216361227`*^9, 3.6490160696831985`*^9}, 3.649065971957795*^9, 
   3.6490686021416197`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"Labeled", "@@@", 
    RowBox[{"Reverse", "/@", 
     RowBox[{"Tally", "[", "nestDepth", "]"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Calibri\>\""}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Levels of Nesting\>\"", ",", "\"\<Depth\>\""}], "}"}]}], 
   ",", 
   RowBox[{"PlotTheme", "->", "\"\<Scientific\>\""}], ",", 
   RowBox[{"GridLines", "->", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Nesting of Built-in Functions\>\"", ",", "\"\<Subsubsection\>\""}], 
     "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.64906860679663*^9, 3.6490688462279987`*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Opacity[0], PointBox[{0.40424519670631287`, 0.}]}, {{}, 
     {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
      Small]}], 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{0.5425434583714547, 0.}, {1.4574565416285452`, 
             136.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{57.88235294117647, 
            97.29709851656989}, {-98.5932189257829, 85.38562148434212}}],
          StatusArea[#, 136]& ,
          TagBoxNote->"136"],
         StyleBox[
         "136", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[136, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}, 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{1.5425434583714546`, 0.}, {2.457456541628545, 34.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{100.41616985508148`, 139.8309154304749}, {
            39.01591138181087, 85.38562148434212}}],
          StatusArea[#, 34]& ,
          TagBoxNote->"34"],
         StyleBox[
         "34", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[34, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}, 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{2.542543458371455, 0.}, {3.457456541628545, 12.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{142.9499867689865, 182.36473234437992`}, {
            68.69631203638991, 85.38562148434212}}],
          StatusArea[#, 12]& ,
          TagBoxNote->"12"],
         StyleBox[
         "12", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[12, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}, 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{3.542543458371455, 0.}, {4.457456541628545, 4.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{185.48380368289153`, 224.89854925828493`}, {
            79.48918500169138, 85.38562148434212}}],
          StatusArea[#, 4]& ,
          TagBoxNote->"4"],
         StyleBox[
         "4", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[4, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}, 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{4.542543458371455, 0.}, {5.457456541628545, 1.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{228.01762059679655`, 267.4323661721899}, {
            83.53651236367944, 85.38562148434212}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox[
         "1", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[1, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}, 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{5.542543458371455, 0.}, {6.457456541628545, 6.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{270.55143751070153`, 309.966183086095}, {
            76.79096676036602, 85.38562148434212}}],
          StatusArea[#, 6]& ,
          TagBoxNote->"6"],
         StyleBox[
         "6", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[6, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}, 
      {RGBColor[0.9, 0.36, 0.054], EdgeForm[{Opacity[0.651], Thickness[
       Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{6.542543458371455, 0.}, {7.457456541628545, 2.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{313.08525442460655`, 352.5}, {82.18740324301676, 
            85.38562148434212}}],
          StatusArea[#, 2]& ,
          TagBoxNote->"2"],
         StyleBox[
         "2", {FontFamily -> "Times", FontFamily -> "Times"}, StripOnInput -> 
          False]],
        Annotation[#, 
         Style[2, {FontFamily -> "Times", FontFamily -> "Times"}], 
         "Tooltip"]& ]}}, {}, {}}, {}, {}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.40424519670631287`, 0.},
  BaseStyle->{FontSize -> 14, FontFamily -> "Calibri"},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"Depth\"", TraditionalForm], None}, {
     FormBox["\"Levels of Nesting\"", TraditionalForm], None}},
  FrameStyle->Automatic,
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["1", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["2", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["3", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["4", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["7", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["5", TraditionalForm], 0}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox["11", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Times"},
  PlotLabel->FormBox[
    StyleBox[
    "\"Nesting of Built-in Functions\"", "Subsubsection", StripOnInput -> 
     False], TraditionalForm],
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{{3.6490688313269763`*^9, 3.6490688468779993`*^9}, 
   3.6490906871994495`*^9, 3.649106619579646*^9, {3.6491067768153396`*^9, 
   3.649106801097983*^9}, 3.649106837724248*^9}]
}, Open  ]],

Cell[TextData[{
 "With this level of rudimentary analysis of nested functions, the user can \
determine where the most likely cause for bottlenecks are located. Often with \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the overwhelming availablity of solution possibilities causes user\
\[CloseCurlyQuote]s to default to their standard method of solving problems. \
It is up to the user to leverage the power of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s functions and pattern matching to reduce computation \
time and increase code readability."
}], "Text",
 CellChangeTimes->{{3.6490689044660873`*^9, 3.6490690139702573`*^9}, {
  3.6490691177324204`*^9, 3.649069228131705*^9}}],

Cell[CellGroupData[{

Cell["Close", "Subsection",
 CellChangeTimes->{{3.649107111362838*^9, 3.6491071119244385`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Close Notebook\>\"", ",", 
   RowBox[{"NotebookClose", "[", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 ButtonBox["\<\"Close Notebook\"\>",
  Appearance->Automatic,
  ButtonFunction:>NotebookClose[],
  Evaluator->Automatic,
  Method->"Preemptive"]], "Output",
 CellChangeTimes->{3.649107226106841*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{942, 962},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.2 for Microsoft Windows (64-bit) (July 29, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 94, 1, 90, "Title"],
Cell[CellGroupData[{
Cell[699, 27, 128, 1, 63, "Section"],
Cell[830, 30, 268, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[1123, 39, 281, 6, 52, "Input"],
Cell[1407, 47, 934, 23, 31, "Output"]
}, Open  ]],
Cell[2356, 73, 556, 9, 87, "Text"],
Cell[2915, 84, 276, 5, 49, "Text"],
Cell[3194, 91, 181, 4, 30, "Text"],
Cell[3378, 97, 235, 5, 30, "Text"],
Cell[3616, 104, 187, 4, 30, "Text"],
Cell[3806, 110, 107, 1, 30, "Text"],
Cell[3916, 113, 722, 15, 72, "Input"],
Cell[4641, 130, 634, 12, 68, "Text"],
Cell[CellGroupData[{
Cell[5300, 146, 395, 11, 52, "Input"],
Cell[5698, 159, 609, 13, 31, "Output"]
}, Open  ]],
Cell[6322, 175, 1356, 35, 92, "Input"],
Cell[CellGroupData[{
Cell[7703, 214, 188, 4, 31, "Input"],
Cell[7894, 220, 316, 6, 31, "Output"]
}, Open  ]],
Cell[8225, 229, 917, 26, 68, "Text"],
Cell[9145, 257, 681, 17, 52, "Input"],
Cell[9829, 276, 567, 16, 52, "Input"],
Cell[10399, 294, 448, 8, 49, "Text"],
Cell[10850, 304, 1035, 27, 92, "Input"],
Cell[11888, 333, 508, 14, 52, "Input"],
Cell[CellGroupData[{
Cell[12421, 351, 447, 12, 52, "Input"],
Cell[12871, 365, 274, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13182, 374, 395, 11, 52, "Input"],
Cell[13580, 387, 346, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13963, 397, 311, 9, 52, "Input"],
Cell[14277, 408, 345, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14659, 417, 1361, 35, 112, "Input"],
Cell[16023, 454, 20486, 495, 249, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36546, 954, 1848, 47, 90, "Input"],
Cell[38397, 1003, 3345, 74, 152, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41791, 1083, 117, 1, 63, "Section"],
Cell[CellGroupData[{
Cell[41933, 1088, 1485, 41, 92, "Input"],
Cell[43421, 1131, 519163, 12128, 3311, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[562633, 13265, 112, 1, 63, "Section"],
Cell[562748, 13268, 716, 11, 87, "Text"],
Cell[563467, 13281, 321, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[563813, 13294, 2797, 69, 283, "Input"],
Cell[566613, 13365, 2616, 52, 411, "Output"]
}, Open  ]],
Cell[569244, 13420, 473, 8, 68, "Text"],
Cell[569720, 13430, 153, 2, 30, "Text"],
Cell[569876, 13434, 143, 1, 30, "Text"],
Cell[570022, 13437, 677, 17, 52, "Input"],
Cell[CellGroupData[{
Cell[570724, 13458, 921, 23, 92, "Input"],
Cell[571648, 13483, 11681, 315, 276, "Output"]
}, Open  ]],
Cell[583344, 13801, 721, 15, 87, "Text"],
Cell[CellGroupData[{
Cell[584090, 13820, 95, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[584210, 13825, 139, 3, 31, "Input"],
Cell[584352, 13830, 212, 6, 80, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
